From e9f0980069076e5406e83363fc8021b7a0043544 Mon Sep 17 00:00:00 2001
From: Shveta Malik <shveta.malik@gmail.com>
Date: Mon, 8 May 2023 15:37:43 +0530
Subject: [PATCH 8/8] objTree Removal for create drop alter table

---
 src/backend/commands/ddldeparse.c             | 4908 ++++++++++-------
 src/backend/replication/logical/ddltrigger.c  |    5 +-
 src/include/tcop/ddldeparse.h                 |    4 +-
 .../expected/alter_table.out                  |  278 +-
 .../expected/constraints.out                  |  284 +-
 .../expected/create_index.out                 |    4 +-
 .../expected/create_rule.out                  |   16 +-
 .../expected/create_table.out                 |  300 +-
 .../test_ddl_deparse_regress.c                |    6 +-
 9 files changed, 3295 insertions(+), 2510 deletions(-)

diff --git a/src/backend/commands/ddldeparse.c b/src/backend/commands/ddldeparse.c
index 5878d7e465..8b7acba8a5 100644
--- a/src/backend/commands/ddldeparse.c
+++ b/src/backend/commands/ddldeparse.c
@@ -122,7 +122,6 @@ typedef struct ObjElem
 bool		verbose = true;
 
 static void append_format_string(ObjTree *tree, char *sub_fmt);
-static void append_array_object(ObjTree *tree, char *sub_fmt, List *array);
 static void append_bool_object(ObjTree *tree, char *sub_fmt, bool value);
 static void append_object_object(ObjTree *tree, char *sub_fmt, ObjTree *value);
 static char *append_object_to_format_string(ObjTree *tree, char *sub_fmt);
@@ -133,19 +132,11 @@ static ObjElem *new_object(ObjType type, char *name);
 static ObjTree *new_objtree_for_qualname_id(Oid classId, Oid objectId);
 static ObjElem *new_object_object(ObjTree *value);
 static ObjTree *new_objtree_VA(char *fmt, int numobjs, ...);
+static void new_jsonb_VA(JsonbParseState *state, char *fmt, bool skipObject, int numobjs, ...);
 static JsonbValue *objtree_to_jsonb_rec(ObjTree *tree, JsonbParseState *state, char *owner);
 static char *RelationGetColumnDefault(Relation rel, AttrNumber attno,
 									  List *dpcontext, Node **expr);
 
-static ObjTree *deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
-								  ColumnDef *coldef, bool is_alter, Node **expr);
-static ObjTree *deparse_ColumnIdentity(Oid seqrelid, char identity, bool alter_table);
-static ObjTree *deparse_ColumnSetOptions(AlterTableCmd *subcmd);
-
-static ObjTree *deparse_DefElem(DefElem *elem, bool is_reset);
-static ObjTree *deparse_OnCommitClause(OnCommitAction option);
-static ObjTree *deparse_RelSetOptions(AlterTableCmd *subcmd);
-
 static inline ObjElem *deparse_Seq_Cache(Form_pg_sequence seqdata, bool alter_table);
 static inline ObjElem *deparse_Seq_Cycle(Form_pg_sequence seqdata, bool alter_table);
 static inline ObjElem *deparse_Seq_IncrementBy(Form_pg_sequence seqdata, bool alter_table);
@@ -155,11 +146,31 @@ static inline ObjElem *deparse_Seq_Restart(int64 last_value);
 static inline ObjElem *deparse_Seq_Startwith(Form_pg_sequence seqdata, bool alter_table);
 static inline ObjElem *deparse_Seq_As(Form_pg_sequence seqdata);
 
-static List *deparse_InhRelations(Oid objectId);
-static List *deparse_TableElements(Relation relation, List *tableElements, List *dpcontext,
-								   bool typed, bool composite);
 static void mark_function_volatile(ddl_deparse_context *context, Node *expr);
 
+static void deparse_ColumnDef_toJsonb(JsonbParseState *state,
+									  Relation relation, List *dpcontext,
+									  bool composite, ColumnDef *coldef,
+									  bool is_alter, Node **expr);
+static void deparse_TableElems_ToJsonb(JsonbParseState *state,
+										 Relation relation, List *tableElements,
+										 List *dpcontext, bool typed,
+										 bool composite);
+
+static void deparse_DefElem_ToJsonb(JsonbParseState *state, DefElem *elem, bool is_reset);
+static void insert_jsonb_key(JsonbParseState *state, char *name);
+static void insert_jsonb_str_element(JsonbParseState *state, char *name, const char *value);
+static void insert_jsonb_bool_element(JsonbParseState *state, char *name, bool value);
+static void insert_jsonb_numeric_element(JsonbParseState *state, char *name, int value);
+static void insert_str_object(JsonbParseState *state, char *fmt, char *key, char *val);
+static void insert_not_present_obj(JsonbParseState *state, char *fmt);
+static void fmt_to_jsonb_element(JsonbParseState *state, char *fmtStr);
+static void new_jsonb_for_type(JsonbParseState *state, Oid typeId, int32 typmod);
+static void new_jsonb_for_qualname(JsonbParseState *state, Oid nspid, char *objName, char* keyName);
+static void new_jsonb_for_qualname_id(JsonbParseState *state, Oid classId, Oid objectId, char* keyName);
+
+static Jsonb *deparse_CreateStmt(Oid objectId, Node *parsetree, char *owner);
+static Jsonb *deparse_alter_table(CollectedCommand *cmd, ddl_deparse_context *context);
 /*
  * Mark the func_volatile flag for an expression in the command.
  */
@@ -202,50 +213,6 @@ append_not_present(ObjTree *tree, char *sub_fmt)
 	append_bool_object(tree, "present", false);
 }
 
-/*
- * Append an array parameter to a tree.
- */
-static void
-append_array_object(ObjTree *tree, char *sub_fmt, List *array)
-{
-	ObjElem    *param;
-	char	   *object_name;
-
-	Assert(sub_fmt);
-
-	if (list_length(array) == 0)
-		return;
-
-	if (!verbose)
-	{
-		ListCell   *lc;
-
-		/* Remove elements where present flag is false */
-		foreach(lc, array)
-		{
-			ObjElem    *elem = (ObjElem *) lfirst(lc);
-
-			Assert(elem->objtype == ObjTypeObject ||
-				   elem->objtype == ObjTypeString);
-
-			if (!elem->value.object->present &&
-				elem->objtype == ObjTypeObject)
-				array = foreach_delete_current(array, lc);
-		}
-
-	}
-
-	/* Check for empty list after removing elements */
-	if (list_length(array) == 0)
-		return;
-
-	object_name = append_object_to_format_string(tree, sub_fmt);
-
-	param = new_object(ObjTypeArray, object_name);
-	param->value.array = array;
-	append_premade_object(tree, param);
-}
-
 /*
  * Append a boolean parameter to a tree.
  */
@@ -547,6 +514,79 @@ new_objtree_for_type(Oid typeId, int32 typmod)
 						  "typarray", ObjTypeBool, type_array);
 }
 
+/*
+ * Append new jsonb key:value pair to output JsonbParseState -- varargs version.
+ *
+ * The "fmt" argument is used to append as a "fmt" element in current object.
+ * The "skipObject" argument indicates if we want to skip object creation
+ * considering it will be taken care by the caller.
+ * The "numobjs" argument indicates the number of extra elements to append;
+ * for each one, a name (string), type (from the jbvType enum) and value must
+ * be supplied.  The value must match the type given; for instance, jbvBool
+ * requires an * bool, jbvString requires a char * and so no,
+ * Each element type  must match the conversion specifier given in the format
+ * string, as described in ddl_deparse_expand_command.
+ *
+ * Note we don't have the luxury of sprintf-like compiler warnings for
+ * malformed argument lists.
+ */
+static void
+new_jsonb_VA(JsonbParseState *state, char *fmt, bool skipObject, int numobjs, ...)
+{
+	va_list		args;
+	int			i;
+
+	/* Set up the toplevel object if needed */
+	if (!skipObject)
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* Set up the "fmt" */
+	if (fmt)
+		fmt_to_jsonb_element(state, fmt);
+
+
+	/* And process the given varargs */
+	va_start(args, numobjs);
+
+	for (i = 0; i < numobjs; i++)
+	{
+		char	   *name;
+		enum jbvType    type;
+
+		name = va_arg(args, char *);
+		type = va_arg(args, enum jbvType);
+
+		/*
+		 * For all param types other than jbvNull, there must be a value in
+		 * the varargs. Fetch it and add the fully formed subobject into the
+		 * main object.
+		 */
+		switch (type)
+		{
+			case jbvNull:
+				/* Null params don't have a value (obviously) */
+				break;
+			case jbvBool:
+				insert_jsonb_bool_element(state, name, va_arg(args, int));
+				break;
+			case jbvString:
+				insert_jsonb_str_element(state, name, va_arg(args, char *));
+				break;
+			case jbvNumeric:
+				insert_jsonb_numeric_element(state, name, va_arg(args, int));
+				break;
+			default:
+				elog(ERROR, "invalid ObjTree element type %d", type);
+		}
+
+	}
+
+	va_end(args);
+
+	if (!skipObject)
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
 /*
  * Allocate a new object tree to store parameter values -- varargs version.
  *
@@ -779,117 +819,6 @@ objtree_to_jsonb_rec(ObjTree *tree, JsonbParseState *state, char *owner)
 	return pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
-/*
- * Subroutine for CREATE TABLE deparsing.
- *
- * Given a table OID, obtain its constraints and append them to the given
- * elements list.  The updated list is returned.
- *
- * This works for typed tables, regular tables.
- *
- * Note that CONSTRAINT_FOREIGN constraints are always ignored.
- */
-static List *
-obtainConstraints(List *elements, Oid relationId)
-{
-	Relation	conRel;
-	ScanKeyData key;
-	SysScanDesc scan;
-	HeapTuple	tuple;
-	ObjTree    *constr;
-
-	Assert(OidIsValid(relationId));
-
-	/*
-	 * Scan pg_constraint to fetch all constraints linked to the given
-	 * relation.
-	 */
-	conRel = table_open(ConstraintRelationId, AccessShareLock);
-	ScanKeyInit(&key, Anum_pg_constraint_conrelid, BTEqualStrategyNumber,
-				F_OIDEQ, ObjectIdGetDatum(relationId));
-	scan = systable_beginscan(conRel, ConstraintRelidTypidNameIndexId, true,
-							  NULL, 1, &key);
-
-	/*
-	 * For each constraint, add a node to the list of table elements.  In
-	 * these nodes we include not only the printable information ("fmt"), but
-	 * also separate attributes to indicate the type of constraint, for
-	 * automatic processing.
-	 */
-	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
-	{
-		Form_pg_constraint constrForm;
-		char	   *contype;
-
-		constrForm = (Form_pg_constraint) GETSTRUCT(tuple);
-
-		switch (constrForm->contype)
-		{
-			case CONSTRAINT_CHECK:
-				contype = "check";
-				break;
-			case CONSTRAINT_FOREIGN:
-				continue;		/* not here */
-			case CONSTRAINT_PRIMARY:
-				contype = "primary key";
-				break;
-			case CONSTRAINT_UNIQUE:
-				contype = "unique";
-				break;
-			case CONSTRAINT_EXCLUSION:
-				contype = "exclusion";
-				break;
-			default:
-				elog(ERROR, "unrecognized constraint type");
-		}
-
-		/*
-		 * "type" and "contype" are not part of the printable output, but are
-		 * useful to programmatically distinguish these from columns and among
-		 * different constraint types.
-		 *
-		 * XXX it might be useful to also list the column names in a PK, etc.
-		 */
-		constr = new_objtree_VA("CONSTRAINT %{name}I %{definition}s", 4,
-								"type", ObjTypeString, "constraint",
-								"contype", ObjTypeString, contype,
-								"name", ObjTypeString, NameStr(constrForm->conname),
-								"definition", ObjTypeString,
-								pg_get_constraintdef_string(constrForm->oid));
-
-		if (constrForm->conindid &&
-			(constrForm->contype == CONSTRAINT_PRIMARY ||
-			 constrForm->contype == CONSTRAINT_UNIQUE ||
-			 constrForm->contype == CONSTRAINT_EXCLUSION))
-		{
-			Oid			tblspc = get_rel_tablespace(constrForm->conindid);
-
-			if (OidIsValid(tblspc))
-			{
-				char	   *tblspcname = get_tablespace_name(tblspc);
-
-				if (!tblspcname)
-				{
-					elog(ERROR, "cache lookup failed for tablespace %u",
-									tblspc);
-				}
-
-				append_string_object(constr,
-									 "USING INDEX TABLESPACE %{tblspc}s",
-									 "tblspc",
-									 tblspcname);
-			}
-		}
-
-		elements = lappend(elements, new_object_object(constr));
-	}
-
-	systable_endscan(scan);
-	table_close(conRel, AccessShareLock);
-
-	return elements;
-}
-
 /*
  * Obtain the deparsed default value for the given column of the given table.
  *
@@ -944,651 +873,202 @@ RelationGetPartitionBound(Oid relid)
 }
 
 /*
- * Deparse a ColumnDef node within a regular (non-typed) table creation.
- *
- * NOT NULL constraints in the column definition are emitted directly in the
- * column definition by this routine; other constraints must be emitted
- * elsewhere (the info in the parse node is incomplete anyway).
+ * ... ALTER COLUMN ... SET/RESET (...)
  *
  * Verbose syntax
- * %{name}I %{coltype}T %{compression}s %{default}s %{not_null}s %{collation}s
+ * ALTER COLUMN %{column}I RESET|SET (%{options:, }s)
  */
-static ObjTree *
-deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
-				  ColumnDef *coldef, bool is_alter, Node **expr)
+static void
+deparse_ColumnSetOptions_ToJsonb(JsonbParseState *state, AlterTableCmd *subcmd)
 {
-	ObjTree    *ret;
-	ObjTree    *tmp_obj;
-	Oid			relid = RelationGetRelid(relation);
-	HeapTuple	attrTup;
-	Form_pg_attribute attrForm;
-	Oid			typid;
-	int32		typmod;
-	Oid			typcollation;
-	bool		saw_notnull;
 	ListCell   *cell;
+	bool		is_reset = subcmd->subtype == AT_ResetOptions;
+	bool            elem_found = false;
 
-	/*
-	 * Inherited columns without local definitions must not be emitted.
-	 *
-	 * XXX maybe it is useful to have them with "present = false" or some
-	 * such?
-	 */
-	if (!coldef->is_local)
-		return NULL;
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	new_jsonb_VA(state,
+				 "ALTER COLUMN %{column}I %{option}s (%{options:, }s)", true, 2,
+				 "column", jbvString, subcmd->name,
+				 "option", jbvString, is_reset ? "RESET" : "SET");
 
-	attrTup = SearchSysCacheAttName(relid, coldef->colname);
-	if (!HeapTupleIsValid(attrTup))
-		elog(ERROR, "could not find cache entry for column \"%s\" of relation %u",
-			 coldef->colname, relid);
-	attrForm = (Form_pg_attribute) GETSTRUCT(attrTup);
+	insert_jsonb_key(state, "options");
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
 
-	get_atttypetypmodcoll(relid, attrForm->attnum,
-						  &typid, &typmod, &typcollation);
+	foreach(cell, (List *) subcmd->def)
+	{
+		DefElem    *elem;
 
-	ret = new_objtree_VA("%{name}I %{coltype}T", 3,
-						 "type", ObjTypeString, "column",
-						 "name", ObjTypeString, coldef->colname,
-						 "coltype", ObjTypeObject,
-						 new_objtree_for_type(typid, typmod));
+		elem = (DefElem *) lfirst(cell);
+		deparse_DefElem_ToJsonb(state, elem, is_reset);
+		elem_found = true;
+	}
 
-	/* STORAGE clause */
-	if (!composite)
-		append_string_object(ret, "STORAGE %{colstorage}s", "colstorage",
-							 storage_name(attrForm->attstorage));
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 
-	/* COMPRESSION clause */
-	tmp_obj = new_objtree("COMPRESSION");
-	if (coldef->compression)
-		append_string_object(tmp_obj, "%{compression_method}I",
-							 "compression_method", coldef->compression);
-	else
-		append_not_present(tmp_obj, "%{compression_method}I");
+	Assert(elem_found);
 
-	append_object_object(ret, "%{compression}s", tmp_obj);
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
 
-	tmp_obj = new_objtree("COLLATE");
-	if (OidIsValid(typcollation))
-		append_object_object(tmp_obj, "%{collation_name}D",
-							 new_objtree_for_qualname_id(CollationRelationId,
-														 typcollation));
-	else
-		append_not_present(tmp_obj, "%{collation_name}D");
+/*
+ * Deparse the sequence CACHE option.
+ *
+ * Verbose syntax
+ * SET CACHE %{value}s
+ * OR
+ * CACHE %{value}
+ */
+static inline ObjElem *
+deparse_Seq_Cache(Form_pg_sequence seqdata, bool alter_table)
+{
+	ObjTree    *ret;
+	char	   *fmt;
 
-	append_object_object(ret, "%{collation}s", tmp_obj);
+	fmt = alter_table ? "SET CACHE %{value}s" : "CACHE %{value}s";
 
-	if (!composite)
-	{
-		Oid			seqrelid = InvalidOid;
+	ret = new_objtree_VA(fmt, 2,
+						 "clause", ObjTypeString, "cache",
+						 "value", ObjTypeString,
+						 psprintf(INT64_FORMAT, seqdata->seqcache));
 
-		/*
-		 * Emit a NOT NULL declaration if necessary.  Note that we cannot
-		 * trust pg_attribute.attnotnull here, because that bit is also set
-		 * when primary keys are specified; we must not emit a NOT NULL
-		 * constraint in that case, unless explicitly specified.  Therefore,
-		 * we scan the list of constraints attached to this column to
-		 * determine whether we need to emit anything. (Fortunately, NOT NULL
-		 * constraints cannot be table constraints.)
-		 *
-		 * In the ALTER TABLE cases, we also add a NOT NULL if the colDef is
-		 * marked is_not_null.
-		 */
-		saw_notnull = false;
-		foreach(cell, coldef->constraints)
-		{
-			Constraint *constr = (Constraint *) lfirst(cell);
-
-			if (constr->contype == CONSTR_NOTNULL)
-			{
-				saw_notnull = true;
-				break;
-			}
-		}
-
-		if (is_alter && coldef->is_not_null)
-			saw_notnull = true;
-
-		append_string_object(ret, "%{not_null}s", "not_null",
-							 saw_notnull ? "NOT NULL" : "");
-
-		tmp_obj = new_objtree("DEFAULT");
-		if (attrForm->atthasdef &&
-			coldef->generated != ATTRIBUTE_GENERATED_STORED)
-		{
-			char	   *defstr;
-
-			defstr = RelationGetColumnDefault(relation, attrForm->attnum,
-											  dpcontext, expr);
-
-			append_string_object(tmp_obj, "%{default}s", "default", defstr);
-		}
-		else
-			append_not_present(tmp_obj, "%{default}s");
-
-		append_object_object(ret, "%{default}s", tmp_obj);
-
-		/* IDENTITY COLUMN */
-		if (coldef->identity)
-		{
-			/*
-			 * For identity column, find the sequence owned by column in order
-			 * to deparse the column definition.
-			 */
-			seqrelid = getIdentitySequence(relid, attrForm->attnum, true);
-			if (OidIsValid(seqrelid) && coldef->identitySequence)
-				seqrelid = RangeVarGetRelid(coldef->identitySequence, NoLock, false);
-		}
-
-		tmp_obj = new_objtree("");
-		if (OidIsValid(seqrelid))
-		{
-			ObjTree    *tmp_obj2;
-
-			tmp_obj2 = deparse_ColumnIdentity(seqrelid, coldef->identity, is_alter);
-			append_object_object(tmp_obj, "%{identity_column}s", tmp_obj2);
-		}
-		else
-			append_not_present(tmp_obj, "%{identity_column}s");
-
-		append_object_object(ret, "%{identity_column}s", tmp_obj);
-
-		/* GENERATED COLUMN EXPRESSION */
-		tmp_obj = new_objtree("GENERATED ALWAYS AS");
-		if (coldef->generated == ATTRIBUTE_GENERATED_STORED)
-		{
-			char	   *defstr;
-
-			defstr = RelationGetColumnDefault(relation, attrForm->attnum,
-											  dpcontext, expr);
-			append_string_object(tmp_obj, "(%{generation_expr}s) STORED",
-								 "generation_expr", defstr);
-		}
-		else
-			append_not_present(tmp_obj, "(%{generation_expr}s) STORED");
-
-		append_object_object(ret, "%{generated_column}s", tmp_obj);
-	}
-
-	ReleaseSysCache(attrTup);
-
-	return ret;
-}
+	return new_object_object(ret);
+}
 
 /*
- * Deparse a ColumnDef node within a typed table creation. This is simpler
- * than the regular case, because we don't have to emit the type declaration,
- * collation, or default. Here we only return something if the column is being
- * declared NOT NULL.
- *
- * As in deparse_ColumnDef, any other constraint is processed elsewhere.
+ * Deparse the sequence CYCLE option.
  *
  * Verbose syntax
- * %{name}I WITH OPTIONS %{not_null}s %{default}s.
+ * SET %{no}s CYCLE
+ * OR
+ * %{no}s CYCLE
  */
-static ObjTree *
-deparse_ColumnDef_typed(Relation relation, List *dpcontext, ColumnDef *coldef)
+static inline ObjElem *
+deparse_Seq_Cycle(Form_pg_sequence seqdata, bool alter_table)
 {
-	ObjTree    *ret = NULL;
-	ObjTree    *tmp_obj;
-	Oid			relid = RelationGetRelid(relation);
-	HeapTuple	attrTup;
-	Form_pg_attribute attrForm;
-	Oid			typid;
-	int32		typmod;
-	Oid			typcollation;
-	bool		saw_notnull;
-	ListCell   *cell;
-
-	attrTup = SearchSysCacheAttName(relid, coldef->colname);
-	if (!HeapTupleIsValid(attrTup))
-		elog(ERROR, "could not find cache entry for column \"%s\" of relation %u",
-			 coldef->colname, relid);
-	attrForm = (Form_pg_attribute) GETSTRUCT(attrTup);
-
-	get_atttypetypmodcoll(relid, attrForm->attnum,
-						  &typid, &typmod, &typcollation);
-
-	/*
-	 * Search for a NOT NULL declaration. As in deparse_ColumnDef, we rely on
-	 * finding a constraint on the column rather than coldef->is_not_null.
-	 * (This routine is never used for ALTER cases.)
-	 */
-	saw_notnull = false;
-	foreach(cell, coldef->constraints)
-	{
-		Constraint *constr = (Constraint *) lfirst(cell);
-
-		if (constr->contype == CONSTR_NOTNULL)
-		{
-			saw_notnull = true;
-			break;
-		}
-	}
-
-	if (!saw_notnull && !attrForm->atthasdef)
-	{
-		ReleaseSysCache(attrTup);
-		return NULL;
-	}
-
-	tmp_obj = new_objtree("DEFAULT");
-	if (attrForm->atthasdef)
-	{
-		char	   *defstr;
-
-		defstr = RelationGetColumnDefault(relation, attrForm->attnum,
-										  dpcontext, NULL);
-
-		append_string_object(tmp_obj, "%{default}s", "default", defstr);
-	}
-	else
-		append_not_present(tmp_obj, "%{default}s");
-
-	ret = new_objtree_VA("%{name}I WITH OPTIONS %{not_null}s %{default}s", 4,
-						 "type", ObjTypeString, "column",
-						 "name", ObjTypeString, coldef->colname,
-						 "not_null", ObjTypeString,
-						 saw_notnull ? "NOT NULL" : "",
-						 "default", ObjTypeObject, tmp_obj);
+	ObjTree    *ret;
+	char	   *fmt;
 
-	/* Generated columns are not supported on typed tables, so we are done */
+	fmt = alter_table ? "SET %{no}s CYCLE" : "%{no}s CYCLE";
 
-	ReleaseSysCache(attrTup);
+	ret = new_objtree_VA(fmt, 2,
+						 "clause", ObjTypeString, "cycle",
+						 "no", ObjTypeString,
+						 seqdata->seqcycle ? "" : "NO");
 
-	return ret;
+	return new_object_object(ret);
 }
 
 /*
- * Deparse the definition of column identity.
+ * Deparse the sequence INCREMENT BY option.
  *
  * Verbose syntax
- * SET GENERATED %{option}s %{identity_type}s %{seq_definition: }s
- * 	OR
- * GENERATED %{option}s AS IDENTITY %{identity_type}s ( %{seq_definition: }s )
+ * SET INCREMENT BY %{value}s
+ * OR
+ * INCREMENT BY %{value}s
  */
-static ObjTree *
-deparse_ColumnIdentity(Oid seqrelid, char identity, bool alter_table)
+static inline ObjElem *
+deparse_Seq_IncrementBy(Form_pg_sequence seqdata, bool alter_table)
 {
 	ObjTree    *ret;
-	ObjTree    *ident_obj;
-	List	   *elems = NIL;
-	Form_pg_sequence seqform;
-	Sequence_values *seqvalues;
-	char	   *identfmt;
-	char	   *objfmt;
-
-	if (alter_table)
-	{
-		identfmt = "SET GENERATED ";
-		objfmt = "%{option}s";
-	}
-	else
-	{
-		identfmt = "GENERATED ";
-		objfmt = "%{option}s AS IDENTITY";
-	}
-
-	ident_obj = new_objtree(identfmt);
-	if (identity == ATTRIBUTE_IDENTITY_ALWAYS)
-		append_string_object(ident_obj, objfmt, "option", "ALWAYS");
-	else if (identity == ATTRIBUTE_IDENTITY_BY_DEFAULT)
-		append_string_object(ident_obj, objfmt, "option", "BY DEFAULT");
-	else
-		append_not_present(ident_obj, objfmt);
-
-	ret = new_objtree_VA("%{identity_type}s", 1,
-						 "identity_type", ObjTypeObject, ident_obj);
-
-	seqvalues = get_sequence_values(seqrelid);
-	seqform = seqvalues->seqform;
+	char	   *fmt;
 
-	/* Definition elements */
-	elems = lappend(elems, deparse_Seq_Cache(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Cycle(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_IncrementBy(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Minvalue(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Maxvalue(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Startwith(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Restart(seqvalues->last_value));
-	/* We purposefully do not emit OWNED BY here */
+	fmt = alter_table ? "SET INCREMENT BY %{value}s" : "INCREMENT BY %{value}s";
 
-	if (alter_table)
-		append_array_object(ret, "%{seq_definition: }s", elems);
-	else
-		append_array_object(ret, "( %{seq_definition: }s )", elems);
+	ret = new_objtree_VA(fmt, 2,
+						 "clause", ObjTypeString, "seqincrement",
+						 "value", ObjTypeString,
+						 psprintf(INT64_FORMAT, seqdata->seqincrement));
 
-	return ret;
+	return new_object_object(ret);
 }
 
 /*
- * ... ALTER COLUMN ... SET/RESET (...)
+ * Deparse the sequence MAXVALUE option.
  *
  * Verbose syntax
- * ALTER COLUMN %{column}I RESET|SET (%{options:, }s)
+ * SET MAXVALUE %{value}s
+ * OR
+ * MAXVALUE %{value}s
  */
-static ObjTree *
-deparse_ColumnSetOptions(AlterTableCmd *subcmd)
+static inline ObjElem *
+deparse_Seq_Maxvalue(Form_pg_sequence seqdata, bool alter_table)
 {
-	List	   *sets = NIL;
-	ListCell   *cell;
 	ObjTree    *ret;
-	bool		is_reset = subcmd->subtype == AT_ResetOptions;
-
-	ret = new_objtree_VA("ALTER COLUMN %{column}I %{option}s", 2,
-						 "column", ObjTypeString, subcmd->name,
-						 "option", ObjTypeString, is_reset ? "RESET" : "SET");
-
-	foreach(cell, (List *) subcmd->def)
-	{
-		DefElem    *elem;
-		ObjTree    *set;
+	char	   *fmt;
 
-		elem = (DefElem *) lfirst(cell);
-		set = deparse_DefElem(elem, is_reset);
-		sets = lappend(sets, new_object_object(set));
-	}
+	fmt = alter_table ? "SET MAXVALUE %{value}s" : "MAXVALUE %{value}s";
 
-	Assert(sets);
-	append_array_object(ret, "(%{options:, }s)", sets);
+	ret = new_objtree_VA(fmt, 2,
+						 "clause", ObjTypeString, "maxvalue",
+						 "value", ObjTypeString,
+						 psprintf(INT64_FORMAT, seqdata->seqmax));
 
-	return ret;
+	return new_object_object(ret);
 }
 
 /*
- * Deparse SET/RESET clause as used by ALTER TABLE ... SET/RESET (...)
+ * Deparse the sequence MINVALUE option.
  *
  * Verbose syntax
- * RESET|SET (%{options:, }s)
+ * SET MINVALUE %{value}s
+ * OR
+ * MINVALUE %{value}s
  */
-static ObjTree *
-deparse_RelSetOptions(AlterTableCmd *subcmd)
+static inline ObjElem *
+deparse_Seq_Minvalue(Form_pg_sequence seqdata, bool alter_table)
 {
-	List	   *sets = NIL;
-	ListCell   *cell;
-	bool		is_reset = subcmd->subtype == AT_ResetRelOptions;
-
-	foreach(cell, (List *) subcmd->def)
-	{
-		DefElem    *elem;
-		ObjTree    *set;
+	ObjTree    *ret;
+	char	   *fmt;
 
-		elem = (DefElem *) lfirst(cell);
-		set = deparse_DefElem(elem, is_reset);
-		sets = lappend(sets, new_object_object(set));
-	}
+	fmt = alter_table ? "SET MINVALUE %{value}s" : "MINVALUE %{value}s";
 
-	Assert(sets);
+	ret = new_objtree_VA(fmt, 2,
+						 "clause", ObjTypeString, "minvalue",
+						 "value", ObjTypeString,
+						 psprintf(INT64_FORMAT, seqdata->seqmin));
 
-	return new_objtree_VA("%{set_reset}s (%{options:, }s)", 2,
-						  "set_reset", ObjTypeString, is_reset ? "RESET" : "SET",
-						  "options", ObjTypeArray, sets);
+	return new_object_object(ret);
 }
 
 /*
- * Deparse DefElems, as used e.g. by ALTER COLUMN ... SET, into a list of SET
- * (...)  or RESET (...) contents.
+ * Deparse the sequence OWNED BY command.
  *
  * Verbose syntax
- * %{label}s = %{value}L
+ * OWNED BY %{owner}D
  */
-static ObjTree *
-deparse_DefElem(DefElem *elem, bool is_reset)
+static ObjElem *
+deparse_Seq_OwnedBy(Oid sequenceId, bool alter_table)
 {
-	ObjTree    *ret;
-	ObjTree    *optname = new_objtree("");
+	ObjTree    *ret = NULL;
+	Relation	depRel;
+	SysScanDesc scan;
+	ScanKeyData keys[3];
+	HeapTuple	tuple;
 
-	if (elem->defnamespace != NULL)
-		append_string_object(optname, "%{schema}I.", "schema",
-							 elem->defnamespace);
+	depRel = table_open(DependRelationId, AccessShareLock);
+	ScanKeyInit(&keys[0],
+				Anum_pg_depend_classid,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(RelationRelationId));
+	ScanKeyInit(&keys[1],
+				Anum_pg_depend_objid,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(sequenceId));
+	ScanKeyInit(&keys[2],
+				Anum_pg_depend_objsubid,
+				BTEqualStrategyNumber, F_INT4EQ,
+				Int32GetDatum(0));
 
-	append_string_object(optname, "%{label}I", "label", elem->defname);
+	scan = systable_beginscan(depRel, DependDependerIndexId, true,
+							  NULL, 3, keys);
+	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
+	{
+		Oid			ownerId;
+		Form_pg_depend depform;
+		ObjTree    *tmp_obj;
+		char	   *colname;
 
-	ret = new_objtree_VA("%{label}s", 1,
-						 "label", ObjTypeObject, optname);
-
-	if (!is_reset)
-		append_string_object(ret, "= %{value}L", "value",
-							 elem->arg ? defGetString(elem) :
-							 defGetBoolean(elem) ? "TRUE" : "FALSE");
-
-	return ret;
-}
-
-/*
- * Deparse the INHERITS relations.
- *
- * Given a table OID, return a schema-qualified table list representing
- * the parent tables.
- */
-static List *
-deparse_InhRelations(Oid objectId)
-{
-	List	   *parents = NIL;
-	Relation	inhRel;
-	SysScanDesc scan;
-	ScanKeyData key;
-	HeapTuple	tuple;
-
-	inhRel = table_open(InheritsRelationId, RowExclusiveLock);
-
-	ScanKeyInit(&key,
-				Anum_pg_inherits_inhrelid,
-				BTEqualStrategyNumber, F_OIDEQ,
-				ObjectIdGetDatum(objectId));
-
-	scan = systable_beginscan(inhRel, InheritsRelidSeqnoIndexId,
-							  true, NULL, 1, &key);
-
-	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
-	{
-		ObjTree    *parent;
-		Form_pg_inherits formInh = (Form_pg_inherits) GETSTRUCT(tuple);
-
-		parent = new_objtree_for_qualname_id(RelationRelationId,
-											 formInh->inhparent);
-		parents = lappend(parents, new_object_object(parent));
-	}
-
-	systable_endscan(scan);
-	table_close(inhRel, RowExclusiveLock);
-
-	return parents;
-}
-
-/*
- * Deparse the ON COMMIT ... clause for CREATE ... TEMPORARY ...
- *
- * Verbose syntax
- * ON COMMIT %{on_commit_value}s
- */
-static ObjTree *
-deparse_OnCommitClause(OnCommitAction option)
-{
-	ObjTree    *ret  = new_objtree("ON COMMIT");
-	switch (option)
-	{
-		case ONCOMMIT_DROP:
-			append_string_object(ret, "%{on_commit_value}s",
-								 "on_commit_value", "DROP");
-			break;
-
-		case ONCOMMIT_DELETE_ROWS:
-			append_string_object(ret, "%{on_commit_value}s",
-								 "on_commit_value", "DELETE ROWS");
-			break;
-
-		case ONCOMMIT_PRESERVE_ROWS:
-			append_string_object(ret, "%{on_commit_value}s",
-								 "on_commit_value", "PRESERVE ROWS");
-			break;
-
-		case ONCOMMIT_NOOP:
-			append_not_present(ret, "%{on_commit_value}s");
-			break;
-	}
-
-	return ret;
-}
-
-/*
- * Deparse the sequence CACHE option.
- *
- * Verbose syntax
- * SET CACHE %{value}s
- * OR
- * CACHE %{value}
- */
-static inline ObjElem *
-deparse_Seq_Cache(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET CACHE %{value}s" : "CACHE %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "cache",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqcache));
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence CYCLE option.
- *
- * Verbose syntax
- * SET %{no}s CYCLE
- * OR
- * %{no}s CYCLE
- */
-static inline ObjElem *
-deparse_Seq_Cycle(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET %{no}s CYCLE" : "%{no}s CYCLE";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "cycle",
-						 "no", ObjTypeString,
-						 seqdata->seqcycle ? "" : "NO");
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence INCREMENT BY option.
- *
- * Verbose syntax
- * SET INCREMENT BY %{value}s
- * OR
- * INCREMENT BY %{value}s
- */
-static inline ObjElem *
-deparse_Seq_IncrementBy(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET INCREMENT BY %{value}s" : "INCREMENT BY %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "seqincrement",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqincrement));
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence MAXVALUE option.
- *
- * Verbose syntax
- * SET MAXVALUE %{value}s
- * OR
- * MAXVALUE %{value}s
- */
-static inline ObjElem *
-deparse_Seq_Maxvalue(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET MAXVALUE %{value}s" : "MAXVALUE %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "maxvalue",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqmax));
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence MINVALUE option.
- *
- * Verbose syntax
- * SET MINVALUE %{value}s
- * OR
- * MINVALUE %{value}s
- */
-static inline ObjElem *
-deparse_Seq_Minvalue(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET MINVALUE %{value}s" : "MINVALUE %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "minvalue",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqmin));
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence OWNED BY command.
- *
- * Verbose syntax
- * OWNED BY %{owner}D
- */
-static ObjElem *
-deparse_Seq_OwnedBy(Oid sequenceId, bool alter_table)
-{
-	ObjTree    *ret = NULL;
-	Relation	depRel;
-	SysScanDesc scan;
-	ScanKeyData keys[3];
-	HeapTuple	tuple;
-
-	depRel = table_open(DependRelationId, AccessShareLock);
-	ScanKeyInit(&keys[0],
-				Anum_pg_depend_classid,
-				BTEqualStrategyNumber, F_OIDEQ,
-				ObjectIdGetDatum(RelationRelationId));
-	ScanKeyInit(&keys[1],
-				Anum_pg_depend_objid,
-				BTEqualStrategyNumber, F_OIDEQ,
-				ObjectIdGetDatum(sequenceId));
-	ScanKeyInit(&keys[2],
-				Anum_pg_depend_objsubid,
-				BTEqualStrategyNumber, F_INT4EQ,
-				Int32GetDatum(0));
-
-	scan = systable_beginscan(depRel, DependDependerIndexId, true,
-							  NULL, 3, keys);
-	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
-	{
-		Oid			ownerId;
-		Form_pg_depend depform;
-		ObjTree    *tmp_obj;
-		char	   *colname;
-
-		depform = (Form_pg_depend) GETSTRUCT(tuple);
+		depform = (Form_pg_depend) GETSTRUCT(tuple);
 
 		/* Only consider AUTO dependencies on pg_class */
 		if (depform->deptype != DEPENDENCY_AUTO)
@@ -1691,51 +1171,6 @@ deparse_Seq_Startwith(Form_pg_sequence seqdata, bool alter_table)
 	return new_object_object(ret);
 }
 
-/*
- * Subroutine for CREATE TABLE deparsing.
- *
- * Deal with all the table elements (columns and constraints).
- *
- * Note we ignore constraints in the parse node here; they are extracted from
- * system catalogs instead.
- */
-static List *
-deparse_TableElements(Relation relation, List *tableElements, List *dpcontext,
-					  bool typed, bool composite)
-{
-	List	   *elements = NIL;
-	ListCell   *lc;
-
-	foreach(lc, tableElements)
-	{
-		Node	   *elt = (Node *) lfirst(lc);
-
-		switch (nodeTag(elt))
-		{
-			case T_ColumnDef:
-				{
-					ObjTree    *tree;
-
-					tree = typed ?
-						deparse_ColumnDef_typed(relation, dpcontext,
-												(ColumnDef *) elt) :
-						deparse_ColumnDef(relation, dpcontext,
-										  composite, (ColumnDef *) elt,
-										  false, NULL);
-					if (tree != NULL)
-						elements = lappend(elements, new_object_object(tree));
-				}
-				break;
-			case T_Constraint:
-				break;
-			default:
-				elog(ERROR, "invalid node type %d", nodeTag(elt));
-		}
-	}
-
-	return elements;
-}
-
 /*
  * Deparse a CreateSeqStmt.
  *
@@ -1800,1507 +1235,2854 @@ deparse_CreateSeqStmt(Oid objectId, Node *parsetree)
 }
 
 /*
- * Deparse a CreateStmt (CREATE TABLE).
- *
- * Given a table OID and the parse tree that created it, return an ObjTree
- * representing the creation command.
+ * Deparse CREATE TABLE AS command.
  *
- * Verbose syntax
- * CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D [OF
- * %{of_type}T | PARTITION OF %{parent_identity}D] %{table_elements}s
- * %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s
- * %{on_commit}s %{tablespace}s
+ * deparse_CreateStmt do the actual work as we deparse the final CreateStmt for
+ * CREATE TABLE AS command.
  */
-static ObjTree *
-deparse_CreateStmt(Oid objectId, Node *parsetree)
+static Jsonb *
+deparse_CreateTableAsStmt(CollectedCommand *cmd, ddl_deparse_context *context)
 {
-	CreateStmt *node = (CreateStmt *) parsetree;
-	Relation	relation = relation_open(objectId, AccessShareLock);
-	List	   *dpcontext;
-	ObjTree    *ret;
-	ObjTree    *tmp_obj;
-	List	   *list = NIL;
-	ListCell   *cell;
+	Oid			objectId;
+	Node	   *parsetree;
+	char	   *owner = context->include_owner ? cmd->role : NULL;
 
-	ret = new_objtree_VA("CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D", 3,
-						 "persistence", ObjTypeString,
-						 get_persistence_str(relation->rd_rel->relpersistence),
-						 "if_not_exists", ObjTypeString,
-						 node->if_not_exists ? "IF NOT EXISTS" : "",
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(relation->rd_rel->relnamespace,
-												  RelationGetRelationName(relation)));
+	Assert(cmd->type == SCT_CreateTableAs);
 
-	dpcontext = deparse_context_for(RelationGetRelationName(relation),
-									objectId);
+	parsetree = cmd->d.ctas.real_create;
+	objectId = cmd->d.ctas.address.objectId;
+	return deparse_CreateStmt(objectId, parsetree, owner);
+}
+
+/*
+ * Deparse an AlterObjectSchemaStmt (ALTER ... SET SCHEMA command)
+ *
+ * Given the object address and the parse tree that created it, return an
+ * ObjTree representing the alter command.
+ *
+ * Verbose syntax
+ * ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I
+ */
+static ObjTree *
+deparse_AlterObjectSchemaStmt(ObjectAddress address, Node *parsetree,
+							  ObjectAddress old_schema)
+{
+	AlterObjectSchemaStmt *node = (AlterObjectSchemaStmt *) parsetree;
+	char	   *identity;
+	char	   *new_schema = node->newschema;
+	char	   *old_schname;
+	char	   *ident;
 
 	/*
-	 * Typed tables and partitions use a slightly different format string: we
-	 * must not put table_elements with parents directly in the fmt string,
-	 * because if there are no options the parentheses must not be emitted;
-	 * and also, typed tables do not allow for inheritance.
+	 * Since the command has already taken place from the point of view of
+	 * catalogs, getObjectIdentity returns the object name with the already
+	 * changed schema.  The output of our deparsing must return the original
+	 * schema name, however, so we chop the schema name off the identity
+	 * string and then prepend the quoted schema name.
+	 *
+	 * XXX This is pretty clunky. Can we do better?
 	 */
-	if (node->ofTypename || node->partbound)
-	{
-		List	   *tableelts = NIL;
-
-		/*
-		 * We can't put table elements directly in the fmt string as an array
-		 * surrounded by parentheses here, because an empty clause would cause
-		 * a syntax error.  Therefore, we use an indirection element and set
-		 * present=false when there are no elements.
-		 */
-		if (node->ofTypename)
-		{
-			tmp_obj = new_objtree_for_type(relation->rd_rel->reloftype, -1);
-			append_object_object(ret, "OF %{of_type}T", tmp_obj);
-		}
-		else
-		{
-			List	   *parents;
-			ObjElem    *elem;
-
-			parents = deparse_InhRelations(objectId);
-			elem = (ObjElem *) linitial(parents);
-
-			Assert(list_length(parents) == 1);
-
-			append_format_string(ret, "PARTITION OF");
-
-			append_object_object(ret, "%{parent_identity}D",
-								 elem->value.object);
-		}
-
-		tableelts = deparse_TableElements(relation, node->tableElts, dpcontext,
-										  true, /* typed table */
-										  false);	/* not composite */
-		tableelts = obtainConstraints(tableelts, objectId);
-
-		tmp_obj = new_objtree("");
-		if (tableelts)
-			append_array_object(tmp_obj, "(%{elements:, }s)", tableelts);
-		else
-			append_not_present(tmp_obj, "(%{elements:, }s)");
-
-		append_object_object(ret, "%{table_elements}s", tmp_obj);
-	}
-	else
-	{
-		List	   *tableelts = NIL;
-
-		/*
-		 * There is no need to process LIKE clauses separately; they have
-		 * already been transformed into columns and constraints.
-		 */
-
-		/*
-		 * Process table elements: column definitions and constraints.  Only
-		 * the column definitions are obtained from the parse node itself.  To
-		 * get constraints we rely on pg_constraint, because the parse node
-		 * might be missing some things such as the name of the constraints.
-		 */
-		tableelts = deparse_TableElements(relation, node->tableElts, dpcontext,
-										  false,	/* not typed table */
-										  false);	/* not composite */
-		tableelts = obtainConstraints(tableelts, objectId);
-
-		if (tableelts)
-			append_array_object(ret, "(%{table_elements:, }s)", tableelts);
-		else
-			append_format_string(ret, "()");
-
-		/*
-		 * Add inheritance specification.  We cannot simply scan the list of
-		 * parents from the parser node, because that may lack the actual
-		 * qualified names of the parent relations.  Rather than trying to
-		 * re-resolve them from the information in the parse node, it seems
-		 * more accurate and convenient to grab it from pg_inherits.
-		 */
-		tmp_obj = new_objtree("INHERITS");
-		if (node->inhRelations != NIL)
-			append_array_object(tmp_obj, "(%{parents:, }D)",
-								deparse_InhRelations(objectId));
-		else
-			append_not_present(tmp_obj, "(%{parents:, }D)");
-
-		append_object_object(ret, "%{inherits}s", tmp_obj);
-	}
-
-	/* FOR VALUES clause */
-	if (node->partbound)
-	{
-		/*
-		 * Get pg_class.relpartbound. We cannot use partbound in the parsetree
-		 * directly as it's the original partbound expression which haven't
-		 * been transformed.
-		 */
-		append_string_object(ret, "%{partition_bound}s", "partition_bound",
-							 RelationGetPartitionBound(objectId));
-	}
-
-	/* PARTITION BY clause */
-	tmp_obj = new_objtree("PARTITION BY");
-	if (relation->rd_rel->relkind == RELKIND_PARTITIONED_TABLE)
-		append_string_object(tmp_obj, "%{definition}s", "definition",
-							 pg_get_partkeydef_string(objectId));
-	else
-		append_not_present(tmp_obj, "%{definition}s");
-
-	append_object_object(ret, "%{partition_by}s", tmp_obj);
-
-	/* USING clause */
-	tmp_obj = new_objtree("USING");
-	if (node->accessMethod)
-		append_string_object(tmp_obj, "%{access_method}I", "access_method",
-							 node->accessMethod);
-	else
-		append_not_present(tmp_obj, "%{access_method}I");
-
-	append_object_object(ret, "%{access_method}s", tmp_obj);
-
-	/* WITH clause */
-	tmp_obj = new_objtree("WITH");
-
-	foreach(cell, node->options)
-	{
-		ObjTree    *tmp_obj2;
-		DefElem    *opt = (DefElem *) lfirst(cell);
-
-		tmp_obj2 = deparse_DefElem(opt, false);
-		list = lappend(list, new_object_object(tmp_obj2));
-	}
-
-	if (list)
-		append_array_object(tmp_obj, "(%{with:, }s)", list);
-	else
-		append_not_present(tmp_obj, "(%{with:, }s)");
-
-	append_object_object(ret, "%{with_clause}s", tmp_obj);
-
-	append_object_object(ret, "%{on_commit}s",
-						 deparse_OnCommitClause(node->oncommit));
-
-	tmp_obj = new_objtree("TABLESPACE");
-	if (node->tablespacename)
-		append_string_object(tmp_obj, "%{tablespace}I", "tablespace",
-							 node->tablespacename);
-	else
-		append_not_present(tmp_obj, "%{tablespace}I");
-
-	append_object_object(ret, "%{tablespace}s", tmp_obj);
+	identity = getObjectIdentity(&address, false);
+	old_schname = get_namespace_name(old_schema.objectId);
+	if (!old_schname)
+		elog(ERROR, "cache lookup failed for schema with OID %u",
+			 old_schema.objectId);
 
-	relation_close(relation, AccessShareLock);
+	ident = psprintf("%s%s", quote_identifier(old_schname),
+					 identity + strlen(quote_identifier(new_schema)));
 
-	return ret;
+	return new_objtree_VA("ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I", 3,
+						  "objtype", ObjTypeString,
+						  stringify_objtype(node->objectType, false),
+						  "identity", ObjTypeString, ident,
+						  "newschema", ObjTypeString, new_schema);
 }
 
 /*
- * Deparse CREATE TABLE AS command.
+ * Deparse an AlterOwnerStmt (ALTER ... OWNER TO ...).
  *
- * deparse_CreateStmt do the actual work as we deparse the final CreateStmt for
- * CREATE TABLE AS command.
+ * Given the object address and the parse tree that created it, return an
+ * ObjTree representing the alter command.
+ *
+ * Verbose syntax
+ * ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I
  */
 static ObjTree *
-deparse_CreateTableAsStmt(CollectedCommand *cmd)
+deparse_AlterOwnerStmt(ObjectAddress address, Node *parsetree)
 {
-	Oid			objectId;
-	Node	   *parsetree;
-
-	Assert(cmd->type == SCT_CreateTableAs);
-
-	parsetree = cmd->d.ctas.real_create;
-	objectId = cmd->d.ctas.address.objectId;
+	AlterOwnerStmt *node = (AlterOwnerStmt *) parsetree;
 
-	return deparse_CreateStmt(objectId, parsetree);
+	return new_objtree_VA("ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I", 3,
+						  "objtype", ObjTypeString,
+						  stringify_objtype(node->objectType, false),
+						  "identity", ObjTypeString,
+						  getObjectIdentity(&address, false),
+						  "newowner", ObjTypeString,
+						  get_rolespec_name(node->newowner));
 }
 
 /*
- * Deparse all the collected subcommands and return an ObjTree representing the
- * alter command.
+ * Deparse an AlterSeqStmt.
+ *
+ * Given a sequence OID and a parse tree that modified it, return an ObjTree
+ * representing the alter command.
+ *
+ * Note: We need to deparse the ALTER SEQUENCE command for the TABLE commands.
+ * For example, When creating a table, if we specify a column as a sequence
+ * type, then we will create a sequence for that column and set that sequence
+ * OWNED BY the table.
  *
  * Verbose syntax
- * ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s
+ * ALTER SEQUENCE %{identity}D %{definition: }s
  */
 static ObjTree *
-deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
+deparse_AlterSeqStmt(Oid objectId, Node *parsetree)
 {
 	ObjTree    *ret;
-	ObjTree    *tmp_obj;
-	ObjTree    *tmp_obj2;
-	List	   *dpcontext;
-	Relation	rel;
-	List	   *subcmds = NIL;
+	Relation	relation;
+	List	   *elems = NIL;
 	ListCell   *cell;
-	const char *reltype;
-	Node	   *expr = NULL;
-	Oid			relId = cmd->d.alterTable.objectId;
-	AlterTableStmt *stmt = NULL;
-
-	Assert(cmd->type == SCT_AlterTable);
-	stmt = (AlterTableStmt *) cmd->parsetree;
-	Assert(IsA(stmt, AlterTableStmt));
+	Form_pg_sequence seqform;
+	Sequence_values *seqvalues;
+	AlterSeqStmt *alterSeqStmt = (AlterSeqStmt *) parsetree;
 
 	/*
-	 * ALTER TABLE subcommands generated for TableLikeClause is processed in
-	 * the top level CREATE TABLE command; return empty here.
+	 * Sequence for IDENTITY COLUMN output separately (via CREATE TABLE or
+	 * ALTER TABLE); return empty here.
 	 */
-	if (stmt->table_like)
+	if (alterSeqStmt->for_identity)
 		return NULL;
 
-	rel = relation_open(relId, AccessShareLock);
-
-	switch (rel->rd_rel->relkind)
-	{
-		case RELKIND_RELATION:
-		case RELKIND_PARTITIONED_TABLE:
-			reltype = "TABLE";
-			break;
-		case RELKIND_INDEX:
-		case RELKIND_PARTITIONED_INDEX:
-		case RELKIND_VIEW:
-		case RELKIND_COMPOSITE_TYPE:
-		case RELKIND_FOREIGN_TABLE:
-		case RELKIND_MATVIEW:
-			/* unsupported relkind */
-			table_close(rel, AccessShareLock);
-			return NULL;
-
-		default:
-			elog(ERROR, "unexpected relkind %d", rel->rd_rel->relkind);
-	}
-
-	dpcontext = deparse_context_for(RelationGetRelationName(rel),
-									relId);
-
-	ret = new_objtree_VA("ALTER %{objtype}s %{only}s %{identity}D", 3,
-						 "objtype", ObjTypeString, reltype,
-						 "only", ObjTypeString,
-						 stmt->relation->inh ? "" : "ONLY",
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(rel->rd_rel->relnamespace,
-												  RelationGetRelationName(rel)));
+	seqvalues = get_sequence_values(objectId);
+	seqform = seqvalues->seqform;
 
-	foreach(cell, cmd->d.alterTable.subcmds)
+	foreach(cell, ((AlterSeqStmt *) parsetree)->options)
 	{
-		CollectedATSubcmd *sub = (CollectedATSubcmd *) lfirst(cell);
-		AlterTableCmd *subcmd = (AlterTableCmd *) sub->parsetree;
-		ObjTree    *tree;
-
-		Assert(IsA(subcmd, AlterTableCmd));
-
-	   /*
-		* Skip deparse of the subcommand if the objectId doesn't match the
-		* target relation ID. It can happen for inherited tables when
-		* subcommands for inherited tables and the parent table are both
-		* collected in the ALTER TABLE command for the parent table.
-		*/
-		if (subcmd->subtype != AT_AttachPartition &&
-			sub->address.objectId != relId &&
-			has_superclass(sub->address.objectId))
-			continue;
+		DefElem    *elem = (DefElem *) lfirst(cell);
+		ObjElem    *newelm;
 
-		switch (subcmd->subtype)
+		if (strcmp(elem->defname, "cache") == 0)
+			newelm = deparse_Seq_Cache(seqform, false);
+		else if (strcmp(elem->defname, "cycle") == 0)
+			newelm = deparse_Seq_Cycle(seqform, false);
+		else if (strcmp(elem->defname, "increment") == 0)
+			newelm = deparse_Seq_IncrementBy(seqform, false);
+		else if (strcmp(elem->defname, "minvalue") == 0)
+			newelm = deparse_Seq_Minvalue(seqform, false);
+		else if (strcmp(elem->defname, "maxvalue") == 0)
+			newelm = deparse_Seq_Maxvalue(seqform, false);
+		else if (strcmp(elem->defname, "start") == 0)
+			newelm = deparse_Seq_Startwith(seqform, false);
+		else if (strcmp(elem->defname, "restart") == 0)
+			newelm = deparse_Seq_Restart(seqvalues->last_value);
+		else if (strcmp(elem->defname, "owned_by") == 0)
+			newelm = deparse_Seq_OwnedBy(objectId, false);
+		else if (strcmp(elem->defname, "as") == 0)
+			newelm = deparse_Seq_As(seqform);
+		else
+			elog(ERROR, "invalid sequence option %s", elem->defname);
+
+		elems = lappend(elems, newelm);
+	}
+
+	relation = relation_open(objectId, AccessShareLock);
+
+	ret = new_objtree_VA("ALTER SEQUENCE %{identity}D %{definition: }s", 2,
+						 "identity", ObjTypeObject,
+						 new_objtree_for_qualname(relation->rd_rel->relnamespace,
+												  RelationGetRelationName(relation)),
+						 "definition", ObjTypeArray, elems);
+
+	relation_close(relation, AccessShareLock);
+
+	return ret;
+}
+
+/*
+ * Deparse a RenameStmt.
+ *
+ * Verbose syntax
+ * ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I
+ * OR
+ * ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I
+ * OR
+ * ALTER %{objtype}s %{if_exists}s %{only}s %{identity}D RENAME COLUMN %{colname}I TO %{newname}I %{cascade}s
+ */
+static ObjTree *
+deparse_RenameStmt(ObjectAddress address, Node *parsetree)
+{
+	RenameStmt *node = (RenameStmt *) parsetree;
+	ObjTree    *ret;
+	Relation	relation;
+	Oid			schemaId;
+
+	/*
+	 * In an ALTER .. RENAME command, we don't have the original name of the
+	 * object in system catalogs: since we inspect them after the command has
+	 * executed, the old name is already gone.  Therefore, we extract it from
+	 * the parse node.  Note we still extract the schema name from the catalog
+	 * (it might not be present in the parse node); it cannot possibly have
+	 * changed anyway.
+	 */
+	switch (node->renameType)
+	{
+		case OBJECT_TABLE:
+			relation = relation_open(address.objectId, AccessShareLock);
+			schemaId = RelationGetNamespace(relation);
+			ret = new_objtree_VA("ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I", 4,
+								 "objtype", ObjTypeString,
+								 stringify_objtype(node->renameType, false),
+								 "if_exists", ObjTypeString,
+								 node->missing_ok ? "IF EXISTS" : "",
+								 "identity", ObjTypeObject,
+								 new_objtree_for_qualname(schemaId,
+														  node->relation->relname),
+								 "newname", ObjTypeString,
+								 node->newname);
+			relation_close(relation, AccessShareLock);
+			break;
+
+		case OBJECT_TABCONSTRAINT:
+			{
+				HeapTuple	constrtup;
+				Form_pg_constraint constform;
+
+				constrtup = SearchSysCache1(CONSTROID,
+											ObjectIdGetDatum(address.objectId));
+				if (!HeapTupleIsValid(constrtup))
+					elog(ERROR, "cache lookup failed for constraint with OID %u",
+						 address.objectId);
+				constform = (Form_pg_constraint) GETSTRUCT(constrtup);
+
+				ret = new_objtree_VA("ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I", 4,
+									"only",  ObjTypeString,
+									node->relation->inh ? "" : "ONLY",
+									"identity", ObjTypeObject,
+									new_objtree_for_qualname_id(RelationRelationId,
+																constform->conrelid),
+									"oldname", ObjTypeString, node->subname,
+									"newname", ObjTypeString, node->newname);
+				ReleaseSysCache(constrtup);
+			}
+			break;
+
+		case OBJECT_COLUMN:
+			relation = relation_open(address.objectId, AccessShareLock);
+			schemaId = RelationGetNamespace(relation);
+
+			ret = new_objtree_VA("ALTER %{objtype}s", 1,
+								 "objtype", ObjTypeString,
+								 stringify_objtype(node->relationType, false));
+
+			/* Composite types do not support IF EXISTS */
+			if (node->renameType == OBJECT_COLUMN)
+				append_string_object(ret, "%{if_exists}s",
+									 "if_exists",
+									 node->missing_ok ? "IF EXISTS" : "");
+			if (!node->relation->inh)
+				append_string_object(ret, "%{only}s",
+									 "only",
+									 "ONLY");
+			append_object_object(ret, "%{identity}D",
+								 new_objtree_for_qualname(schemaId,
+														  node->relation->relname));
+			append_string_object(ret, "RENAME COLUMN %{colname}I",
+								 "colname", node->subname);
+
+			append_string_object(ret, "TO %{newname}I", "newname",
+								 node->newname);
+
+			if (node->renameType == OBJECT_ATTRIBUTE)
+			{
+				ObjTree	   *tmp_obj = new_objtree("CASCADE");
+
+				if (node->behavior != DROP_CASCADE)
+					append_not_present(tmp_obj, NULL);
+				append_object_object(ret, "%{cascade}s", tmp_obj);
+			}
+
+			relation_close(relation, AccessShareLock);
+			break;
+
+		default:
+			elog(ERROR, "unsupported object type %d", node->renameType);
+	}
+
+	return ret;
+}
+
+/*
+ * Handle deparsing of simple commands.
+ *
+ * This function should cover all cases handled in ProcessUtilitySlow.
+ */
+static ObjTree *
+deparse_simple_command(CollectedCommand *cmd, ddl_deparse_context *context)
+{
+	Oid			objectId;
+	Node	   *parsetree;
+
+	Assert(cmd->type == SCT_Simple);
+
+	parsetree = cmd->parsetree;
+	objectId = cmd->d.simple.address.objectId;
+
+	if (cmd->in_extension && (nodeTag(parsetree) != T_CreateExtensionStmt))
+		return NULL;
+
+	/* This switch needs to handle everything that ProcessUtilitySlow does */
+	switch (nodeTag(parsetree))
+	{
+		case T_AlterObjectSchemaStmt:
+			context->include_owner = false;
+			return deparse_AlterObjectSchemaStmt(cmd->d.simple.address,
+												 parsetree,
+												 cmd->d.simple.secondaryObject);
+
+		case T_AlterOwnerStmt:
+			context->include_owner = false;
+			return deparse_AlterOwnerStmt(cmd->d.simple.address, parsetree);
+
+		case T_AlterSeqStmt:
+			return deparse_AlterSeqStmt(objectId, parsetree);
+
+		case T_CreateSeqStmt:
+			return deparse_CreateSeqStmt(objectId, parsetree);
+
+		case T_CreateStmt:
+			{
+				char	   *owner = context->include_owner ? cmd->role : NULL;
+
+				/*
+				 * get direct jsonb from parsetree and typecast to ObjTree* for the
+				 * time being to satisfy the prototype.
+				 */
+				return (ObjTree *) deparse_CreateStmt(objectId, parsetree, owner);
+			}
+		case T_RenameStmt:
+			context->include_owner = false;
+			return deparse_RenameStmt(cmd->d.simple.address, parsetree);
+
+		default:
+			elog(LOG, "unrecognized node type in deparse command: %d",
+				 (int) nodeTag(parsetree));
+	}
+
+	return NULL;
+}
+
+/*
+ * Workhorse to deparse a CollectedCommand.
+ */
+char *
+deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context)
+{
+	OverrideSearchPath *overridePath;
+	MemoryContext oldcxt;
+	MemoryContext tmpcxt;
+	ObjTree    *tree;
+	char	   *command = NULL;
+	StringInfoData str;
+
+	/*
+	 * Allocate everything done by the deparsing routines into a temp context,
+	 * to avoid having to sprinkle them with memory handling code, but
+	 * allocate the output StringInfo before switching.
+	 */
+	initStringInfo(&str);
+	tmpcxt = AllocSetContextCreate(CurrentMemoryContext,
+								   "deparse ctx",
+								   ALLOCSET_DEFAULT_MINSIZE,
+								   ALLOCSET_DEFAULT_INITSIZE,
+								   ALLOCSET_DEFAULT_MAXSIZE);
+	oldcxt = MemoryContextSwitchTo(tmpcxt);
+
+	/*
+	 * Many routines underlying this one will invoke ruleutils.c functionality
+	 * to obtain deparsed versions of expressions.  In such results, we want
+	 * all object names to be qualified, so that results are "portable" to
+	 * environments with different search_path settings.  Rather than
+	 * injecting what would be repetitive calls to override search path all
+	 * over the place, we do it centrally here.
+	 */
+	overridePath = GetOverrideSearchPath(CurrentMemoryContext);
+	overridePath->schemas = NIL;
+	overridePath->addCatalog = false;
+	overridePath->addTemp = true;
+	PushOverrideSearchPath(overridePath);
+
+	verbose = context->verbose_mode;
+
+	switch (cmd->type)
+	{
+		case SCT_Simple:
+			tree = deparse_simple_command(cmd, context);
+			break;
+		case SCT_AlterTable:
+			 /* typecast to ObjTree* for the time being to satisfy the prototype. */
+			tree = (ObjTree *)deparse_alter_table(cmd, context);
+			context->include_owner = false;
+			break;
+		case SCT_CreateTableAs:
+			 /* typecast to ObjTree* for the time being to satisfy the prototype. */
+			tree = (ObjTree *)deparse_CreateTableAsStmt(cmd, context);
+			break;
+		default:
+			elog(ERROR, "unexpected deparse node type %d", cmd->type);
+	}
+
+	PopOverrideSearchPath();
+
+	if (tree)
+	{
+		Jsonb	   *jsonb;
+
+		if ((nodeTag(cmd->parsetree) == T_CreateStmt) ||
+			(nodeTag(cmd->parsetree) == T_CreateTableAsStmt) ||
+			(nodeTag(cmd->parsetree) == T_AlterTableStmt))
+		{
+			/* no object tree as intermediate stage for Create-Table */
+			jsonb = (Jsonb *) tree;
+			command = JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
+		}
+		else
+		{
+			jsonb = context->include_owner ? objtree_to_jsonb(tree, cmd->role) :
+										 objtree_to_jsonb(tree, NULL);
+			command = JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
+		}
+	}
+
+	/*
+	 * Clean up.  Note that since we created the StringInfo in the caller's
+	 * context, the output string is not deleted here.
+	 */
+	MemoryContextSwitchTo(oldcxt);
+	MemoryContextDelete(tmpcxt);
+
+	return command;
+}
+
+/*
+ * Given a CollectedCommand, return a JSON representation of it.
+ *
+ * The command is expanded fully so that there are no ambiguities even in the
+ * face of search_path changes.
+ */
+Datum
+ddl_deparse_to_json(PG_FUNCTION_ARGS)
+{
+	CollectedCommand *cmd = (CollectedCommand *) PG_GETARG_POINTER(0);
+	char	   *command;
+	ddl_deparse_context context;
+
+	context.verbose_mode = true;
+	context.include_owner = false;
+	context.func_volatile = PROVOLATILE_IMMUTABLE;
+
+	command = deparse_utility_command(cmd, &context);
+
+	if (command)
+		PG_RETURN_TEXT_P(cstring_to_text(command));
+
+	PG_RETURN_NULL();
+}
+
+/*
+ * Insert JsonbValue key to JsonbParseState
+ */
+static void
+insert_jsonb_key(JsonbParseState *state, char *name)
+{
+	JsonbValue	key;
+
+	/* Push the key */
+	key.type = jbvString;
+	key.val.string.val = name;
+	key.val.string.len = strlen(name);
+	pushJsonbValue(&state, WJB_KEY, &key);
+}
+
+/*
+ * Insert JsonbValue key:value pair to JsonbParseState, the
+ * value here is of type jbvString.
+ */
+static void
+insert_jsonb_str_element(JsonbParseState *state, char *name, const char *value)
+{
+	JsonbValue	val;
+
+	/* Push the key first */
+	insert_jsonb_key(state, name);
+
+	/* Push the value now */
+	val.type = jbvString;
+	val.val.string.len = strlen(value);
+	val.val.string.val = pstrdup(value);
+	pushJsonbValue(&state, WJB_VALUE, &val);
+}
+
+/*
+ * Insert JsonbValue key:value pair to JsonbParseState, the
+ * value here is of type jbvBool.
+ */
+static void
+insert_jsonb_bool_element(JsonbParseState *state, char *name, bool value)
+{
+	JsonbValue	val;
+
+	/* Push the key first */
+	insert_jsonb_key(state, name);
+
+	/* Push the value now */
+	val.type = jbvBool;
+	val.val.boolean = value;
+	pushJsonbValue(&state, WJB_VALUE, &val);
+}
+
+/*
+ * Insert JsonbValue key:value pair to JsonbParseState, the
+ * value here is of type jbvNumeric.
+ */
+static void
+insert_jsonb_numeric_element(JsonbParseState *state, char *name, int value)
+{
+	JsonbValue	val;
+
+	/* Push the key first */
+	insert_jsonb_key(state, name);
+
+	/* Push the value now */
+	val.type = jbvNumeric;
+	val.val.numeric = int64_to_numeric(value);
+	pushJsonbValue(&state, WJB_VALUE, &val);
+}
+
+/*
+ * Insert JsonbValue key and the jsonb array to JsonbParseState
+ */
+static void
+insert_jsonb_array_oid(JsonbParseState *state, char *keyname, List *array)
+{
+	ListCell   *lc;
+
+	/* Push the key first */
+	insert_jsonb_key(state, keyname);
+
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+	/* Push the array elements now */
+	foreach(lc, array)
+		new_jsonb_for_qualname_id(state, RelationRelationId, lfirst_oid(lc),
+								  NULL);
+
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+}
+
+/*
+ * Insert new Object with one key:value pair to JsonbParseState, the
+ * value here is of jbvString.
+ */
+static void
+insert_str_object(JsonbParseState *state, char *fmt, char *keynm, char *keyval)
+{
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	fmt_to_jsonb_element(state, fmt);
+
+	/* push key-value pair */
+	insert_jsonb_str_element(state, keynm, keyval);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+
+/*
+ * Insert new object with present:false as key-value pair
+ * to JsonbParseState
+ */
+static void
+insert_not_present_obj(JsonbParseState *state, char *fmt)
+{
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	fmt_to_jsonb_element(state, fmt);
+
+	/* push key-value pair */
+	insert_jsonb_bool_element(state, "present", false);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Insert the format string into the output parse state.
+ */
+static void
+fmt_to_jsonb_element(JsonbParseState *state, char *fmtStr)
+{
+	Assert(fmtStr);
+	insert_jsonb_str_element(state, "fmt", fmtStr);
+}
+
+/*
+ * A helper routine to insert jsonb for coltyp to JsonbParseState
+ */
+static void
+new_jsonb_for_type(JsonbParseState *state, Oid typeId, int32 typmod)
+{
+	Oid			typnspid;
+	char	   *type_nsp;
+	char	   *type_name = NULL;
+	char	   *typmodstr;
+	bool		type_array;
+
+	format_type_detailed(typeId, typmod,
+						 &typnspid, &type_name, &typmodstr, &type_array);
+
+	if (OidIsValid(typnspid))
+		type_nsp = get_namespace_name_or_temp(typnspid);
+	else
+		type_nsp = pstrdup("");
+
+	new_jsonb_VA(state, NULL, false, 4,
+						"schemaname", jbvString, type_nsp,
+						"typename", jbvString, type_name,
+						"typmod", jbvString, typmodstr,
+						"typarray", jbvBool, type_array);
+
+}
+
+/*
+ * A helper routine to set up name: schemaname, objname
+ *
+ * Elements "schema_name" and "obj_name" are set.  If the namespace OID
+ * corresponds to a temp schema, that's set to "pg_temp".
+ *
+ * The difference between those two element types is whether the obj_name will
+ * be quoted as an identifier or not, which is not something that this routine
+ * concerns itself with; that will be up to the expand function.
+ */
+static void
+new_jsonb_for_qualname(JsonbParseState *state, Oid nspid, char *objName, char *keyName)
+{
+	char	   *namespace;
+
+	if (isAnyTempNamespace(nspid))
+		namespace = pstrdup("pg_temp");
+	else
+		namespace = get_namespace_name(nspid);
+
+	/* Push the key first */
+	if (keyName)
+		insert_jsonb_key(state, keyName);
+
+	new_jsonb_VA(state, NULL, false, 2,
+					"schemaname", jbvString, namespace,
+					"objname", jbvString, objName);
+}
+
+/*
+ * A helper routine to set up name: 'schemaname, objname' where the object is
+ * specified by classId and objId.
+ */
+static void
+new_jsonb_for_qualname_id(JsonbParseState *state, Oid classId, Oid objectId, char *keyName)
+{
+	Relation	catalog;
+	HeapTuple	catobj;
+	Datum		obj_nsp;
+	Datum		obj_name;
+	AttrNumber	Anum_name;
+	AttrNumber	Anum_namespace;
+	AttrNumber	Anum_oid = get_object_attnum_oid(classId);
+	bool		isnull;
+
+	catalog = table_open(classId, AccessShareLock);
+
+	catobj = get_catalog_object_by_oid(catalog, Anum_oid, objectId);
+	if (!catobj)
+		elog(ERROR, "cache lookup failed for object with OID %u of catalog \"%s\"",
+			 objectId, RelationGetRelationName(catalog));
+	Anum_name = get_object_attnum_name(classId);
+	Anum_namespace = get_object_attnum_namespace(classId);
+
+	obj_nsp = heap_getattr(catobj, Anum_namespace, RelationGetDescr(catalog),
+						   &isnull);
+	if (isnull)
+		elog(ERROR, "null namespace for object %u", objectId);
+
+	obj_name = heap_getattr(catobj, Anum_name, RelationGetDescr(catalog),
+							&isnull);
+	if (isnull)
+		elog(ERROR, "null attribute name for object %u", objectId);
+
+	new_jsonb_for_qualname(state, DatumGetObjectId(obj_nsp),
+						   NameStr(*DatumGetName(obj_name)), keyName);
+	table_close(catalog, AccessShareLock);
+}
+
+/*
+ * A helper function to insert collate object for column definition
+ */
+static void
+insert_collate_object(JsonbParseState *state, char *fmt, Oid classId, Oid objectId, char *key)
+{
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	fmt_to_jsonb_element(state, fmt);
+
+	/* push object now */
+	new_jsonb_for_qualname_id(state, classId, objectId, key);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * A helper function to insert identity object for the table definition
+ */
+static void
+insert_identity_object(JsonbParseState *state, Oid nspid, char *relname)
+{
+	char	   *namespace;
+
+	if (isAnyTempNamespace(nspid))
+		namespace = pstrdup("pg_temp");
+	else
+		namespace = get_namespace_name(nspid);
+
+	/* Push the key first */
+	insert_jsonb_key(state, "identity");
+
+	/* create object now for its value */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* identity object will have 2 elements */
+	insert_jsonb_str_element(state, "schemaname", namespace);
+	insert_jsonb_str_element(state, "objname", relname);
+
+	/* mark end of object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence CACHE option to Jsonb
+ *
+ * Verbose syntax
+ * SET CACHE %{value}s
+ * OR
+ * CACHE %{value}
+ */
+static inline void
+deparse_Seq_Cache_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
+
+	fmt = alter_table ? "SET CACHE %{value}s" : "CACHE %{value}s";
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	insert_jsonb_str_element(state, "clause", "cache");
+	insert_jsonb_str_element(state, "value", psprintf(INT64_FORMAT, seqdata->seqcache));
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence CYCLE option to Jsonb.
+ *
+ * Verbose syntax
+ * SET %{no}s CYCLE
+ * OR
+ * %{no}s CYCLE
+ */
+static inline void
+deparse_Seq_Cycle_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
+
+	fmt = alter_table ? "SET %{no}s CYCLE" : "%{no}s CYCLE";
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	insert_jsonb_str_element(state, "clause", "cycle");
+	insert_jsonb_str_element(state, "no", seqdata->seqcycle ? "" : "NO");
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence INCREMENT BY option to Jsonb
+ *
+ * Verbose syntax
+ * SET INCREMENT BY %{value}s
+ * OR
+ * INCREMENT BY %{value}s
+ */
+static inline void
+deparse_Seq_IncrementBy_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
+
+	fmt = alter_table ? "SET INCREMENT BY %{value}s" : "INCREMENT BY %{value}s";
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	insert_jsonb_str_element(state, "clause", "seqincrement");
+	insert_jsonb_str_element(state, "value", psprintf(INT64_FORMAT, seqdata->seqincrement));
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence MAXVALUE option to Jsonb.
+ *
+ * Verbose syntax
+ * SET MAXVALUE %{value}s
+ * OR
+ * MAXVALUE %{value}s
+ */
+static inline void
+deparse_Seq_Maxvalue_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
+
+	fmt = alter_table ? "SET MAXVALUE %{value}s" : "MAXVALUE %{value}s";
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	insert_jsonb_str_element(state, "clause", "maxvalue");
+	insert_jsonb_str_element(state, "value", psprintf(INT64_FORMAT, seqdata->seqmax));
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence MINVALUE option to Jsonb
+ *
+ * Verbose syntax
+ * SET MINVALUE %{value}s
+ * OR
+ * MINVALUE %{value}s
+ */
+static inline void
+deparse_Seq_Minvalue_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
+
+	fmt = alter_table ? "SET MINVALUE %{value}s" : "MINVALUE %{value}s";
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	insert_jsonb_str_element(state, "clause", "minvalue");
+	insert_jsonb_str_element(state, "value", psprintf(INT64_FORMAT, seqdata->seqmin));
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence START WITH option to Jsonb.
+ *
+ * Verbose syntax
+ * SET START WITH %{value}s
+ * OR
+ * START WITH %{value}s
+ */
+static inline void
+deparse_Seq_Startwith_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
+
+	fmt = alter_table ? "SET START WITH %{value}s" : "START WITH %{value}s";
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	insert_jsonb_str_element(state, "clause", "start");
+	insert_jsonb_str_element(state, "value", psprintf(INT64_FORMAT, seqdata->seqstart));
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse the sequence RESTART option to Jsonb
+ *
+ * Verbose syntax
+ * RESTART %{value}s
+ */
+static inline void
+deparse_Seq_Restart_toJsonb(JsonbParseState *state, int64 last_value)
+{
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, "RESTART %{value}s");
+
+	insert_jsonb_str_element(state, "clause", "restart");
+	insert_jsonb_str_element(state, "value", psprintf(INT64_FORMAT, last_value));
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+
+/*
+ * Deparse the definition of column identity to Jsonb.
+ *
+ * Verbose syntax
+ * SET GENERATED %{option}s %{identity_type}s %{seq_definition: }s
+ * 	OR
+ * GENERATED %{option}s AS IDENTITY %{identity_type}s ( %{seq_definition: }s )
+ */
+static void
+deparse_ColumnIdentity_toJsonb(JsonbParseState *state, Oid seqrelid, char identity, bool alter_table)
+{
+	Form_pg_sequence seqform;
+	Sequence_values *seqvalues;
+	char	   *fmt;
+
+	if (alter_table)
+		fmt = "%{identity_type}s %{seq_definition: }s";
+	else
+		fmt = "%{identity_type}s ( %{seq_definition: }s )";
+
+	/* create object now for value of identity_column */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
+
+	/* identity_type object creation */
+	{
+		char	   *identfmt;
+
+		/* Push the key first */
+		insert_jsonb_key(state, "identity_type");
+
+		if (alter_table)
+			identfmt = "SET GENERATED %{option}s";
+		else
+			identfmt = "GENERATED %{option}s AS IDENTITY";
+
+		if (identity == ATTRIBUTE_IDENTITY_ALWAYS)
+			insert_str_object(state, identfmt, "option", "ALWAYS");
+		else if (identity == ATTRIBUTE_IDENTITY_BY_DEFAULT)
+			insert_str_object(state, identfmt, "option", "BY DEFAULT");
+		else
+			insert_not_present_obj(state, verbose ? identfmt : (alter_table ? "SET GENERATED " : "GENERATED "));
+	}
+
+	/* seq_definition array object creation */
+	{
+
+		/* Push the key first */
+		insert_jsonb_key(state, "seq_definition");
+
+		pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+		seqvalues = get_sequence_values(seqrelid);
+		seqform = seqvalues->seqform;
+
+		/* Definition elements */
+		deparse_Seq_Cache_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Cycle_toJsonb(state, seqform, alter_table);
+		deparse_Seq_IncrementBy_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Minvalue_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Maxvalue_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Startwith_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Restart_toJsonb(state, seqvalues->last_value);
+		/* We purposefully do not emit OWNED BY here */
+
+		pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+	}
+
+	/* end of idendity_column object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+
+/*
+ * Deparse a ColumnDef node within a regular (non-typed) table creation.
+ *
+ * NOT NULL constraints in the column definition are emitted directly in the
+ * column definition by this routine; other constraints must be emitted
+ * elsewhere (the info in the parse node is incomplete anyway).
+ *
+ * Verbose syntax
+ * "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s
+ *  %{not_null}s %{default}s %{identity_column}s %{generated_column}s"
+ */
+static void
+deparse_ColumnDef_toJsonb(JsonbParseState *state, Relation relation,
+						  List *dpcontext, bool composite, ColumnDef *coldef,
+						  bool is_alter, Node **expr)
+{
+	Oid			relid = RelationGetRelid(relation);
+	HeapTuple	attrTup;
+	Form_pg_attribute attrForm;
+	Oid			typid;
+	int32		typmod;
+	Oid			typcollation;
+	char	   *fmtStr = "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s "
+		"%{not_null}s %{default}s %{identity_column}s %{generated_column}s";
+	bool		saw_notnull;
+	ListCell   *cell;
+
+	/*
+	 * Inherited columns without local definitions must not be emitted.
+	 *
+	 * XXX maybe it is useful to have them with "present = false" or some
+	 * such?
+	 */
+	if (!coldef->is_local)
+		return;
+
+	attrTup = SearchSysCacheAttName(relid, coldef->colname);
+	if (!HeapTupleIsValid(attrTup))
+		elog(ERROR, "could not find cache entry for column \"%s\" of relation %u",
+			 coldef->colname, relid);
+	attrForm = (Form_pg_attribute) GETSTRUCT(attrTup);
+
+	get_atttypetypmodcoll(relid, attrForm->attnum,
+						  &typid, &typmod, &typcollation);
+
+	/* start making column object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmtStr);
+
+	/* creat name and type elements for column */
+	insert_jsonb_str_element(state, "name", coldef->colname);
+	insert_jsonb_str_element(state, "type", "column");
+
+	/*
+	 * create coltype object having 4 elements: schemaname, typename, typemod,
+	 * typearray
+	 */
+	{
+		/* Push the key first */
+		insert_jsonb_key(state, "coltype");
+
+		/* Push the value */
+		new_jsonb_for_type(state, typid, typmod);
+	}
+
+	/* STORAGE clause */
+	if (!composite)
+		insert_jsonb_str_element(state, "colstorage", storage_name(attrForm->attstorage));
+
+	/* COMPRESSION clause */
+	{
+		/* Push the key first */
+		insert_jsonb_key(state, "compression");
+
+		/* Push the value now: object in this case */
+		if (coldef->compression)
+			insert_str_object(state, "COMPRESSION %{compression_method}I",
+							  "compression_method", coldef->compression);
+		else
+			insert_not_present_obj(state, verbose ? "COMPRESSION %{compression_method}I" : "COMPRESSION");
+	}
+
+	/* COLLATE clause */
+	{
+		/* Push the key first */
+		insert_jsonb_key(state, "collation");
+
+		if (OidIsValid(typcollation))
+			insert_collate_object(state, "COLLATE %{collation_name}D",
+								  CollationRelationId, typcollation,
+								  "collation_name");
+		else
+			insert_not_present_obj(state, verbose ? "COLLATE %{collation_name}D" : "COLLATE");
+	}
+
+	if (!composite)
+	{
+		Oid			seqrelid = InvalidOid;
+
+		/*
+		 * Emit a NOT NULL declaration if necessary.  Note that we cannot
+		 * trust pg_attribute.attnotnull here, because that bit is also set
+		 * when primary keys are specified; we must not emit a NOT NULL
+		 * constraint in that case, unless explicitly specified.  Therefore,
+		 * we scan the list of constraints attached to this column to
+		 * determine whether we need to emit anything. (Fortunately, NOT NULL
+		 * constraints cannot be table constraints.)
+		 *
+		 * In the ALTER TABLE cases, we also add a NOT NULL if the colDef is
+		 * marked is_not_null.
+		 */
+		saw_notnull = false;
+		foreach(cell, coldef->constraints)
+		{
+			Constraint *constr = (Constraint *) lfirst(cell);
+
+			if (constr->contype == CONSTR_NOTNULL)
+			{
+				saw_notnull = true;
+				break;
+			}
+		}
+
+		if (is_alter && coldef->is_not_null)
+			saw_notnull = true;
+
+		/* NOT NULL */
+		insert_jsonb_str_element(state, "not_null", saw_notnull ? "NOT NULL" : "");
+
+		/* DEFAULT: Push the key first */
+		insert_jsonb_key(state, "default");
+
+		/* DEFAULT: Push the value now */
+		if (attrForm->atthasdef &&
+			coldef->generated != ATTRIBUTE_GENERATED_STORED)
+		{
+			char	   *defstr;
+
+			defstr = RelationGetColumnDefault(relation, attrForm->attnum,
+											  dpcontext, expr);
+
+			insert_str_object(state, "DEFAULT %{default}s", "default", defstr);
+		}
+		else
+			insert_not_present_obj(state, verbose ? "DEFAULT %{default}s" : "DEFAULT");
+
+
+		/* IDENTITY COLUMN */
+		if (coldef->identity)
+		{
+			/*
+			 * For identity column, find the sequence owned by column in order
+			 * to deparse the column definition.
+			 */
+			seqrelid = getIdentitySequence(relid, attrForm->attnum, true);
+			if (OidIsValid(seqrelid) && coldef->identitySequence)
+				seqrelid = RangeVarGetRelid(coldef->identitySequence, NoLock, false);
+		}
+
+		/* IDENTITY COLUMN: Push the key first */
+		insert_jsonb_key(state, "identity_column");
+
+		/* IDENTITY COLUMN: Push the value now */
+		if (OidIsValid(seqrelid))
+		{
+
+			deparse_ColumnIdentity_toJsonb(state, seqrelid, coldef->identity, is_alter);
+		}
+		else
+			insert_not_present_obj(state, verbose ? "%{identity_column}s" : "");
+
+		/* GENERATED COLUMN EXPRESSION: Push the key first */
+		insert_jsonb_key(state, "generated_column");
+
+		/* GENERATED COLUMN EXPRESSION: Push the value now */
+		if (coldef->generated == ATTRIBUTE_GENERATED_STORED)
+		{
+			char	   *defstr;
+
+			defstr = RelationGetColumnDefault(relation, attrForm->attnum,
+											  dpcontext, expr);
+			insert_str_object(state, "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr", defstr);
+		}
+		else
+			insert_not_present_obj(state, verbose ? "GENERATED ALWAYS AS (%{generation_expr}s) STORED" : "GENERATED ALWAYS AS");
+	}
+	ReleaseSysCache(attrTup);
+
+	/* mark the end of one column object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Helper for deparse_ColumnDef_typed_toJsonb()
+ *
+ * Returns true if we need to deparse a ColumnDef node within a typed
+ * table creation.
+ */
+static bool
+deparse_ColDef_typed_needed(Relation relation, ColumnDef *coldef,
+						 Form_pg_attribute *atFormOut, bool *notnull)
+{
+	Oid			relid = RelationGetRelid(relation);
+	HeapTuple	attrTup;
+	Form_pg_attribute attrForm;
+	Oid			typid;
+	int32		typmod;
+	Oid			typcollation;
+	bool		saw_notnull;
+	ListCell   *cell;
+
+	attrTup = SearchSysCacheAttName(relid, coldef->colname);
+	if (!HeapTupleIsValid(attrTup))
+		elog(ERROR, "could not find cache entry for column \"%s\" of relation %u",
+			 coldef->colname, relid);
+
+	attrForm = (Form_pg_attribute) GETSTRUCT(attrTup);
+
+	if (atFormOut)
+		*atFormOut = attrForm;
+
+	get_atttypetypmodcoll(relid, attrForm->attnum,
+						  &typid, &typmod, &typcollation);
+
+	/*
+	 * Search for a NOT NULL declaration. As in deparse_ColumnDef, we rely on
+	 * finding a constraint on the column rather than coldef->is_not_null.
+	 * (This routine is never used for ALTER cases.)
+	 */
+	saw_notnull = false;
+	foreach(cell, coldef->constraints)
+	{
+		Constraint *constr = (Constraint *) lfirst(cell);
+
+		if (constr->contype == CONSTR_NOTNULL)
+		{
+			saw_notnull = true;
+			break;
+		}
+	}
+
+	if (notnull)
+		*notnull = saw_notnull;
+
+	if (!saw_notnull && !attrForm->atthasdef)
+	{
+		ReleaseSysCache(attrTup);
+		return false;
+	}
+
+	ReleaseSysCache(attrTup);
+	return true;
+}
+
+/*
+ * Deparse a ColumnDef node within a typed table creation. This is simpler
+ * than the regular case, because we don't have to emit the type declaration,
+ * collation, or default. Here we only return something if the column is being
+ * declared NOT NULL.
+ *
+ * As in deparse_ColumnDef, any other constraint is processed elsewhere.
+ *
+ * Verbose syntax
+ * %{name}I WITH OPTIONS %{not_null}s %{default}s.
+ */
+static void
+deparse_ColumnDef_typed_toJsonb(JsonbParseState *state, Relation relation,
+								List *dpcontext, ColumnDef *coldef)
+{
+	char	   *fmtStr = "%{name}I WITH OPTIONS %{not_null}s %{default}s";
+	bool		needed;
+	Form_pg_attribute attrForm;
+	bool		saw_notnull;
+
+	needed = deparse_ColDef_typed_needed(relation, coldef, &attrForm, &saw_notnull);
+	if (!needed)
+		return;
+
+	/* start making column object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmtStr);
+
+	/* Insert TYPE, NAME and NOT_NULL elements */
+	insert_jsonb_str_element(state, "type", "column");
+	insert_jsonb_str_element(state, "name", coldef->colname);
+	insert_jsonb_str_element(state, "not_null", saw_notnull ? "NOT NULL" : "");
+
+	/* DEFAULT: Push the key first */
+	insert_jsonb_key(state, "default");
+
+	/* DEFAULT: Push the value now */
+	if (attrForm->atthasdef)
+	{
+		char	   *defstr;
+
+		defstr = RelationGetColumnDefault(relation, attrForm->attnum,
+										  dpcontext, NULL);
+		insert_str_object(state, "DEFAULT %{default}s", "default", defstr);
+	}
+	else
+		insert_not_present_obj(state, verbose ? "DEFAULT %{default}s" : "DEFAULT");
+
+	/* mark the end of column object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+	/* Generated columns are not supported on typed tables, so we are done */
+
+}
+
+/*
+ * Subroutine for CREATE TABLE deparsing.
+ *
+ * Returns true if at-least one local column is present
+ * (i.e. not inherited).
+ */
+static bool
+table_elem_present_col(Relation relation, List *tableElements, bool typed)
+{
+	ListCell   *lc;
+
+	foreach(lc, tableElements)
+	{
+		Node	   *elt = (Node *) lfirst(lc);
+
+		switch (nodeTag(elt))
+		{
+			case T_ColumnDef:
+				{
+					if (typed)
+					{
+						if (deparse_ColDef_typed_needed(relation,
+													 ((ColumnDef *) elt), NULL, NULL))
+							return true;
+					}
+					else
+					{
+						if (((ColumnDef *) elt)->is_local)
+							return true;
+					}
+				}
+				break;
+			case T_Constraint:
+				break;
+			default:
+				elog(ERROR, "invalid node type %d", nodeTag(elt));
+		}
+	}
+
+	return false;
+}
+
+
+/*
+ * Subroutine for CREATE TABLE deparsing.
+ *
+ * Returns true if at-least one constraint is present.
+ *
+ * Note that CONSTRAINT_FOREIGN constraints are always ignored.
+ */
+static bool
+table_elem_present_const(Oid relationId)
+{
+	Relation	conRel;
+	ScanKeyData key;
+	SysScanDesc scan;
+	HeapTuple	tuple;
+	bool		bconst = false;
+
+	Assert(OidIsValid(relationId));
+
+	/*
+	 * Scan pg_constraint to fetch all constraints linked to the given
+	 * relation.
+	 */
+	conRel = table_open(ConstraintRelationId, AccessShareLock);
+	ScanKeyInit(&key, Anum_pg_constraint_conrelid, BTEqualStrategyNumber,
+				F_OIDEQ, ObjectIdGetDatum(relationId));
+	scan = systable_beginscan(conRel, ConstraintRelidTypidNameIndexId, true,
+							  NULL, 1, &key);
+
+	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
+	{
+		Form_pg_constraint constrForm;
+
+		constrForm = (Form_pg_constraint) GETSTRUCT(tuple);
+
+		switch (constrForm->contype)
+		{
+			case CONSTRAINT_CHECK:
+			case CONSTRAINT_PRIMARY:
+			case CONSTRAINT_UNIQUE:
+			case CONSTRAINT_EXCLUSION:
+				bconst = true;
+				break;
+			case CONSTRAINT_FOREIGN:
+				continue;		/* not here */
+			default:
+				elog(ERROR, "unrecognized constraint type");
+		}
+	}
+
+	systable_endscan(scan);
+	table_close(conRel, AccessShareLock);
+
+	return bconst;
+}
+
+/*
+ * Subroutine for CREATE TABLE deparsing.
+ *
+ * Deal with all the table elements (columns and constraints).
+ *
+ * Note we ignore constraints in the parse node here; they are extracted from
+ * system catalogs instead.
+ */
+
+static void
+deparse_TableElems_ToJsonb(JsonbParseState *state, Relation relation,
+							 List *tableElements, List *dpcontext,
+							 bool typed, bool composite)
+{
+	ListCell   *lc;
+
+	foreach(lc, tableElements)
+	{
+		Node	   *elt = (Node *) lfirst(lc);
+
+		switch (nodeTag(elt))
+		{
+			case T_ColumnDef:
+				{
+					if (typed)
+						deparse_ColumnDef_typed_toJsonb(state, relation, dpcontext,
+														(ColumnDef *) elt);
+					else
+						deparse_ColumnDef_toJsonb(state, relation, dpcontext,
+												  composite, (ColumnDef *) elt,
+												  false, NULL);
+				}
+				break;
+			case T_Constraint:
+				break;
+			default:
+				elog(ERROR, "invalid node type %d", nodeTag(elt));
+		}
+	}
+
+}
+
+/*
+ * Subroutine for CREATE TABLE deparsing.
+ *
+ * Deparse the INHERITS relations.
+ *
+ * Given a table OID, return a schema-qualified table list representing
+ * the parent tables.
+ */
+static List *
+deparse_InhRels_ToJsonb(Oid objectId)
+{
+	List	   *parents = NIL;
+	Relation	inhRel;
+	SysScanDesc scan;
+	ScanKeyData key;
+	HeapTuple	tuple;
+
+	inhRel = table_open(InheritsRelationId, RowExclusiveLock);
+
+	ScanKeyInit(&key,
+				Anum_pg_inherits_inhrelid,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(objectId));
+
+	scan = systable_beginscan(inhRel, InheritsRelidSeqnoIndexId,
+							  true, NULL, 1, &key);
+
+	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
+	{
+		Form_pg_inherits formInh = (Form_pg_inherits) GETSTRUCT(tuple);
+
+		parents = lappend_oid(parents, formInh->inhparent);
+	}
+
+	systable_endscan(scan);
+	table_close(inhRel, RowExclusiveLock);
+
+	return parents;
+}
+
+/*
+ * Subroutine for CREATE TABLE deparsing.
+ *
+ * Given a table OID, obtain its constraints and append them to the given
+ * JsonbParseState.
+ *
+ * This works for typed tables, regular tables.
+ *
+ * Note that CONSTRAINT_FOREIGN constraints are always ignored.
+ */
+static void
+deparse_Constraints_ToJsonb(JsonbParseState *state, Oid relationId)
+{
+	Relation	conRel;
+	ScanKeyData key;
+	SysScanDesc scan;
+	HeapTuple	tuple;
+
+	Assert(OidIsValid(relationId));
+
+	/*
+	 * Scan pg_constraint to fetch all constraints linked to the given
+	 * relation.
+	 */
+	conRel = table_open(ConstraintRelationId, AccessShareLock);
+	ScanKeyInit(&key, Anum_pg_constraint_conrelid, BTEqualStrategyNumber,
+				F_OIDEQ, ObjectIdGetDatum(relationId));
+	scan = systable_beginscan(conRel, ConstraintRelidTypidNameIndexId, true,
+							  NULL, 1, &key);
+
+	/*
+	 * For each constraint, add a node to the list of table elements.  In
+	 * these nodes we include not only the printable information ("fmt"), but
+	 * also separate attributes to indicate the type of constraint, for
+	 * automatic processing.
+	 */
+	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
+	{
+		Form_pg_constraint constrForm;
+		char	   *contype;
+		char	   *fmtStr = "CONSTRAINT %{name}I %{definition}s";
+
+		constrForm = (Form_pg_constraint) GETSTRUCT(tuple);
+
+		switch (constrForm->contype)
+		{
+			case CONSTRAINT_CHECK:
+				contype = "check";
+				break;
+			case CONSTRAINT_FOREIGN:
+				continue;		/* not here */
+			case CONSTRAINT_PRIMARY:
+				contype = "primary key";
+				break;
+			case CONSTRAINT_UNIQUE:
+				contype = "unique";
+				break;
+			case CONSTRAINT_EXCLUSION:
+				contype = "exclusion";
+				break;
+			default:
+				elog(ERROR, "unrecognized constraint type");
+		}
+
+		/*
+		 * "type" and "contype" are not part of the printable output, but are
+		 * useful to programmatically distinguish these from columns and among
+		 * different constraint types.
+		 *
+		 * XXX it might be useful to also list the column names in a PK, etc.
+		 */
+
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+		new_jsonb_VA(state, fmtStr, true, 4,
+								"type", jbvString, "constraint",
+								"contype", jbvString, contype,
+								"name", jbvString, NameStr(constrForm->conname),
+								"definition", jbvString,
+								pg_get_constraintdef_string(constrForm->oid));
+
+		if (constrForm->conindid &&
+			(constrForm->contype == CONSTRAINT_PRIMARY ||
+			 constrForm->contype == CONSTRAINT_UNIQUE ||
+			 constrForm->contype == CONSTRAINT_EXCLUSION))
+		{
+			Oid			tblspc = get_rel_tablespace(constrForm->conindid);
+
+			if (OidIsValid(tblspc))
+			{
+				char	   *tblspcname = get_tablespace_name(tblspc);
+
+				if (!tblspcname)
+					elog(ERROR, "cache lookup failed for tablespace %u", tblspc);
+
+				fmt_to_jsonb_element(state, "USING INDEX TABLESPACE %{tblspc}s");
+				insert_jsonb_str_element(state, "tblspc", tblspcname);
+			}
+		}
+
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+	}
+
+	systable_endscan(scan);
+	table_close(conRel, AccessShareLock);
+}
+
+/*
+ * Deparse DefElems, as used by Create Table
+ *
+ * Verbose syntax
+ * %{label}s = %{value}L
+ */
+static void
+deparse_DefElem_ToJsonb(JsonbParseState *state, DefElem *elem, bool is_reset)
+{
+	StringInfoData fmtStr;
+
+	initStringInfo(&fmtStr);
+
+	appendStringInfoString(&fmtStr, "%{label}s");
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* LABEL */
+	{
+		StringInfoData labelfmt;
+
+		initStringInfo(&labelfmt);
+
+		/* insert LABEL as key */
+		insert_jsonb_key(state, "label");
+
+		/* LABEL's value is an object */
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+		if (elem->defnamespace != NULL)
 		{
-			case AT_AddColumn:
-				/* XXX need to set the "recurse" bit somewhere? */
-				Assert(IsA(subcmd->def, ColumnDef));
-				tree = deparse_ColumnDef(rel, dpcontext, false,
-										 (ColumnDef *) subcmd->def, true, &expr);
+			appendStringInfoString(&labelfmt, "%{schema}I.");
+			insert_jsonb_str_element(state, "schema", elem->defnamespace);
+		}
 
-				mark_function_volatile(context, expr);
+		appendStringInfoString(&labelfmt, "%{label}I");
+		insert_jsonb_str_element(state, "label", elem->defname);
 
-				tmp_obj = new_objtree_VA("ADD %{objtype}s %{if_not_exists}s %{definition}s", 4,
-										"objtype", ObjTypeString, "COLUMN",
-										"type", ObjTypeString, "add column",
-										"if_not_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF NOT EXISTS" : "",
-										"definition", ObjTypeObject, tree);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+		fmt_to_jsonb_element(state, labelfmt.data);
+		pfree(labelfmt.data);
 
-			case AT_AddIndexConstraint:
-				{
-					IndexStmt  *istmt;
-					Relation	idx;
-					Oid			constrOid = sub->address.objectId;
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+	}
 
-					Assert(IsA(subcmd->def, IndexStmt));
-					istmt = (IndexStmt *) subcmd->def;
+	/* VALUE */
+	if (!is_reset)
+	{
+		appendStringInfoString(&fmtStr, " = %{value}L");
+		insert_jsonb_str_element(state, "value",
+								 elem->arg ? defGetString(elem) :
+								 defGetBoolean(elem) ? "TRUE" : "FALSE");
+	}
 
-					Assert(istmt->isconstraint && istmt->unique);
+	fmt_to_jsonb_element(state, fmtStr.data);
+	pfree(fmtStr.data);
 
-					idx = relation_open(istmt->indexOid, AccessShareLock);
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
 
-					/*
-					 * Verbose syntax
-					 *
-					 * ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX
-					 * %index_name}I %{deferrable}s %{init_deferred}s
-					 */
-					tmp_obj = new_objtree_VA("ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX %{index_name}I %{deferrable}s %{init_deferred}s", 6,
-											"type", ObjTypeString, "add constraint using index",
-											"name", ObjTypeString, get_constraint_name(constrOid),
-											"constraint_type", ObjTypeString,
-											istmt->primary ? "PRIMARY KEY" : "UNIQUE",
-											"index_name", ObjTypeString,
-											RelationGetRelationName(idx),
-											"deferrable", ObjTypeString,
-											istmt->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
-											"init_deferred", ObjTypeString,
-											istmt->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
-
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+/*
+ * Deparse SET/RESET clause as used by ALTER TABLE ... SET/RESET (...)
+ *
+ * Verbose syntax
+ * RESET|SET (%{options:, }s)
+ */
+static void
+deparse_RelSetOptions_toJsonb(JsonbParseState *state, AlterTableCmd *subcmd)
+{
+	ListCell   *cell;
+	bool		is_reset = subcmd->subtype == AT_ResetRelOptions;
+	bool       elem_found = false;
 
-					relation_close(idx, AccessShareLock);
-				}
-				break;
 
-			case AT_ReAddIndex:
-			case AT_ReAddConstraint:
-			case AT_ReAddDomainConstraint:
-			case AT_ReAddComment:
-			case AT_ReplaceRelOptions:
-			case AT_CheckNotNull:
-			case AT_ReAddStatistics:
-				/* Subtypes used for internal operations; nothing to do here */
-				break;
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	new_jsonb_VA(state, "%{set_reset}s (%{options:, }s)", true, 1,
+						  "set_reset", jbvString, is_reset ? "RESET" : "SET");
 
-			case AT_CookedColumnDefault:
-				{
-					Relation	attrrel;
-					HeapTuple	atttup;
-					Form_pg_attribute attStruct;
+	/* insert options array */
+	insert_jsonb_key(state, "options");
 
-					attrrel = table_open(AttributeRelationId, RowExclusiveLock);
-					atttup = SearchSysCacheCopy2(ATTNUM,
-												 ObjectIdGetDatum(RelationGetRelid(rel)),
-												 Int16GetDatum(subcmd->num));
-					if (!HeapTupleIsValid(atttup))
-						elog(ERROR, "cache lookup failed for attribute %d of relation with OID %u",
-							 subcmd->num, RelationGetRelid(rel));
-					attStruct = (Form_pg_attribute) GETSTRUCT(atttup);
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
 
-					/*
-					 * Both default and generation expression not supported
-					 * together.
-					 */
-					if (!attStruct->attgenerated)
-						elog(WARNING, "unsupported alter table subtype %d",
-							 subcmd->subtype);
+	foreach(cell, (List *) subcmd->def)
+	{
+		DefElem    *elem;
 
-					heap_freetuple(atttup);
-					table_close(attrrel, RowExclusiveLock);
-					break;
-				}
+		elem = (DefElem *) lfirst(cell);
+		deparse_DefElem_ToJsonb(state, elem, is_reset);
+		elem_found = true;
+	}
 
-			case AT_AddColumnToView:
-				/* CREATE OR REPLACE VIEW -- nothing to do here */
-				break;
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 
-			case AT_ColumnDefault:
-				if (subcmd->def == NULL)
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP DEFAULT", 2,
-											"type", ObjTypeString, "drop default",
-											"column", ObjTypeString, subcmd->name);
-				else
-				{
-					List	   *dpcontext_rel;
-					HeapTuple	attrtup;
-					AttrNumber	attno;
+	Assert(elem_found);
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET DEFAULT", 2,
-											"type", ObjTypeString, "set default",
-											"column", ObjTypeString, subcmd->name);
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
 
-					dpcontext_rel = deparse_context_for(RelationGetRelationName(rel),
-														RelationGetRelid(rel));
-					attrtup = SearchSysCacheAttName(RelationGetRelid(rel), subcmd->name);
-					attno = ((Form_pg_attribute) GETSTRUCT(attrtup))->attnum;
-					append_string_object(tmp_obj, "%{definition}s", "definition",
-										 RelationGetColumnDefault(rel, attno,
-																  dpcontext_rel,
-																  NULL));
-					ReleaseSysCache(attrtup);
-				}
+/*
+ * Deparse with clause, as used by Create Table
+ *
+ * Insert with-clause object for table definition
+ */
+static void
+deparse_withObj_ToJsonb(JsonbParseState *state, char *fmt, CreateStmt *node)
+{
+	ListCell   *cell;
 
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+	/* with_clause's value is an object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
 
-			case AT_DropNotNull:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP NOT NULL", 2,
-										"type", ObjTypeString, "drop not null",
-										"column", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+	/* WITH */
+	{
+		/* insert with as key */
+		insert_jsonb_key(state, "with");
 
-			case AT_ForceRowSecurity:
-				tmp_obj = new_objtree("FORCE ROW LEVEL SECURITY");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+		/* with's value is an array */
+		pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
 
-			case AT_NoForceRowSecurity:
-				tmp_obj = new_objtree("NO FORCE ROW LEVEL SECURITY");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+		/* add elements to array */
+		foreach(cell, node->options)
+		{
+			DefElem    *opt = (DefElem *) lfirst(cell);
+
+			deparse_DefElem_ToJsonb(state, opt, false);
+		}
+
+		/* with's array end */
+		pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+	}
+
+	/* with_clause's object end */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+}
+
+/*
+ * Deparse a CreateStmt (CREATE TABLE).
+ *
+ * Given a table OID and the parse tree that created it, return JsonbValue
+ * representing the creation command.
+ *
+ * Verbose syntax
+ * CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D [OF
+ * %{of_type}T | PARTITION OF %{parent_identity}D] %{table_elements}s
+ * %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s
+ * %{tablespace}s
+ */
+static Jsonb *
+deparse_CreateStmt(Oid objectId, Node *parsetree, char *owner)
+{
+	CreateStmt *node = (CreateStmt *) parsetree;
+	Relation	relation = relation_open(objectId, AccessShareLock);
+	Oid			nspid = relation->rd_rel->relnamespace;
+	char	   *relname = RelationGetRelationName(relation);
+	List	   *dpcontext;
+	StringInfoData fmtStr;
+	JsonbParseState *state = NULL;
+	bool		telems = false;
+	JsonbValue *value;
+
+	initStringInfo(&fmtStr);
+
+	dpcontext = deparse_context_for(RelationGetRelationName(relation),
+									objectId);
+
+	appendStringInfoString(&fmtStr, "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D");
+
+	/* mark the start of ROOT object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* create owner jsonb element */
+	role_to_jsonb_element(state, owner);
+
+	/* PERSISTENCE clause creation */
+	insert_jsonb_str_element(state, "persistence", get_persistence_str(relation->rd_rel->relpersistence));
+
+	/* IF NOT EXISTS clause creation */
+	insert_jsonb_str_element(state, "if_not_exists", node->if_not_exists ? "IF NOT EXISTS" : "");
+
+
+	/* IDENTITY creation */
+	insert_identity_object(state, nspid, relname);
+
+	/*
+	 * TABLE-ELEMENTS array creation
+	 *
+	 * Typed tables and partitions use a slightly different format string: we
+	 * must not put table_elements with parents directly in the fmt string,
+	 * because if there are no options the parentheses must not be emitted;
+	 * and also, typed tables do not allow for inheritance.
+	 */
+	if (node->ofTypename || node->partbound)
+	{
+		/*
+		 * We can't put table elements directly in the fmt string as an array
+		 * surrounded by parentheses here, because an empty clause would cause
+		 * a syntax error.  Therefore, we use an indirection element and set
+		 * present=false when there are no elements.
+		 */
+		if (node->ofTypename)
+		{
+			appendStringInfoString(&fmtStr, " OF %{of_type}T");
+
+			/* Push the key first */
+			insert_jsonb_key(state, "of_type");
+
+			/* Push the value */
+			new_jsonb_for_type(state, relation->rd_rel->reloftype, -1);
+		}
+		else
+		{
+			List	   *parents;
+			Oid			objid;
+
+			appendStringInfoString(&fmtStr, " PARTITION OF %{parent_identity}D");
+
+			parents = deparse_InhRels_ToJsonb(objectId);
+			objid = linitial_oid(parents);
+
+			Assert(list_length(parents) == 1);
+
+			new_jsonb_for_qualname_id(state, RelationRelationId,
+									  objid, "parent_identity");
+		}
+
+		telems = table_elem_present_col(relation, node->tableElts, true);
+		if (!telems)
+			telems = table_elem_present_const(objectId);
+
+		appendStringInfoString(&fmtStr, " %{table_elements}s");
+
+		if (telems)
+		{
+			insert_jsonb_key(state, "table_elements");
+			pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+			fmt_to_jsonb_element(state, "(%{elements:, }s)");
+
+			insert_jsonb_key(state, "elements");
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+			deparse_TableElems_ToJsonb(state, relation, node->tableElts, dpcontext,
+										 true,	/* typed table */
+										 false); /* not composite */
+
+			deparse_Constraints_ToJsonb(state, objectId);
+
+			/* end of elements array */
+			pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+
+			/* end of table_elements object */
+			pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+		}
+		else
+		{
+			insert_jsonb_key(state, "table_elements");
+			insert_not_present_obj(state, "(%{elements:, }s)");
+		}
+	}
+	else
+	{
+		List	   *inhrelations;
+
+		/*
+		 * There is no need to process LIKE clauses separately; they have
+		 * already been transformed into columns and constraints.
+		 */
+
+		/*
+		 * Process table elements: column definitions and constraints.  Only
+		 * the column definitions are obtained from the parse node itself.  To
+		 * get constraints we rely on pg_constraint, because the parse node
+		 * might be missing some things such as the name of the constraints.
+		 */
+		telems = table_elem_present_col(relation, node->tableElts, false);
+		if (!telems)
+			telems = table_elem_present_const(objectId);
+
+		if (telems)
+		{
+			appendStringInfoString(&fmtStr, " (%{table_elements:, }s)");
+			insert_jsonb_key(state, "table_elements");
+
+			/*
+			 * It will be of array type for multi-columns table, so lets begin
+			 * an arrayobject. deparse_TableElems_ToJsonb() will add
+			 * elements to it.
+			 */
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+			deparse_TableElems_ToJsonb(state, relation, node->tableElts, dpcontext,
+										 false, /* not typed table */
+										 false); /* not composite */
+			deparse_Constraints_ToJsonb(state, objectId);
+
+			pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+		}
+		else
+			appendStringInfoString(&fmtStr, " ()");
+
+		appendStringInfoString(&fmtStr, " %{inherits}s");
+		insert_jsonb_key(state, "inherits");
+
+		/*
+		 * Add inheritance specification.  We cannot simply scan the list of
+		 * parents from the parser node, because that may lack the actual
+		 * qualified names of the parent relations.  Rather than trying to
+		 * re-resolve them from the information in the parse node, it seems
+		 * more accurate and convenient to grab it from pg_inherits.
+		 */
+		if (node->inhRelations != NIL)
+		{
+			pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+			fmt_to_jsonb_element(state, "INHERITS (%{parents:, }D)");
+			inhrelations = deparse_InhRels_ToJsonb(objectId);
+
+			insert_jsonb_array_oid(state, "parents", inhrelations);
+			pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+		}
+		else
+			insert_not_present_obj(state, verbose ? "INHERITS (%{parents:, }D)" : "INHERITS");
+	}
+
+
+	/* FOR VALUES clause */
+	if (node->partbound)
+	{
+		appendStringInfoString(&fmtStr, " %{partition_bound}s");
+
+		/*
+		 * Get pg_class.relpartbound. We cannot use partbound in the parsetree
+		 * directly as it's the original partbound expression which haven't
+		 * been transformed.
+		 */
+		insert_jsonb_str_element(state, "partition_bound",
+								 RelationGetPartitionBound(objectId));
+	}
+
+	/* PARTITION BY clause */
+	appendStringInfoString(&fmtStr, " %{partition_by}s");
+	insert_jsonb_key(state, "partition_by");
+
+	if (relation->rd_rel->relkind == RELKIND_PARTITIONED_TABLE)
+		insert_str_object(state, "PARTITION BY %{definition}s", "definition",
+						  pg_get_partkeydef_string(objectId));
+	else
+		insert_not_present_obj(state, verbose ? "PARTITION BY %{definition}s" : "PARTITION BY");
 
-			case AT_SetNotNull:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET NOT NULL", 2,
-										"type", ObjTypeString, "set not null",
-										"column", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
 
-			case AT_DropExpression:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", 3,
-										"type", ObjTypeString, "drop expression",
-										"column", ObjTypeString, subcmd->name,
-										"if_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF EXISTS" : "");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+	/* USING clause */
+	appendStringInfoString(&fmtStr, " %{access_method}s");
+	insert_jsonb_key(state, "access_method");
 
-			case AT_SetStatistics:
-				{
-					Assert(IsA(subcmd->def, Integer));
-					if (subcmd->name)
-						tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", 3,
-												"type", ObjTypeString, "set statistics",
-												"column", ObjTypeString, subcmd->name,
-												"statistics", ObjTypeInteger,
-												intVal((Integer *) subcmd->def));
-					else
-						tmp_obj = new_objtree_VA("ALTER COLUMN %{column}n SET STATISTICS %{statistics}n", 3,
-												"type", ObjTypeString, "set statistics",
-												"column", ObjTypeInteger, subcmd->num,
-												"statistics", ObjTypeInteger,
-												intVal((Integer *) subcmd->def));
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				}
-				break;
+	if (node->accessMethod)
+		insert_str_object(state, "USING %{access_method}I", "access_method",
+						  node->accessMethod);
+	else
+		insert_not_present_obj(state, verbose ? "USING %{access_method}I" : "USING");
 
-			case AT_SetOptions:
-			case AT_ResetOptions:
-				subcmds = lappend(subcmds, new_object_object(
-															 deparse_ColumnSetOptions(subcmd)));
-				break;
+	/* WITH clause */
+	appendStringInfoString(&fmtStr, " %{with_clause}s");
+	insert_jsonb_key(state, "with_clause");
 
-			case AT_SetStorage:
-				Assert(IsA(subcmd->def, String));
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET STORAGE %{storage}s", 3,
-										"type", ObjTypeString, "set storage",
-										"column", ObjTypeString, subcmd->name,
-										"storage", ObjTypeString,
-										strVal((String *) subcmd->def));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+	if (node->options)
+		deparse_withObj_ToJsonb(state, "WITH (%{with:, }s)", node);
+	else
+		insert_not_present_obj(state, verbose ? "WITH (%{with:, }s)" : "WITH");
 
-			case AT_SetCompression:
-				Assert(IsA(subcmd->def, String));
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET COMPRESSION %{compression_method}s", 3,
-										"type", ObjTypeString, "set compression",
-										"column", ObjTypeString, subcmd->name,
-										"compression_method", ObjTypeString,
-										strVal((String *) subcmd->def));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+	/* TABLESPACE */
+	appendStringInfoString(&fmtStr, " %{tablespace}s");
+	insert_jsonb_key(state, "tablespace");
 
-			case AT_DropColumn:
-				tmp_obj = new_objtree_VA("DROP %{objtype}s %{if_exists}s %{column}I", 4,
-										"objtype", ObjTypeString, "COLUMN",
-										"type", ObjTypeString, "drop column",
-										"if_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF EXISTS" : "",
-										"column", ObjTypeString, subcmd->name);
-				tmp_obj2 = new_objtree("CASCADE");
-				if (subcmd->behavior != DROP_CASCADE)
-					append_not_present(tmp_obj2, NULL);
-				append_object_object(tmp_obj, "%{cascade}s", tmp_obj2);
+	/* Push the value now: object in this case */
+	if (node->tablespacename)
+		insert_str_object(state, "TABLESPACE %{tablespace}I", "tablespace", node->tablespacename);
+	else
+		insert_not_present_obj(state, verbose ? "TABLESPACE %{tablespace}I" : "TABLESPACE");
 
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
 
-			case AT_AddIndex:
-				{
-					Oid			idxOid = sub->address.objectId;
-					IndexStmt  *istmt;
-					Relation	idx;
-					const char *idxname;
-					Oid			constrOid;
+	relation_close(relation, AccessShareLock);
 
-					Assert(IsA(subcmd->def, IndexStmt));
-					istmt = (IndexStmt *) subcmd->def;
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
 
-					if (!istmt->isconstraint)
-						break;
+	pfree(fmtStr.data);
 
-					idx = relation_open(idxOid, AccessShareLock);
-					idxname = RelationGetRelationName(idx);
+	/* Mark the end of ROOT object */
+	value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-					constrOid = get_relation_constraint_oid(
-															cmd->d.alterTable.objectId, idxname, false);
+	return JsonbValueToJsonb(value);
+}
 
-					tmp_obj = new_objtree_VA("ADD CONSTRAINT %{name}I %{definition}s", 3,
-											"type", ObjTypeString, "add constraint",
-											"name", ObjTypeString, idxname,
-											"definition", ObjTypeString,
-											pg_get_constraintdef_string(constrOid));
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+/*
+ * Deparse a DropStmt (DROP TABLE).
+ *
+ * Given an object identity and the parse tree that created it, return
+ * jsonb string representing the drop command.
+ *
+ * Verbose syntax
+ * DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s %{cascade}s
+ */
+char *
+deparse_drop_table(const char *objidentity, const char *objecttype,
+							  Node *parsetree)
+{
+	DropStmt   *node = (DropStmt *) parsetree;
+	StringInfoData fmtStr;
+	char	   *identity = (char *) objidentity;
+	JsonbValue *jsonbval;
+	Jsonb	   *jsonb;
+	StringInfoData str;
+	JsonbParseState *state = NULL;
 
-					relation_close(idx, AccessShareLock);
-				}
-				break;
+	initStringInfo(&str);
+	initStringInfo(&fmtStr);
 
-			case AT_AddConstraint:
-				{
-					/* XXX need to set the "recurse" bit somewhere? */
-					Oid			constrOid = sub->address.objectId;
-					bool		isnull;
-					HeapTuple	tup;
-					Datum		val;
-					Constraint *constr;
+	/* Start constructing fmt string */
+	appendStringInfoString(&fmtStr, "DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s");
 
-					/* Skip adding constraint for inherits table sub command */
-					if (!constrOid)
-						continue;
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-					Assert(IsA(subcmd->def, Constraint));
-					constr = castNode(Constraint, subcmd->def);
+	insert_jsonb_str_element(state, "objtype", objecttype);
+	insert_jsonb_str_element(state, "concurrently",
+							 node->concurrent ? "CONCURRENTLY" : "");
+	insert_jsonb_str_element(state, "if_exists", node->missing_ok ? "IF EXISTS" : "");
+	insert_jsonb_str_element(state, "objidentity", identity);
 
-					if (!constr->skip_validation)
-					{
-						tup = SearchSysCache1(CONSTROID, ObjectIdGetDatum(constrOid));
+	if (node->behavior == DROP_CASCADE)
+	{
+		appendStringInfoString(&fmtStr, " %{cascade}s");
+		insert_jsonb_key(state, "cascade");
 
-						if (HeapTupleIsValid(tup))
-						{
-							char	   *conbin;
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+		fmt_to_jsonb_element(state, "CASCADE");
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+	}
 
-							/* Fetch constraint expression in parsetree form */
-							val = SysCacheGetAttr(CONSTROID, tup,
-												  Anum_pg_constraint_conbin, &isnull);
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
+	pfree(fmtStr.data);
 
-							if (!isnull)
-							{
-								conbin = TextDatumGetCString(val);
-								expr = stringToNode(conbin);
-								mark_function_volatile(context, expr);
-							}
+	jsonbval = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-							ReleaseSysCache(tup);
-						}
-					}
+	jsonb = JsonbValueToJsonb(jsonbval);
+	return JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
+}
 
-					tmp_obj = new_objtree_VA("ADD CONSTRAINT %{name}I %{definition}s", 3,
-											"type", ObjTypeString, "add constraint",
-											"name", ObjTypeString, get_constraint_name(constrOid),
-											"definition", ObjTypeString,
-											pg_get_constraintdef_string(constrOid));
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				}
-				break;
+/*
+ * Deparse all the collected subcommands and return jsonb string representing
+ * the alter command.
+ *
+ * Verbose syntax
+ * ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s
+ */
+static Jsonb *
+deparse_alter_table(CollectedCommand *cmd, ddl_deparse_context * context)
+{
+	List	   *dpcontext;
+	Relation	rel;
+	ListCell   *cell;
+	const char *reltype;
+	Node	   *expr = NULL;
+	Oid			relId = cmd->d.alterTable.objectId;
+	AlterTableStmt *stmt = NULL;
+	StringInfoData fmtStr;
+	JsonbParseState *state = NULL;
+	bool		subCmdFound = false;
+	JsonbValue *value;
 
-			case AT_AlterConstraint:
-				{
-					Oid			constrOid = sub->address.objectId;
-					Constraint *c = (Constraint *) subcmd->def;
+	Assert(cmd->type == SCT_AlterTable);
+	stmt = (AlterTableStmt *) cmd->parsetree;
+	Assert(IsA(stmt, AlterTableStmt));
 
-					/* If no constraint was altered, silently skip it */
-					if (!OidIsValid(constrOid))
-						break;
+	/*
+	 * ALTER TABLE subcommands generated for TableLikeClause is processed in
+	 * the top level CREATE TABLE command; return empty here.
+	 */
+	if (stmt->table_like)
+		return NULL;
 
-					Assert(IsA(c, Constraint));
-					tmp_obj = new_objtree_VA("ALTER CONSTRAINT %{name}I %{deferrable}s %{init_deferred}s", 4,
-											"type", ObjTypeString, "alter constraint",
-											"name", ObjTypeString, get_constraint_name(constrOid),
-											"deferrable", ObjTypeString,
-											c->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
-											"init_deferred", ObjTypeString,
-											c->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
-
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				}
-				break;
+	rel = relation_open(relId, AccessShareLock);
 
-			case AT_ValidateConstraint:
-				tmp_obj = new_objtree_VA("VALIDATE CONSTRAINT %{constraint}I", 2,
-										"type", ObjTypeString, "validate constraint",
-										"constraint", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+	switch (rel->rd_rel->relkind)
+	{
+		case RELKIND_RELATION:
+		case RELKIND_PARTITIONED_TABLE:
+			reltype = "TABLE";
+			break;
+		case RELKIND_INDEX:
+		case RELKIND_PARTITIONED_INDEX:
+		case RELKIND_VIEW:
+		case RELKIND_COMPOSITE_TYPE:
+		case RELKIND_FOREIGN_TABLE:
+		case RELKIND_MATVIEW:
+			/* unsupported relkind */
+			table_close(rel, AccessShareLock);
+			return NULL;
 
-			case AT_DropConstraint:
-				tmp_obj = new_objtree_VA("DROP CONSTRAINT %{if_exists}s %{constraint}I %{cascade}s", 4,
-										"type", ObjTypeString, "drop constraint",
-										"if_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF EXISTS" : "",
-										"constraint", ObjTypeString, subcmd->name,
-										"cascade", ObjTypeString,
-										subcmd->behavior == DROP_CASCADE ? "CASCADE" : "");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+		default:
+			elog(ERROR, "unexpected relkind %d", rel->rd_rel->relkind);
+	}
 
-			case AT_AlterColumnType:
-				{
-					TupleDesc	tupdesc = RelationGetDescr(rel);
-					Form_pg_attribute att;
-					ColumnDef  *def;
 
-					att = &(tupdesc->attrs[sub->address.objectSubId - 1]);
-					def = (ColumnDef *) subcmd->def;
-					Assert(IsA(def, ColumnDef));
+	dpcontext = deparse_context_for(RelationGetRelationName(rel),
+									relId);
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET DATA TYPE %{datatype}T", 3,
-											"type", ObjTypeString, "alter column type",
-											"column", ObjTypeString, subcmd->name,
-											"datatype", ObjTypeObject,
-											new_objtree_for_type(att->atttypid,
-																 att->atttypmod));
+	initStringInfo(&fmtStr);
 
-					/* Add a COLLATE clause, if needed */
-					tmp_obj2 = new_objtree("COLLATE");
-					if (OidIsValid(att->attcollation))
-					{
-						ObjTree    *collname;
+	/* Start constructing fmt string */
+	appendStringInfoString(&fmtStr, "ALTER %{objtype}s %{only}s %{identity}D ");
 
-						collname = new_objtree_for_qualname_id(CollationRelationId,
-															   att->attcollation);
-						append_object_object(tmp_obj2, "%{name}D", collname);
-					}
-					else
-						append_not_present(tmp_obj2, "%{name}D");
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	insert_jsonb_str_element(state, "objtype", reltype);
+	insert_jsonb_str_element(state, "only", stmt->relation->inh ? "" : "ONLY");
+	insert_identity_object(state, rel->rd_rel->relnamespace,
+						   RelationGetRelationName(rel));
 
-					append_object_object(tmp_obj, "%{collation}s", tmp_obj2);
+	foreach(cell, cmd->d.alterTable.subcmds)
+	{
+		CollectedATSubcmd *sub = (CollectedATSubcmd *) lfirst(cell);
+		AlterTableCmd *subcmd = (AlterTableCmd *) sub->parsetree;
 
-					/*
-					 * If there's a USING clause, transformAlterTableStmt ran
-					 * it through transformExpr and stored the resulting node
-					 * in cooked_default, which we can use here.
-					 */
-					tmp_obj2 = new_objtree("USING");
-					if (def->raw_default)
-					{
-						append_string_object(tmp_obj2, "%{expression}s",
-											 "expression", sub->usingexpr);
-						mark_function_volatile(context, def->cooked_default);
-					}
-					else
-						append_not_present(tmp_obj2, "%{expression}s");
+		Assert(IsA(subcmd, AlterTableCmd));
 
-					append_object_object(tmp_obj, "%{using}s", tmp_obj2);
+		/*
+		 * Skip deparse of the subcommand if the objectId doesn't match the
+		 * target relation ID. It can happen for inherited tables when
+		 * subcommands for inherited tables and the parent table are both
+		 * collected in the ALTER TABLE command for the parent table.
+		 */
+		if (subcmd->subtype != AT_AttachPartition &&
+			sub->address.objectId != relId &&
+			has_superclass(sub->address.objectId))
+			continue;
 
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				}
-				break;
+		if (!subCmdFound)
+		{
+			insert_jsonb_key(state, "subcmds");
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+			subCmdFound = true;
+		}
 
-#ifdef TODOLIST
-			case AT_AlterColumnGenericOptions:
-				tmp_obj = deparse_FdwOptions((List *) subcmd->def,
-											subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-#endif
-			case AT_ChangeOwner:
-				tmp_obj = new_objtree_VA("OWNER TO %{owner}I", 2,
-										"type", ObjTypeString, "change owner",
-										"owner", ObjTypeString,
-										get_rolespec_name(subcmd->newowner));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+		switch (subcmd->subtype)
+		{
+			case AT_AddColumn:
+				/* XXX need to set the "recurse" bit somewhere? */
+				Assert(IsA(subcmd->def, ColumnDef));
 
-			case AT_ClusterOn:
-				tmp_obj = new_objtree_VA("CLUSTER ON %{index}I", 2,
-										"type", ObjTypeString, "cluster on",
-										"index", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+				mark_function_volatile(context, expr);
 
-			case AT_DropCluster:
-				tmp_obj = new_objtree_VA("SET WITHOUT CLUSTER", 1,
-										"type", ObjTypeString, "set without cluster");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state,
+							 "ADD %{objtype}s %{if_not_exists}s %{definition}s", true, 3,
+							 "objtype", jbvString, "COLUMN",
+							 "type", jbvString, "add column",
+							 "if_not_exists", jbvString,
+							 subcmd->missing_ok ? "IF NOT EXISTS" : "");
 
-			case AT_SetLogged:
-				tmp_obj = new_objtree_VA("SET LOGGED", 1,
-										"type", ObjTypeString, "set logged");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				insert_jsonb_key(state, "definition");
+				deparse_ColumnDef_toJsonb(state, rel, dpcontext,
+										  false, (ColumnDef *) subcmd->def,
+										  true, NULL);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 
-			case AT_SetUnLogged:
-				tmp_obj = new_objtree_VA("SET UNLOGGED", 1,
-										"type", ObjTypeString, "set unlogged");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+			case AT_AddIndexConstraint:
+				{
+					IndexStmt  *istmt;
+					Relation	idx;
+					Oid			constrOid = sub->address.objectId;
 
-			case AT_DropOids:
-				tmp_obj = new_objtree_VA("SET WITHOUT OIDS", 1,
-										"type", ObjTypeString, "set without oids");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-			case AT_SetAccessMethod:
-				tmp_obj = new_objtree_VA("SET ACCESS METHOD %{access_method}I", 2,
-										"type", ObjTypeString, "set access method",
-										"access_method", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-			case AT_SetTableSpace:
-				tmp_obj = new_objtree_VA("SET TABLESPACE %{tablespace}I", 2,
-										"type", ObjTypeString, "set tablespace",
-										"tablespace", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					Assert(IsA(subcmd->def, IndexStmt));
+					istmt = (IndexStmt *) subcmd->def;
 
-			case AT_SetRelOptions:
-			case AT_ResetRelOptions:
-				subcmds = lappend(subcmds, new_object_object(
-															 deparse_RelSetOptions(subcmd)));
-				break;
+					Assert(istmt->isconstraint && istmt->unique);
 
-			case AT_EnableTrig:
-				tmp_obj = new_objtree_VA("ENABLE TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "enable trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					idx = relation_open(istmt->indexOid, AccessShareLock);
 
-			case AT_EnableAlwaysTrig:
-				tmp_obj = new_objtree_VA("ENABLE ALWAYS TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "enable always trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+					/*
+					 * Verbose syntax
+					 *
+					 * ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX
+					 * %index_name}I %{deferrable}s %{init_deferred}s
+					 */
+					new_jsonb_VA(state,
+								 "ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX %{index_name}I %{deferrable}s %{init_deferred}s", false, 6,
+								 "type", jbvString, "add constraint using index",
+								 "name", jbvString, get_constraint_name(constrOid),
+								 "constraint_type", jbvString,
+								 istmt->primary ? "PRIMARY KEY" : "UNIQUE",
+								 "index_name", jbvString,
+								 RelationGetRelationName(idx),
+								 "deferrable", jbvString,
+								 istmt->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
+								 "init_deferred", jbvString,
+								 istmt->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
+					relation_close(idx, AccessShareLock);
+					break;
+				}
+			case AT_ReAddIndex:
+			case AT_ReAddConstraint:
+			case AT_ReAddDomainConstraint:
+			case AT_ReAddComment:
+			case AT_ReplaceRelOptions:
+			case AT_CheckNotNull:
+			case AT_ReAddStatistics:
+				/* Subtypes used for internal operations; nothing to do here */
 				break;
 
-			case AT_EnableReplicaTrig:
-				tmp_obj = new_objtree_VA("ENABLE REPLICA TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "enable replica trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+			case AT_CookedColumnDefault:
+				{
+					Relation	attrrel;
+					HeapTuple	atttup;
+					Form_pg_attribute attStruct;
 
-			case AT_DisableTrig:
-				tmp_obj = new_objtree_VA("DISABLE TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "disable trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					attrrel = table_open(AttributeRelationId, RowExclusiveLock);
+					atttup = SearchSysCacheCopy2(ATTNUM,
+												 ObjectIdGetDatum(RelationGetRelid(rel)),
+												 Int16GetDatum(subcmd->num));
+					if (!HeapTupleIsValid(atttup))
+						elog(ERROR, "cache lookup failed for attribute %d of relation with OID %u",
+							 subcmd->num, RelationGetRelid(rel));
+					attStruct = (Form_pg_attribute) GETSTRUCT(atttup);
 
-			case AT_EnableTrigAll:
-				tmp_obj = new_objtree_VA("ENABLE TRIGGER ALL", 1,
-										"type", ObjTypeString, "enable trigger all");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					/*
+					 * Both default and generation expression not supported
+					 * together.
+					 */
+					if (!attStruct->attgenerated)
+						elog(WARNING, "unsupported alter table subtype %d",
+							 subcmd->subtype);
 
-			case AT_DisableTrigAll:
-				tmp_obj = new_objtree_VA("DISABLE TRIGGER ALL", 1,
-										"type", ObjTypeString, "disable trigger all");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					heap_freetuple(atttup);
+					table_close(attrrel, RowExclusiveLock);
+					break;
+				}
 
-			case AT_EnableTrigUser:
-				tmp_obj = new_objtree_VA("ENABLE TRIGGER USER", 1,
-										"type", ObjTypeString, "enable trigger user");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_AddColumnToView:
+				/* CREATE OR REPLACE VIEW -- nothing to do here */
 				break;
 
-			case AT_DisableTrigUser:
-				tmp_obj = new_objtree_VA("DISABLE TRIGGER USER", 1,
-										"type", ObjTypeString, "disable trigger user");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+			case AT_ColumnDefault:
+				if (subcmd->def == NULL)
+					new_jsonb_VA(state,
+								 "ALTER COLUMN %{column}I DROP DEFAULT", false, 2,
+								 "type", jbvString, "drop default",
+								 "column", jbvString, subcmd->name);
+				else
+				{
+					List	   *dpcontext_rel;
+					HeapTuple	attrtup;
+					AttrNumber	attno;
 
-			case AT_EnableRule:
-				tmp_obj = new_objtree_VA("ENABLE RULE %{rule}I", 2,
-										"type", ObjTypeString, "enable rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					dpcontext_rel = deparse_context_for(RelationGetRelationName(rel),
+														RelationGetRelid(rel));
+					attrtup = SearchSysCacheAttName(RelationGetRelid(rel), subcmd->name);
+					attno = ((Form_pg_attribute) GETSTRUCT(attrtup))->attnum;
 
-			case AT_EnableAlwaysRule:
-				tmp_obj = new_objtree_VA("ENABLE ALWAYS RULE %{rule}I", 2,
-										"type", ObjTypeString, "enable always rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+					new_jsonb_VA(state,
+								 "ALTER COLUMN %{column}I SET DEFAULT %{definition}s", false, 3,
+								 "type", jbvString, "set default",
+								 "column", jbvString, subcmd->name,
+								 "definition", jbvString,
+								 RelationGetColumnDefault(rel, attno,
+														  dpcontext_rel,
+														  NULL));
+					ReleaseSysCache(attrtup);
+				}
 
-			case AT_EnableReplicaRule:
-				tmp_obj = new_objtree_VA("ENABLE REPLICA RULE %{rule}I", 2,
-										"type", ObjTypeString, "enable replica rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
 				break;
 
-			case AT_DisableRule:
-				tmp_obj = new_objtree_VA("DISABLE RULE %{rule}I", 2,
-										"type", ObjTypeString, "disable rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_DropNotNull:
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I DROP NOT NULL", false, 2,
+							 "type", jbvString, "drop not null",
+							 "column", jbvString, subcmd->name);
 				break;
 
-			case AT_AddInherit:
-				tmp_obj = new_objtree_VA("INHERIT %{parent}D", 2,
-										"type", ObjTypeString, "inherit",
-										"parent", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_ForceRowSecurity:
+				new_jsonb_VA(state, "FORCE ROW LEVEL SECURITY", false, 0);
 				break;
 
-			case AT_DropInherit:
-				tmp_obj = new_objtree_VA("NO INHERIT %{parent}D", 2,
-										"type", ObjTypeString, "drop inherit",
-										"parent", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_NoForceRowSecurity:
+				new_jsonb_VA(state, "NO FORCE ROW LEVEL SECURITY", false, 0);
 				break;
 
-			case AT_AddOf:
-				tmp_obj = new_objtree_VA("OF %{type_of}T", 2,
-										"type", ObjTypeString, "add of",
-										"type_of", ObjTypeObject,
-										new_objtree_for_type(sub->address.objectId, -1));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_SetNotNull:
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I SET NOT NULL", false, 2,
+							 "type", jbvString, "set not null",
+							 "column", jbvString, subcmd->name);
 				break;
 
-			case AT_DropOf:
-				tmp_obj = new_objtree_VA("NOT OF", 1,
-										"type", ObjTypeString, "not of");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_DropExpression:
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", false, 3,
+							 "type", jbvString, "drop expression",
+							 "column", jbvString, subcmd->name,
+							 "if_exists", jbvString,
+							 subcmd->missing_ok ? "IF EXISTS" : "");
 				break;
 
-			case AT_ReplicaIdentity:
-				tmp_obj = new_objtree_VA("REPLICA IDENTITY", 1,
-										"type", ObjTypeString, "replica identity");
-				switch (((ReplicaIdentityStmt *) subcmd->def)->identity_type)
+			case AT_SetStatistics:
 				{
-					case REPLICA_IDENTITY_DEFAULT:
-						append_string_object(tmp_obj, "%{ident}s", "ident",
-											 "DEFAULT");
-						break;
-					case REPLICA_IDENTITY_FULL:
-						append_string_object(tmp_obj, "%{ident}s", "ident",
-											 "FULL");
-						break;
-					case REPLICA_IDENTITY_NOTHING:
-						append_string_object(tmp_obj, "%{ident}s", "ident",
-											 "NOTHING");
-						break;
-					case REPLICA_IDENTITY_INDEX:
-						tmp_obj2 = new_objtree_VA("USING INDEX %{index}I", 1,
-												 "index", ObjTypeString,
-												 ((ReplicaIdentityStmt *) subcmd->def)->name);
-						append_object_object(tmp_obj, "%{ident}s", tmp_obj2);
-						break;
+					Assert(IsA(subcmd->def, Integer));
+					if (subcmd->name)
+						new_jsonb_VA(state,
+									 "ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", false, 3,
+									 "type", jbvString, "set statistics",
+									 "column", jbvString, subcmd->name,
+									 "statistics", jbvNumeric,
+									 intVal((Integer *) subcmd->def));
+					else
+						new_jsonb_VA(state,
+									 "ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", false, 3,
+									 "type", jbvString, "set statistics",
+									 "column", jbvNumeric, subcmd->num,
+									 "statistics", jbvNumeric,
+									 intVal((Integer *) subcmd->def));
 				}
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
 				break;
 
-			case AT_EnableRowSecurity:
-				tmp_obj = new_objtree_VA("ENABLE ROW LEVEL SECURITY", 1,
-										"type", ObjTypeString, "enable row security");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_SetOptions:
+			case AT_ResetOptions:
+				deparse_ColumnSetOptions_ToJsonb(state, subcmd);
 				break;
 
-			case AT_DisableRowSecurity:
-				tmp_obj = new_objtree_VA("DISABLE ROW LEVEL SECURITY", 1,
-										"type", ObjTypeString, "disable row security");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+			case AT_SetStorage:
+				Assert(IsA(subcmd->def, String));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I SET STORAGE %{storage}s", false, 3,
+							 "type", jbvString, "set storage",
+							 "column", jbvString, subcmd->name,
+							 "storage", jbvString,
+							 strVal((String *) subcmd->def));
 				break;
-#ifdef TODOLIST
-			case AT_GenericOptions:
-				tmp_obj = deparse_FdwOptions((List *) subcmd->def, NULL);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+
+			case AT_SetCompression:
+				Assert(IsA(subcmd->def, String));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I SET COMPRESSION %{compression_method}s", false, 3,
+							 "type", jbvString, "set compression",
+							 "column", jbvString, subcmd->name,
+							 "compression_method", jbvString,
+							 strVal((String *) subcmd->def));
 				break;
-#endif
-			case AT_AttachPartition:
-				tmp_obj = new_objtree_VA("ATTACH PARTITION %{partition_identity}D",
-										2, "type", ObjTypeString, "attach partition",
-										"partition_identity", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
 
-				tmp_obj2 = new_objtree("");
-				if (rel->rd_rel->relkind == RELKIND_PARTITIONED_TABLE)
-					append_string_object(tmp_obj, "%{partition_bound}s",
-										 "partition_bound",
-										 RelationGetPartitionBound(sub->address.objectId));
+			case AT_DropColumn:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state,
+							 "DROP %{objtype}s %{if_exists}s %{column}I %{cascade}s", true, 4,
+							 "objtype", jbvString, "COLUMN",
+							 "type", jbvString, "drop column",
+							 "if_exists", jbvString,
+							 subcmd->missing_ok ? "IF EXISTS" : "",
+							 "column", jbvString, subcmd->name);
+
+				if (subcmd->behavior == DROP_CASCADE)
+					insert_jsonb_str_element(state, "cascade", "CASCADE");
 				else
-					append_not_present(tmp_obj2, "%{partition_bound}s");
+				{
+					insert_jsonb_key(state, "cascade");
+					insert_not_present_obj(state, "CASCADE");
+				}
 
-				append_object_object(tmp_obj, "%{partition_bound}s", tmp_obj2);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-			case AT_DetachPartition:
-			{
-				PartitionCmd *cmd;
-
-				Assert(IsA(subcmd->def, PartitionCmd));
-				cmd = (PartitionCmd *) subcmd->def;
-
-				tmp_obj = new_objtree_VA("DETACH PARTITION %{partition_identity}D %{concurrent}s", 3,
-										"type", ObjTypeString,
-										"detach partition",
-										"partition_identity", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId),
-										"concurrent", ObjTypeString,
-										cmd->concurrent ? "CONCURRENTLY" : "");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-			}
-			case AT_DetachPartitionFinalize:
-				tmp_obj = new_objtree_VA("DETACH PARTITION %{partition_identity}D FINALIZE", 2,
-										"type", ObjTypeString, "detach partition finalize",
-										"partition_identity", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
 				break;
-			case AT_AddIdentity:
+
+			case AT_AddIndex:
 				{
-					AttrNumber	attnum;
-					Oid			seq_relid;
-					ObjTree    *seqdef;
-					ColumnDef  *coldef = (ColumnDef *) subcmd->def;
+					Oid			idxOid = sub->address.objectId;
+					IndexStmt  *istmt;
+					Relation	idx;
+					const char *idxname;
+					Oid			constrOid;
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I", 2,
-											"type", ObjTypeString, "add identity",
-											"column", ObjTypeString, subcmd->name);
+					Assert(IsA(subcmd->def, IndexStmt));
+					istmt = (IndexStmt *) subcmd->def;
 
-					attnum = get_attnum(RelationGetRelid(rel), subcmd->name);
-					seq_relid = getIdentitySequence(RelationGetRelid(rel), attnum, true);
+					if (!istmt->isconstraint)
+						break;
 
-					tmp_obj2 = new_objtree("ADD");
-					if (OidIsValid(seq_relid))
-					{
-						seqdef = deparse_ColumnIdentity(seq_relid, coldef->identity, false);
-						append_object_object(tmp_obj2, "%{identity_column}s", seqdef);
-					}
-					else
-						append_not_present(tmp_obj2, "%{identity_column}s");
+					idx = relation_open(idxOid, AccessShareLock);
+					idxname = RelationGetRelationName(idx);
+
+					constrOid = get_relation_constraint_oid(
+															cmd->d.alterTable.objectId, idxname, false);
 
-					append_object_object(tmp_obj, "%{definition}s", tmp_obj2);
+					new_jsonb_VA(state,
+								 "ADD CONSTRAINT %{name}I %{definition}s", false, 3,
+								 "type", jbvString, "add constraint",
+								 "name", jbvString, idxname,
+								 "definition", jbvString,
+								 pg_get_constraintdef_string(constrOid));
 
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+					relation_close(idx, AccessShareLock);
 				}
 				break;
-			case AT_SetIdentity:
+			case AT_AddConstraint:
 				{
-					DefElem    *defel;
-					char		identity = 0;
-					ObjTree    *seqdef;
-					AttrNumber	attnum;
-					Oid			seq_relid;
+					/* XXX need to set the "recurse" bit somewhere? */
+					Oid			constrOid = sub->address.objectId;
+					bool		isnull;
+					HeapTuple	tup;
+					Datum		val;
+					Constraint *constr;
 
+					/* Skip adding constraint for inherits table sub command */
+					if (!constrOid)
+						continue;
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I", 2,
-											"type", ObjTypeString, "set identity",
-											"column", ObjTypeString, subcmd->name);
+					Assert(IsA(subcmd->def, Constraint));
+					constr = castNode(Constraint, subcmd->def);
 
-					if (subcmd->def)
+					if (!constr->skip_validation)
 					{
-						List	   *def = (List *) subcmd->def;
+						tup = SearchSysCache1(CONSTROID, ObjectIdGetDatum(constrOid));
 
-						Assert(IsA(subcmd->def, List));
+						if (HeapTupleIsValid(tup))
+						{
+							char	   *conbin;
 
-						defel = linitial_node(DefElem, def);
-						identity = defGetInt32(defel);
-					}
+							/* Fetch constraint expression in parsetree form */
+							val = SysCacheGetAttr(CONSTROID, tup,
+												  Anum_pg_constraint_conbin, &isnull);
 
-					attnum = get_attnum(RelationGetRelid(rel), subcmd->name);
-					seq_relid = getIdentitySequence(RelationGetRelid(rel), attnum, true);
+							if (!isnull)
+							{
+								conbin = TextDatumGetCString(val);
+								expr = stringToNode(conbin);
+								mark_function_volatile(context, expr);
+							}
 
-					tmp_obj2 = new_objtree("");
-					if (OidIsValid(seq_relid))
-					{
-						seqdef = deparse_ColumnIdentity(seq_relid, identity, true);
-						append_object_object(tmp_obj2, "%{definition}s", seqdef);
+							ReleaseSysCache(tup);
+						}
 					}
-					else
-						append_not_present(tmp_obj2, "%{definition}s");
 
-					append_object_object(tmp_obj, "%{definition}s", tmp_obj2);
-
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
-					break;
+					new_jsonb_VA(state,
+								 "ADD CONSTRAINT %{name}I %{definition}s", false, 3,
+								 "type", jbvString, "add constraint",
+								 "name", jbvString, get_constraint_name(constrOid),
+								 "definition", jbvString,
+								 pg_get_constraintdef_string(constrOid));
 				}
-			case AT_DropIdentity:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP IDENTITY", 2,
-										"type", ObjTypeString, "drop identity",
-										"column", ObjTypeString, subcmd->name);
-
-				append_string_object(tmp_obj, "%{if_exists}s",
-									 "if_exists",
-									 subcmd->missing_ok ? "IF EXISTS" : "");
-
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-			default:
-				elog(WARNING, "unsupported alter table subtype %d",
-					 subcmd->subtype);
 				break;
-		}
-	}
 
-	table_close(rel, AccessShareLock);
+			case AT_AlterConstraint:
+				{
+					Oid			constrOid = sub->address.objectId;
+					Constraint *c = (Constraint *) subcmd->def;
 
-	if (list_length(subcmds) == 0)
-		return NULL;
+					/* If no constraint was altered, silently skip it */
+					if (!OidIsValid(constrOid))
+						break;
 
-	append_array_object(ret, "%{subcmds:, }s", subcmds);
+					Assert(IsA(c, Constraint));
 
-	return ret;
-}
+					new_jsonb_VA(state,
+								 "ALTER CONSTRAINT %{name}I %{deferrable}s %{init_deferred}s", false, 4,
+								 "type", jbvString, "alter constraint",
+								 "name", jbvString, get_constraint_name(constrOid),
+								 "deferrable", jbvString,
+								 c->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
+								 "init_deferred", jbvString,
+								 c->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
+				}
+				break;
 
-/*
- * Handle deparsing of DROP commands.
- *
- * Verbose syntax
- * DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s %{cascade}s
- */
-char *
-deparse_drop_command(const char *objidentity, const char *objecttype,
-					 Node *parsetree)
-{
-	DropStmt   *node = (DropStmt *) parsetree;
-	StringInfoData str;
-	char	   *command;
-	char	   *identity = (char *) objidentity;
-	ObjTree    *stmt;
-	ObjTree    *tmp_obj;
-	Jsonb	   *jsonb;
+			case AT_ValidateConstraint:
+				new_jsonb_VA(state,
+							 "VALIDATE CONSTRAINT %{constraint}I", false, 2,
+							 "type", jbvString, "validate constraint",
+							 "constraint", jbvString, subcmd->name);
+				break;
+
+			case AT_DropConstraint:
+				new_jsonb_VA(state,
+							 "DROP CONSTRAINT %{if_exists}s %{constraint}I %{cascade}s", false, 4,
+							 "type", jbvString, "drop constraint",
+							 "if_exists", jbvString,
+							 subcmd->missing_ok ? "IF EXISTS" : "",
+							 "constraint", jbvString, subcmd->name,
+							 "cascade", jbvString,
+							 subcmd->behavior == DROP_CASCADE ? "CASCADE" : "");
+				break;
 
-	initStringInfo(&str);
+			case AT_AlterColumnType:
+				{
+					TupleDesc	tupdesc = RelationGetDescr(rel);
+					Form_pg_attribute att;
+					ColumnDef  *def;
 
-	stmt = new_objtree_VA("DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s", 4,
-						  "objtype", ObjTypeString, objecttype,
-						  "concurrently", ObjTypeString,
-						  node->concurrent ? "CONCURRENTLY" : "",
-						  "if_exists", ObjTypeString,
-						  node->missing_ok ? "IF EXISTS" : "",
-						  "objidentity", ObjTypeString, identity);
+					att = &(tupdesc->attrs[sub->address.objectSubId - 1]);
+					def = (ColumnDef *) subcmd->def;
+					Assert(IsA(def, ColumnDef));
 
-	tmp_obj = new_objtree("CASCADE");
-	if (node->behavior != DROP_CASCADE)
-		append_not_present(tmp_obj, NULL);
-	append_object_object(stmt, "%{cascade}s", tmp_obj);
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state,
+								 "ALTER COLUMN %{column}I SET DATA TYPE %{datatype}T %{collation}s %{using}s", true, 2,
+								 "type", jbvString, "alter column type",
+								 "column", jbvString, subcmd->name);
 
-	jsonb = objtree_to_jsonb(stmt, NULL /* Owner/role can be skipped for drop command */);
-	command = JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
+					insert_jsonb_key(state, "datatype");
 
-	return command;
-}
+					new_jsonb_for_type(state, att->atttypid, att->atttypmod);
 
-/*
- * Deparse an AlterObjectSchemaStmt (ALTER ... SET SCHEMA command)
- *
- * Given the object address and the parse tree that created it, return an
- * ObjTree representing the alter command.
- *
- * Verbose syntax
- * ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I
- */
-static ObjTree *
-deparse_AlterObjectSchemaStmt(ObjectAddress address, Node *parsetree,
-							  ObjectAddress old_schema)
-{
-	AlterObjectSchemaStmt *node = (AlterObjectSchemaStmt *) parsetree;
-	char	   *identity;
-	char	   *new_schema = node->newschema;
-	char	   *old_schname;
-	char	   *ident;
+					/* Add a COLLATE clause, if needed */
+					insert_jsonb_key(state, "collation");
+					if (OidIsValid(att->attcollation))
+						insert_collate_object(state, "COLLATE %{name}D",
+											  CollationRelationId, att->attcollation, "name");
+					else
+						insert_not_present_obj(state, verbose ? "COLLATE %{name}D" : "COLLATE");
 
-	/*
-	 * Since the command has already taken place from the point of view of
-	 * catalogs, getObjectIdentity returns the object name with the already
-	 * changed schema.  The output of our deparsing must return the original
-	 * schema name, however, so we chop the schema name off the identity
-	 * string and then prepend the quoted schema name.
-	 *
-	 * XXX This is pretty clunky. Can we do better?
-	 */
-	identity = getObjectIdentity(&address, false);
-	old_schname = get_namespace_name(old_schema.objectId);
-	if (!old_schname)
-		elog(ERROR, "cache lookup failed for schema with OID %u",
-			 old_schema.objectId);
+					/*
+					 * If there's a USING clause, transformAlterTableStmt ran
+					 * it through transformExpr and stored the resulting node
+					 * in cooked_default, which we can use here.
+					 */
+					insert_jsonb_key(state, "using");
+					if (def->raw_default)
+					{
+						insert_str_object(state, "USING %{expression}s",
+										  "expression", sub->usingexpr);
+						mark_function_volatile(context, def->cooked_default);
+					}
+					else
+						insert_not_present_obj(state,
+											   verbose ? "USING %{expression}s" : "USING");
 
-	ident = psprintf("%s%s", quote_identifier(old_schname),
-					 identity + strlen(quote_identifier(new_schema)));
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				}
+				break;
 
-	return new_objtree_VA("ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I", 3,
-						  "objtype", ObjTypeString,
-						  stringify_objtype(node->objectType, false),
-						  "identity", ObjTypeString, ident,
-						  "newschema", ObjTypeString, new_schema);
-}
+#ifdef TODOLIST
+			case AT_AlterColumnGenericOptions:
+				tmp_obj = deparse_FdwOptions((List *) subcmd->def,
+											 subcmd->name);
+				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				break;
+#endif
 
-/*
- * Deparse an AlterOwnerStmt (ALTER ... OWNER TO ...).
- *
- * Given the object address and the parse tree that created it, return an
- * ObjTree representing the alter command.
- *
- * Verbose syntax
- * ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I
- */
-static ObjTree *
-deparse_AlterOwnerStmt(ObjectAddress address, Node *parsetree)
-{
-	AlterOwnerStmt *node = (AlterOwnerStmt *) parsetree;
+			case AT_ChangeOwner:
+				new_jsonb_VA(state,
+							 "OWNER TO %{owner}I", false, 2,
+							 "type", jbvString, "change owner",
+							 "owner", jbvString,
+							 get_rolespec_name(subcmd->newowner));
+				break;
 
-	return new_objtree_VA("ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I", 3,
-						  "objtype", ObjTypeString,
-						  stringify_objtype(node->objectType, false),
-						  "identity", ObjTypeString,
-						  getObjectIdentity(&address, false),
-						  "newowner", ObjTypeString,
-						  get_rolespec_name(node->newowner));
-}
+			case AT_ClusterOn:
+				new_jsonb_VA(state,
+							 "CLUSTER ON %{index}I", false, 2,
+							 "type", jbvString, "cluster on",
+							 "index", jbvString, subcmd->name);
+				break;
 
-/*
- * Deparse an AlterSeqStmt.
- *
- * Given a sequence OID and a parse tree that modified it, return an ObjTree
- * representing the alter command.
- *
- * Note: We need to deparse the ALTER SEQUENCE command for the TABLE commands.
- * For example, When creating a table, if we specify a column as a sequence
- * type, then we will create a sequence for that column and set that sequence
- * OWNED BY the table.
- *
- * Verbose syntax
- * ALTER SEQUENCE %{identity}D %{definition: }s
- */
-static ObjTree *
-deparse_AlterSeqStmt(Oid objectId, Node *parsetree)
-{
-	ObjTree    *ret;
-	Relation	relation;
-	List	   *elems = NIL;
-	ListCell   *cell;
-	Form_pg_sequence seqform;
-	Sequence_values *seqvalues;
-	AlterSeqStmt *alterSeqStmt = (AlterSeqStmt *) parsetree;
 
-	/*
-	 * Sequence for IDENTITY COLUMN output separately (via CREATE TABLE or
-	 * ALTER TABLE); return empty here.
-	 */
-	if (alterSeqStmt->for_identity)
-		return NULL;
+			case AT_DropCluster:
+				new_jsonb_VA(state,
+							 "SET WITHOUT CLUSTER", false, 1,
+							 "type", jbvString, "set without cluster");
+				break;
 
-	seqvalues = get_sequence_values(objectId);
-	seqform = seqvalues->seqform;
+			case AT_SetLogged:
+				new_jsonb_VA(state,
+							 "SET LOGGED", false, 1,
+							 "type", jbvString, "set logged");
+				break;
 
-	foreach(cell, ((AlterSeqStmt *) parsetree)->options)
-	{
-		DefElem    *elem = (DefElem *) lfirst(cell);
-		ObjElem    *newelm;
+			case AT_SetUnLogged:
+				new_jsonb_VA(state,
+							 "SET UNLOGGED", false, 1,
+							 "type", jbvString, "set unlogged");
+				break;
 
-		if (strcmp(elem->defname, "cache") == 0)
-			newelm = deparse_Seq_Cache(seqform, false);
-		else if (strcmp(elem->defname, "cycle") == 0)
-			newelm = deparse_Seq_Cycle(seqform, false);
-		else if (strcmp(elem->defname, "increment") == 0)
-			newelm = deparse_Seq_IncrementBy(seqform, false);
-		else if (strcmp(elem->defname, "minvalue") == 0)
-			newelm = deparse_Seq_Minvalue(seqform, false);
-		else if (strcmp(elem->defname, "maxvalue") == 0)
-			newelm = deparse_Seq_Maxvalue(seqform, false);
-		else if (strcmp(elem->defname, "start") == 0)
-			newelm = deparse_Seq_Startwith(seqform, false);
-		else if (strcmp(elem->defname, "restart") == 0)
-			newelm = deparse_Seq_Restart(seqvalues->last_value);
-		else if (strcmp(elem->defname, "owned_by") == 0)
-			newelm = deparse_Seq_OwnedBy(objectId, false);
-		else if (strcmp(elem->defname, "as") == 0)
-			newelm = deparse_Seq_As(seqform);
-		else
-			elog(ERROR, "invalid sequence option %s", elem->defname);
+			case AT_DropOids:
+				new_jsonb_VA(state,
+							 "SET WITHOUT OIDS", false, 1,
+							 "type", jbvString, "set without oids");
+				break;
 
-		elems = lappend(elems, newelm);
-	}
+			case AT_SetAccessMethod:
+				new_jsonb_VA(state,
+							 "SET ACCESS METHOD %{access_method}I", false, 2,
+							 "type", jbvString, "set access method",
+							 "access_method", jbvString, subcmd->name);
+				break;
 
-	relation = relation_open(objectId, AccessShareLock);
+			case AT_SetTableSpace:
+				new_jsonb_VA(state,
+							 "SET TABLESPACE %{tablespace}I", false, 2,
+							 "type", jbvString, "set tablespace",
+							 "tablespace", jbvString, subcmd->name);
+				break;
 
-	ret = new_objtree_VA("ALTER SEQUENCE %{identity}D %{definition: }s", 2,
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(relation->rd_rel->relnamespace,
-												  RelationGetRelationName(relation)),
-						 "definition", ObjTypeArray, elems);
+			case AT_SetRelOptions:
+			case AT_ResetRelOptions:
+				deparse_RelSetOptions_toJsonb(state, subcmd);
+				break;
 
-	relation_close(relation, AccessShareLock);
+			case AT_EnableTrig:
+				new_jsonb_VA(state, "ENABLE TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "enable trigger",
+							 "trigger", jbvString, subcmd->name);
+				break;
 
-	return ret;
-}
+			case AT_EnableAlwaysTrig:
+				new_jsonb_VA(state, "ENABLE ALWAYS TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "enable always trigger",
+							 "trigger", jbvString, subcmd->name);
+				break;
 
-/*
- * Deparse a RenameStmt.
- *
- * Verbose syntax
- * ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I
- * OR
- * ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I
- * OR
- * ALTER %{objtype}s %{if_exists}s %{only}s %{identity}D RENAME COLUMN %{colname}I TO %{newname}I %{cascade}s
- */
-static ObjTree *
-deparse_RenameStmt(ObjectAddress address, Node *parsetree)
-{
-	RenameStmt *node = (RenameStmt *) parsetree;
-	ObjTree    *ret;
-	Relation	relation;
-	Oid			schemaId;
+			case AT_EnableReplicaTrig:
+				new_jsonb_VA(state, "ENABLE REPLICA TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "enable replica trigger",
+							 "trigger", jbvString, subcmd->name);
+				break;
 
-	/*
-	 * In an ALTER .. RENAME command, we don't have the original name of the
-	 * object in system catalogs: since we inspect them after the command has
-	 * executed, the old name is already gone.  Therefore, we extract it from
-	 * the parse node.  Note we still extract the schema name from the catalog
-	 * (it might not be present in the parse node); it cannot possibly have
-	 * changed anyway.
-	 */
-	switch (node->renameType)
-	{
-		case OBJECT_TABLE:
-			relation = relation_open(address.objectId, AccessShareLock);
-			schemaId = RelationGetNamespace(relation);
-			ret = new_objtree_VA("ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I", 4,
-								 "objtype", ObjTypeString,
-								 stringify_objtype(node->renameType, false),
-								 "if_exists", ObjTypeString,
-								 node->missing_ok ? "IF EXISTS" : "",
-								 "identity", ObjTypeObject,
-								 new_objtree_for_qualname(schemaId,
-														  node->relation->relname),
-								 "newname", ObjTypeString,
-								 node->newname);
-			relation_close(relation, AccessShareLock);
-			break;
+			case AT_DisableTrig:
+				new_jsonb_VA(state, "DISABLE TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "disable trigger",
+							 "trigger", jbvString, subcmd->name);
+				break;
 
-		case OBJECT_TABCONSTRAINT:
-			{
-				HeapTuple	constrtup;
-				Form_pg_constraint constform;
+			case AT_EnableTrigAll:
+				new_jsonb_VA(state, "ENABLE TRIGGER ALL", false, 1,
+							 "type", jbvString, "enable trigger all");
+				break;
 
-				constrtup = SearchSysCache1(CONSTROID,
-											ObjectIdGetDatum(address.objectId));
-				if (!HeapTupleIsValid(constrtup))
-					elog(ERROR, "cache lookup failed for constraint with OID %u",
-						 address.objectId);
-				constform = (Form_pg_constraint) GETSTRUCT(constrtup);
+			case AT_DisableTrigAll:
+				new_jsonb_VA(state, "DISABLE TRIGGER ALL", false, 1,
+							 "type", jbvString, "disable trigger all");
+				break;
 
-				ret = new_objtree_VA("ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I", 4,
-									"only",  ObjTypeString,
-									node->relation->inh ? "" : "ONLY",
-									"identity", ObjTypeObject,
-									new_objtree_for_qualname_id(RelationRelationId,
-																constform->conrelid),
-									"oldname", ObjTypeString, node->subname,
-									"newname", ObjTypeString, node->newname);
-				ReleaseSysCache(constrtup);
-			}
-			break;
+			case AT_EnableTrigUser:
+				new_jsonb_VA(state, "ENABLE TRIGGER USER", false, 1,
+							 "type", jbvString, "enable trigger user");
+				break;
 
-		case OBJECT_COLUMN:
-			relation = relation_open(address.objectId, AccessShareLock);
-			schemaId = RelationGetNamespace(relation);
+			case AT_DisableTrigUser:
+				new_jsonb_VA(state, "DISABLE TRIGGER USER", false, 1,
+							 "type", jbvString, "disable trigger user");
+				break;
 
-			ret = new_objtree_VA("ALTER %{objtype}s", 1,
-								 "objtype", ObjTypeString,
-								 stringify_objtype(node->relationType, false));
+			case AT_EnableRule:
+				new_jsonb_VA(state, "ENABLE RULE %{rule}I", false, 2,
+							 "type", jbvString, "enable rule",
+							 "rule", jbvString, subcmd->name);
+				break;
 
-			/* Composite types do not support IF EXISTS */
-			if (node->renameType == OBJECT_COLUMN)
-				append_string_object(ret, "%{if_exists}s",
-									 "if_exists",
-									 node->missing_ok ? "IF EXISTS" : "");
-			if (!node->relation->inh)
-				append_string_object(ret, "%{only}s",
-									 "only",
-									 "ONLY");
-			append_object_object(ret, "%{identity}D",
-								 new_objtree_for_qualname(schemaId,
-														  node->relation->relname));
-			append_string_object(ret, "RENAME COLUMN %{colname}I",
-								 "colname", node->subname);
+			case AT_EnableAlwaysRule:
+				new_jsonb_VA(state, "ENABLE ALWAYS RULE %{rule}I", false, 2,
+							 "type", jbvString, "enable always rule",
+							 "rule", jbvString, subcmd->name);
+				break;
 
-			append_string_object(ret, "TO %{newname}I", "newname",
-								 node->newname);
+			case AT_EnableReplicaRule:
+				new_jsonb_VA(state, "ENABLE REPLICA RULE %{rule}I", false, 2,
+							 "type", jbvString, "enable replica rule",
+							 "rule", jbvString, subcmd->name);
+				break;
 
-			if (node->renameType == OBJECT_ATTRIBUTE)
-			{
-				ObjTree	   *tmp_obj = new_objtree("CASCADE");
+			case AT_DisableRule:
+				new_jsonb_VA(state, "DISABLE RULE %{rule}I", false, 2,
+							 "type", jbvString, "disable rule",
+							 "rule", jbvString, subcmd->name);
+				break;
 
-				if (node->behavior != DROP_CASCADE)
-					append_not_present(tmp_obj, NULL);
-				append_object_object(ret, "%{cascade}s", tmp_obj);
-			}
+			case AT_AddInherit:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "INHERIT %{parent}D", true, 1,
+							 "type", jbvString, "inherit");
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "parent");
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				break;
 
-			relation_close(relation, AccessShareLock);
-			break;
+			case AT_DropInherit:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "NO INHERIT %{parent}D", true, 1,
+							 "type", jbvString, "drop inherit");
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "parent");
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				break;
 
-		default:
-			elog(ERROR, "unsupported object type %d", node->renameType);
-	}
+			case AT_AddOf:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "OF %{type_of}T", true, 1,
+							 "type", jbvString, "add of");
+				insert_jsonb_key(state, "type_of");
+				new_jsonb_for_type(state, sub->address.objectId, -1);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				break;
 
-	return ret;
-}
+			case AT_DropOf:
+				new_jsonb_VA(state, "NOT OF", false, 1,
+							 "type", jbvString, "not of");
+				break;
 
-/*
- * Handle deparsing of simple commands.
- *
- * This function should cover all cases handled in ProcessUtilitySlow.
- */
-static ObjTree *
-deparse_simple_command(CollectedCommand *cmd, bool *include_owner)
-{
-	Oid			objectId;
-	Node	   *parsetree;
+			case AT_ReplicaIdentity:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "REPLICA IDENTITY %{ident}s", true, 1,
+							 "type", jbvString, "replica identity");
+				switch (((ReplicaIdentityStmt *) subcmd->def)->identity_type)
+				{
+					case REPLICA_IDENTITY_DEFAULT:
+						insert_jsonb_str_element(state, "ident", "DEFAULT");
+						break;
+					case REPLICA_IDENTITY_FULL:
+						insert_jsonb_str_element(state, "ident", "FULL");
+						break;
+					case REPLICA_IDENTITY_NOTHING:
+						insert_jsonb_str_element(state, "ident", "NOTHING");
+						break;
+					case REPLICA_IDENTITY_INDEX:
+						insert_jsonb_key(state, "ident");
+						new_jsonb_VA(state, "USING INDEX %{index}I", false, 1,
+									 "index", jbvString,
+									 ((ReplicaIdentityStmt *) subcmd->def)->name);
+						break;
+				}
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				break;
 
-	Assert(cmd->type == SCT_Simple);
+			case AT_EnableRowSecurity:
+				new_jsonb_VA(state, "ENABLE ROW LEVEL SECURITY", false, 1,
+							 "type", jbvString, "enable row security");
+				break;
 
-	parsetree = cmd->parsetree;
-	objectId = cmd->d.simple.address.objectId;
+			case AT_DisableRowSecurity:
+				new_jsonb_VA(state, "DISABLE ROW LEVEL SECURITY", false, 1,
+							 "type", jbvString, "disable row security");
+				break;
+#ifdef TODOLIST
+			case AT_GenericOptions:
+				tmp_obj = deparse_FdwOptions((List *) subcmd->def, NULL);
+				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				break;
+#endif
+			case AT_AttachPartition:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "ATTACH PARTITION %{partition_identity}D %{partition_bound}s", true,
+							 1, "type", jbvString, "attach partition");
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "partition_identity");
 
-	if (cmd->in_extension && (nodeTag(parsetree) != T_CreateExtensionStmt))
-		return NULL;
+				if (rel->rd_rel->relkind == RELKIND_PARTITIONED_TABLE)
+					insert_jsonb_str_element(state, "partition_bound", RelationGetPartitionBound(sub->address.objectId));
+				else
+					insert_jsonb_str_element(state, "partition_bound", "");
 
-	/* This switch needs to handle everything that ProcessUtilitySlow does */
-	switch (nodeTag(parsetree))
-	{
-		case T_AlterObjectSchemaStmt:
-			*include_owner = false;
-			return deparse_AlterObjectSchemaStmt(cmd->d.simple.address,
-												 parsetree,
-												 cmd->d.simple.secondaryObject);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-		case T_AlterOwnerStmt:
-			*include_owner = false;
-			return deparse_AlterOwnerStmt(cmd->d.simple.address, parsetree);
+				break;
+			case AT_DetachPartition:
+				{
+					PartitionCmd *cmd;
+
+					Assert(IsA(subcmd->def, PartitionCmd));
+					cmd = (PartitionCmd *) subcmd->def;
+
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state, "DETACH PARTITION %{partition_identity}D %{concurrent}s", true, 2,
+								 "type", jbvString, "detach partition",
+								 "concurrent", jbvString,
+								 cmd->concurrent ? "CONCURRENTLY" : "");
+					new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "partition_identity");
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+					break;
+				}
+			case AT_DetachPartitionFinalize:
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "DETACH PARTITION %{partition_identity}D FINALIZE", true, 1,
+							 "type", ObjTypeString, "detach partition finalize");
 
-		case T_AlterSeqStmt:
-			return deparse_AlterSeqStmt(objectId, parsetree);
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "partition_identity");
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				break;
+			case AT_AddIdentity:
+				{
+					AttrNumber	attnum;
+					Oid			seq_relid;
+					ColumnDef  *coldef = (ColumnDef *) subcmd->def;
 
-		case T_CreateSeqStmt:
-			return deparse_CreateSeqStmt(objectId, parsetree);
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state, "ALTER COLUMN %{column}I %{definition}s", true, 2,
+								 "type", jbvString, "add identity",
+								 "column", jbvString, subcmd->name);
 
-		case T_CreateStmt:
-			return deparse_CreateStmt(objectId, parsetree);
+					attnum = get_attnum(RelationGetRelid(rel), subcmd->name);
+					seq_relid = getIdentitySequence(RelationGetRelid(rel), attnum, true);
 
-		case T_RenameStmt:
-			*include_owner = false;
-			return deparse_RenameStmt(cmd->d.simple.address, parsetree);
+					insert_jsonb_key(state, "definition");
+					if (OidIsValid(seq_relid))
+					{
+						/* insert definition's value now */
+						pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-		default:
-			elog(LOG, "unrecognized node type in deparse command: %d",
-				 (int) nodeTag(parsetree));
-	}
+						fmt_to_jsonb_element(state, "ADD %{identity_column}s");
 
-	return NULL;
-}
+						/* insert identity_column as key */
+						insert_jsonb_key(state, "identity_column");
 
-/*
- * Workhorse to deparse a CollectedCommand.
- */
-char *
-deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context)
-{
-	OverrideSearchPath *overridePath;
-	MemoryContext oldcxt;
-	MemoryContext tmpcxt;
-	ObjTree    *tree;
-	char	   *command = NULL;
-	StringInfoData str;
+						/* insert identity_column's value */
+						deparse_ColumnIdentity_toJsonb(state, seq_relid, coldef->identity, false);
 
-	/*
-	 * Allocate everything done by the deparsing routines into a temp context,
-	 * to avoid having to sprinkle them with memory handling code, but
-	 * allocate the output StringInfo before switching.
-	 */
-	initStringInfo(&str);
-	tmpcxt = AllocSetContextCreate(CurrentMemoryContext,
-								   "deparse ctx",
-								   ALLOCSET_DEFAULT_MINSIZE,
-								   ALLOCSET_DEFAULT_INITSIZE,
-								   ALLOCSET_DEFAULT_MAXSIZE);
-	oldcxt = MemoryContextSwitchTo(tmpcxt);
+						/* mark definition's value end */
+						pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+					}
+					else
+						insert_not_present_obj(state, verbose ? "ADD %{identity_column}s" : "ADD");
 
-	/*
-	 * Many routines underlying this one will invoke ruleutils.c functionality
-	 * to obtain deparsed versions of expressions.  In such results, we want
-	 * all object names to be qualified, so that results are "portable" to
-	 * environments with different search_path settings.  Rather than
-	 * injecting what would be repetitive calls to override search path all
-	 * over the place, we do it centrally here.
-	 */
-	overridePath = GetOverrideSearchPath(CurrentMemoryContext);
-	overridePath->schemas = NIL;
-	overridePath->addCatalog = false;
-	overridePath->addTemp = true;
-	PushOverrideSearchPath(overridePath);
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+				}
+				break;
+			case AT_SetIdentity:
+				{
+					DefElem    *defel;
+					char		identity = 0;
+					AttrNumber	attnum;
+					Oid			seq_relid;
 
-	verbose = context->verbose_mode;
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state, "ALTER COLUMN %{column}I %{definition}s", true, 2,
+								 "type", jbvString, "set identity",
+								 "column", jbvString, subcmd->name);
 
-	switch (cmd->type)
-	{
-		case SCT_Simple:
-			tree = deparse_simple_command(cmd, &context->include_owner);
-			break;
-		case SCT_AlterTable:
-			tree = deparse_AlterRelation(cmd, context);
-			context->include_owner = false;
-			break;
-		case SCT_CreateTableAs:
-			tree = deparse_CreateTableAsStmt(cmd);
-			break;
-		default:
-			elog(ERROR, "unexpected deparse node type %d", cmd->type);
-	}
+					if (subcmd->def)
+					{
+						List	   *def = (List *) subcmd->def;
 
-	PopOverrideSearchPath();
+						Assert(IsA(subcmd->def, List));
 
-	if (tree)
-	{
-		Jsonb	   *jsonb;
+						defel = linitial_node(DefElem, def);
+						identity = defGetInt32(defel);
+					}
 
-		jsonb = context->include_owner ? objtree_to_jsonb(tree, cmd->role) :
-										 objtree_to_jsonb(tree, NULL);
-		command = JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
+					attnum = get_attnum(RelationGetRelid(rel), subcmd->name);
+					seq_relid = getIdentitySequence(RelationGetRelid(rel), attnum, true);
+
+					insert_jsonb_key(state, "definition");
+					if (OidIsValid(seq_relid))
+					{
+						deparse_ColumnIdentity_toJsonb(state, seq_relid, identity, true);
+					}
+					else
+						insert_not_present_obj(state, verbose ? "%{definition}s" : "");
+
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+					break;
+				}
+			case AT_DropIdentity:
+				{
+					new_jsonb_VA(state, "ALTER COLUMN %{column}I DROP IDENTITY %{if_exists}s", false, 3,
+								 "type", jbvString, "drop identity",
+								 "column", jbvString, subcmd->name,
+								 "if_exists", jbvString, subcmd->missing_ok ? "IF EXISTS" : "");
+					break;
+				}
+			default:
+				elog(WARNING, "unsupported alter table subtype %d",
+					 subcmd->subtype);
+				break;
+		}
 	}
 
-	/*
-	 * Clean up.  Note that since we created the StringInfo in the caller's
-	 * context, the output string is not deleted here.
-	 */
-	MemoryContextSwitchTo(oldcxt);
-	MemoryContextDelete(tmpcxt);
+	table_close(rel, AccessShareLock);
 
-	return command;
-}
+	/* sub commands not found, return NULL */
+	if (!subCmdFound)
+		return NULL;
 
-/*
- * Given a CollectedCommand, return a JSON representation of it.
- *
- * The command is expanded fully so that there are no ambiguities even in the
- * face of search_path changes.
- */
-Datum
-ddl_deparse_to_json(PG_FUNCTION_ARGS)
-{
-	CollectedCommand *cmd = (CollectedCommand *) PG_GETARG_POINTER(0);
-	char	   *command;
-	ddl_deparse_context context;
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+	appendStringInfoString(&fmtStr, "%{subcmds:, }s");
 
-	context.verbose_mode = true;
-	context.include_owner = false;
-	context.func_volatile = PROVOLATILE_IMMUTABLE;
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
 
-	command = deparse_utility_command(cmd, &context);
+	pfree(fmtStr.data);
 
-	if (command)
-		PG_RETURN_TEXT_P(cstring_to_text(command));
+	/* Mark the end of ROOT object */
+	value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-	PG_RETURN_NULL();
+	return JsonbValueToJsonb(value);
 }
diff --git a/src/backend/replication/logical/ddltrigger.c b/src/backend/replication/logical/ddltrigger.c
index 94161a0497..be1c6b40c9 100644
--- a/src/backend/replication/logical/ddltrigger.c
+++ b/src/backend/replication/logical/ddltrigger.c
@@ -282,12 +282,15 @@ publication_deparse_ddl_command_end(PG_FUNCTION_ARGS)
 		else
 			continue;
 
-		command = deparse_drop_command(obj->objidentity, obj->objecttype,
+		command = deparse_drop_table(obj->objidentity, obj->objecttype,
 									   trigdata->parsetree);
 
 		if (command)
+		{
 			LogLogicalDDLMessage("deparse", obj->address.objectId, cmdtype,
 								 command, strlen(command) + 1);
+			elog(LOG, "COMMAND = %s", command);
+		}
 	}
 
 	return PointerGetDatum(NULL);
diff --git a/src/include/tcop/ddldeparse.h b/src/include/tcop/ddldeparse.h
index 1cceb53662..19b1274859 100644
--- a/src/include/tcop/ddldeparse.h
+++ b/src/include/tcop/ddldeparse.h
@@ -32,7 +32,7 @@ typedef struct
 
 extern char *deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context);
 extern char *deparse_ddl_json_to_string(char *jsonb, char** owner);
-extern char *deparse_drop_command(const char *objidentity, const char *objecttype,
-								  Node *parsetree);
+extern char *deparse_drop_table(const char *objidentity, const char *objecttype,
+										   Node *parsetree);
 
 #endif							/* DDL_DEPARSE_H */
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out b/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out
index 9b22999cd9..c78007469b 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out
@@ -7,18 +7,18 @@ CREATE TABLE orders(
     quantity int,
     purchase_date date
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "orders", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.orders (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "orders", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.orders (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- ALTER TABLE [ IF EXISTS ] [ ONLY ] name [ * ]
 --     action [, ... ]
 CREATE TABLE parent_table(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "parent_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.parent_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "parent_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.parent_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE TABLE test_only () INHERITS (parent_table);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_only", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "parent_table", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_only () INHERITS (public.parent_table)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_only", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "parent_table", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_only () INHERITS (public.parent_table)    
 ALTER TABLE test_only ADD col1 int;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD %{objtype}s %{if_not_exists}s %{definition}s", "type": "add column", "objtype": "COLUMN", "definition": {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, "if_not_exists": ""}], "identity": {"objname": "test_only", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_only ADD COLUMN  col1 pg_catalog.int4 STORAGE PLAIN      
@@ -32,8 +32,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.parent_table ADD CONSTRAINT pare
 CREATE TABLE test_add_column(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_add_column ADD col1 int;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD %{objtype}s %{if_not_exists}s %{definition}s", "type": "add column", "objtype": "COLUMN", "definition": {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, "if_not_exists": ""}], "identity": {"objname": "test_add_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_add_column ADD COLUMN  col1 pg_catalog.int4 STORAGE PLAIN      
@@ -59,14 +59,14 @@ CREATE TABLE test_drop_column(
     UNIQUE (id),
     UNIQUE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_column_id_key UNIQUE (id), CONSTRAINT test_drop_column_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_column_id_key UNIQUE (id), CONSTRAINT test_drop_column_name_key UNIQUE (name))     
 CREATE TABLE foreign_table(
     id int REFERENCES test_drop_column (id),
     name varchar REFERENCES test_drop_column (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "foreign_table_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.test_drop_column(id)"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "foreign_table_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.test_drop_column(name)"}], "identity": {"objname": "foreign_table", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.foreign_table ADD CONSTRAINT foreign_table_id_fkey FOREIGN KEY (id) REFERENCES public.test_drop_column(id), ADD CONSTRAINT foreign_table_name_fkey FOREIGN KEY (name) REFERENCES public.test_drop_column(name)
 ALTER TABLE test_drop_column DROP price;
@@ -84,8 +84,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_drop_column DROP COLUMN IF
 CREATE TABLE test_alter_type(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_alter_type ALTER price TYPE int;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET DATA TYPE %{datatype}T %{collation}s %{using}s", "type": "alter column type", "using": {"fmt": "USING %{expression}s", "present": false}, "column": "price", "datatype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "collation": {"fmt": "COLLATE %{name}D", "present": false}}], "identity": {"objname": "test_alter_type", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_type ALTER COLUMN price SET DATA TYPE pg_catalog.int4  
@@ -105,8 +105,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_alter_type ALTER COLUMN nam
 CREATE TABLE test_alter_set_default(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_alter_set_default ALTER price SET DEFAULT 100;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET DEFAULT %{definition}s", "type": "set default", "column": "price", "definition": "100"}], "identity": {"objname": "test_alter_set_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_set_default ALTER COLUMN price SET DEFAULT 100
@@ -119,8 +119,8 @@ CREATE TABLE test_drop_default(
     default_price float4 DEFAULT 10.0,
     default_name varchar DEFAULT 'foo'
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "10.0"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , default_price pg_catalog.float4 STORAGE PLAIN    DEFAULT 10.0  , default_name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "10.0"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , default_price pg_catalog.float4 STORAGE PLAIN    DEFAULT 10.0  , default_name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )     
 ALTER TABLE test_drop_default ALTER default_price DROP DEFAULT;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I DROP DEFAULT", "type": "drop default", "column": "default_price"}], "identity": {"objname": "test_drop_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_default ALTER COLUMN default_price DROP DEFAULT
@@ -132,8 +132,8 @@ CREATE TABLE test_set_not_null(
     LIKE orders,
     size int NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "size", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_not_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , size pg_catalog.int4 STORAGE PLAIN   NOT NULL   )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "size", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_not_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , size pg_catalog.int4 STORAGE PLAIN   NOT NULL   )     
 ALTER TABLE test_set_not_null ALTER COLUMN id SET NOT NULL;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "test_set_not_null", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_not_null ALTER COLUMN id SET NOT NULL
@@ -145,8 +145,8 @@ CREATE TABLE test_drop_expression(
     LIKE orders,
     new_id int GENERATED ALWAYS AS ( 3 * ID ) STORED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "new_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(3 OPERATOR(pg_catalog.*) id)"}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , new_id pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((3 OPERATOR(pg_catalog.*) id)) STORED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "new_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(3 OPERATOR(pg_catalog.*) id)"}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , new_id pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((3 OPERATOR(pg_catalog.*) id)) STORED)     
 ALTER TABLE test_drop_expression ALTER new_id DROP EXPRESSION;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", "type": "drop expression", "column": "new_id", "if_exists": ""}], "identity": {"objname": "test_drop_expression", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_expression ALTER COLUMN new_id DROP EXPRESSION 
@@ -161,8 +161,8 @@ CREATE TABLE test_add_generated(
     col2 int NOT NULL,
     col3 int NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , col1 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col2 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col3 pg_catalog.int4 STORAGE PLAIN   NOT NULL   )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , col1 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col2 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col3 pg_catalog.int4 STORAGE PLAIN   NOT NULL   )     
 ALTER TABLE test_add_generated ALTER col1 ADD GENERATED ALWAYS AS IDENTITY;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
@@ -208,8 +208,8 @@ NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_generated (id1 pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id2 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id3 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id4 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id5 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id6 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id7 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_generated (id1 pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id2 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id3 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id4 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id5 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id6 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id7 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 NOTICE:  deparsed json: <NULL>
@@ -227,37 +227,37 @@ NOTICE:  re-formed command: <NULL>
 ALTER TABLE test_set_generated ALTER id1 SET GENERATED ALWAYS;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id1", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "ALWAYS"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id1", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "ALWAYS"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id1 SET GENERATED ALWAYS SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id2 SET GENERATED BY DEFAULT;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id2", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id2", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id2 SET GENERATED BY DEFAULT SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id3 SET INCREMENT BY 10;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id3", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id3", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id3  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 10 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id4 RESTART;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id4", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id4", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id4  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id5 RESTART WITH 101;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id5", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "101", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id5", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "101", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id5  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 101
 ALTER TABLE test_set_generated ALTER id6 RESTART WITH 201;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id6", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "201", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id6", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "201", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id6  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 201
 ALTER TABLE test_set_generated ALTER COLUMN id7 SET GENERATED BY DEFAULT SET INCREMENT BY 100 RESTART WITH 301;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id7", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "100", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "301", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id7", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "100", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "301", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id7 SET GENERATED BY DEFAULT SET CACHE 1 SET NO CYCLE SET INCREMENT BY 100 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 301
 -- ALTER [ COLUMN ] column_name DROP IDENTITY [ IF EXISTS ]
 CREATE TABLE test_drop_identity(
@@ -266,8 +266,8 @@ CREATE TABLE test_drop_identity(
 );
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_identity (id pg_catalog.int4 STORAGE PLAIN      , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_identity (id pg_catalog.int4 STORAGE PLAIN      , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 ALTER TABLE test_drop_identity ALTER id_generated DROP IDENTITY;
@@ -281,8 +281,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_drop_identity ALTER COLUMN
 CREATE TABLE test_set_statistics(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_statistics ALTER id SET STATISTICS 1;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", "type": "set statistics", "column": "id", "statistics": 1}], "identity": {"objname": "test_set_statistics", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_statistics ALTER COLUMN id SET STATISTICS 1
@@ -290,8 +290,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_statistics ALTER COLUMN
 CREATE TABLE test_set_attribute(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_attribute ALTER name SET (n_distinct = 102);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{option}s (%{options:, }s)", "column": "name", "option": "SET", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "n_distinct"}, "value": "102"}]}], "identity": {"objname": "test_set_attribute", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_attribute ALTER COLUMN name SET (n_distinct = '102')
@@ -302,8 +302,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_attribute ALTER COLUMN
 CREATE TABLE test_reset_attribute(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_reset_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_reset_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_reset_attribute ALTER name RESET (n_distinct);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{option}s (%{options:, }s)", "column": "name", "option": "RESET", "options": [{"fmt": "%{label}s", "label": {"fmt": "%{label}I", "label": "n_distinct"}}]}], "identity": {"objname": "test_reset_attribute", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_reset_attribute ALTER COLUMN name RESET (n_distinct)
@@ -315,8 +315,8 @@ CREATE TABLE test_set_storage(
     LIKE orders,
     product_name text
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , product_name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , product_name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 ALTER TABLE test_set_storage ALTER id SET STORAGE PLAIN;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STORAGE %{storage}s", "type": "set storage", "column": "id", "storage": "plain"}], "identity": {"objname": "test_set_storage", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage ALTER COLUMN id SET STORAGE plain
@@ -333,8 +333,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage ALTER COLUMN pr
 CREATE TABLE test_set_compression(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_compression ALTER name SET COMPRESSION "pglz";
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET COMPRESSION %{compression_method}s", "type": "set compression", "column": "name", "compression_method": "pglz"}], "identity": {"objname": "test_set_compression", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_compression ALTER COLUMN name SET COMPRESSION pglz
@@ -345,8 +345,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_compression ALTER COLUM
 CREATE TABLE test_add_table_constraint(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_table_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_table_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_table_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_table_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_add_table_constraint ADD PRIMARY KEY (id);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "test_add_table_constraint_pkey", "type": "add constraint", "definition": "PRIMARY KEY (id)"}], "identity": {"objname": "test_add_table_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_add_table_constraint ALTER COLUMN id SET NOT NULL, ADD CONSTRAINT test_add_table_constraint_pkey PRIMARY KEY (id)
@@ -384,8 +384,8 @@ CREATE TABLE test_alter_constraint_referenced(
     id3 int UNIQUE,
     id4 int UNIQUE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_referenced", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id1_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id1)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id2_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id2)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id3_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id3)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id4_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id4)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_referenced (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT test_alter_constraint_referenced_id1_key UNIQUE (id1), CONSTRAINT test_alter_constraint_referenced_id2_key UNIQUE (id2), CONSTRAINT test_alter_constraint_referenced_id3_key UNIQUE (id3), CONSTRAINT test_alter_constraint_referenced_id4_key UNIQUE (id4))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_referenced", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id1_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id1)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id2_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id2)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id3_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id3)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id4_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id4)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_referenced (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT test_alter_constraint_referenced_id1_key UNIQUE (id1), CONSTRAINT test_alter_constraint_referenced_id2_key UNIQUE (id2), CONSTRAINT test_alter_constraint_referenced_id3_key UNIQUE (id3), CONSTRAINT test_alter_constraint_referenced_id4_key UNIQUE (id4))     
 CREATE TABLE test_alter_constraint(
     id1 int,
     id2 int,
@@ -397,8 +397,8 @@ CREATE TABLE test_alter_constraint(
     CONSTRAINT alter_cstr3 FOREIGN KEY (id3) REFERENCES test_alter_constraint_referenced (id3) DEFERRABLE INITIALLY DEFERRED,
     CONSTRAINT alter_cstr4 FOREIGN KEY (id4) REFERENCES test_alter_constraint_referenced (id4) DEFERRABLE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr1", "type": "add constraint", "definition": "FOREIGN KEY (id1) REFERENCES public.test_alter_constraint_referenced(id1) DEFERRABLE INITIALLY DEFERRED"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr2", "type": "add constraint", "definition": "FOREIGN KEY (id2) REFERENCES public.test_alter_constraint_referenced(id2)"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr3", "type": "add constraint", "definition": "FOREIGN KEY (id3) REFERENCES public.test_alter_constraint_referenced(id3) DEFERRABLE INITIALLY DEFERRED"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr4", "type": "add constraint", "definition": "FOREIGN KEY (id4) REFERENCES public.test_alter_constraint_referenced(id4) DEFERRABLE"}], "identity": {"objname": "test_alter_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint ADD CONSTRAINT alter_cstr1 FOREIGN KEY (id1) REFERENCES public.test_alter_constraint_referenced(id1) DEFERRABLE INITIALLY DEFERRED, ADD CONSTRAINT alter_cstr2 FOREIGN KEY (id2) REFERENCES public.test_alter_constraint_referenced(id2), ADD CONSTRAINT alter_cstr3 FOREIGN KEY (id3) REFERENCES public.test_alter_constraint_referenced(id3) DEFERRABLE INITIALLY DEFERRED, ADD CONSTRAINT alter_cstr4 FOREIGN KEY (id4) REFERENCES public.test_alter_constraint_referenced(id4) DEFERRABLE
 ALTER TABLE test_alter_constraint ALTER CONSTRAINT alter_cstr1 NOT DEFERRABLE;
@@ -417,8 +417,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint ALTER CONS
 CREATE TABLE test_validate_constraint(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_validate_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_validate_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_validate_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_validate_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_validate_constraint ADD CONSTRAINT test_validate_constraint_cstr CHECK (length(name) < 10) NOT VALID;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "test_validate_constraint_cstr", "type": "add constraint", "definition": "CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)) NOT VALID"}], "identity": {"objname": "test_validate_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_validate_constraint ADD CONSTRAINT test_validate_constraint_cstr CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)) NOT VALID
@@ -431,15 +431,15 @@ CREATE TABLE test_drop_constraint(
     CONSTRAINT test_drop_constraint_check CHECK (id < 100),
     CONSTRAINT test_drop_constraint_uniq UNIQUE (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.<) 100))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_uniq", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_constraint_check CHECK ((id OPERATOR(pg_catalog.<) 100)), CONSTRAINT test_drop_constraint_uniq UNIQUE (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.<) 100))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_uniq", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_constraint_check CHECK ((id OPERATOR(pg_catalog.<) 100)), CONSTRAINT test_drop_constraint_uniq UNIQUE (id))     
 CREATE TABLE test_drop_constraint_reference(
     id int REFERENCES test_drop_constraint (id),
     name varchar,
     CONSTRAINT test_drop_constraint_reference_cstr1 CHECK (length(name) < 10)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_constraint_reference", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_reference_cstr1", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint_reference (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT test_drop_constraint_reference_cstr1 CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_constraint_reference", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_reference_cstr1", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint_reference (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT test_drop_constraint_reference_cstr1 CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)))     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_reference_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.test_drop_constraint(id)"}], "identity": {"objname": "test_drop_constraint_reference", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_constraint_reference ADD CONSTRAINT test_drop_constraint_reference_id_fkey FOREIGN KEY (id) REFERENCES public.test_drop_constraint(id)
 ALTER TABLE test_drop_constraint_reference DROP CONSTRAINT test_drop_constraint_reference_cstr1;
@@ -482,8 +482,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_enable_always_rule ENABLE R
 CREATE TABLE test_disable_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_disable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_disable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_disable_row_security DISABLE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "DISABLE ROW LEVEL SECURITY", "type": "disable row security"}], "identity": {"objname": "test_disable_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_disable_row_security DISABLE ROW LEVEL SECURITY
@@ -491,8 +491,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_disable_row_security DISABL
 CREATE TABLE test_enable_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_enable_row_security ENABLE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ENABLE ROW LEVEL SECURITY", "type": "enable row security"}], "identity": {"objname": "test_enable_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_enable_row_security ENABLE ROW LEVEL SECURITY
@@ -500,8 +500,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_enable_row_security ENABLE
 CREATE TABLE test_force_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_force_row_security FORCE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "FORCE ROW LEVEL SECURITY"}], "identity": {"objname": "test_force_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_force_row_security FORCE ROW LEVEL SECURITY
@@ -509,8 +509,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_force_row_security FORCE RO
 CREATE TABLE test_no_force_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_no_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_no_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_no_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_no_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_no_force_row_security NO FORCE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "NO FORCE ROW LEVEL SECURITY"}], "identity": {"objname": "test_no_force_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_no_force_row_security NO FORCE ROW LEVEL SECURITY
@@ -519,8 +519,8 @@ CREATE TABLE test_cluster(
     LIKE orders,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_cluster_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_cluster_pkey PRIMARY KEY (id))     
 ALTER TABLE test_cluster CLUSTER ON test_cluster_pkey;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "CLUSTER ON %{index}I", "type": "cluster on", "index": "test_cluster_pkey"}], "identity": {"objname": "test_cluster", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_cluster CLUSTER ON test_cluster_pkey
@@ -529,8 +529,8 @@ CREATE TABLE test_without_cluster(
     LIKE orders,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_without_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_without_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_without_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_without_cluster_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_without_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_without_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_without_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_without_cluster_pkey PRIMARY KEY (id))     
 ALTER TABLE test_without_cluster CLUSTER ON test_without_cluster_pkey;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "CLUSTER ON %{index}I", "type": "cluster on", "index": "test_without_cluster_pkey"}], "identity": {"objname": "test_without_cluster", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_without_cluster CLUSTER ON test_without_cluster_pkey
@@ -541,8 +541,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_without_cluster SET WITHOUT
 CREATE TABLE test_set_without_oids(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_without_oids SET WITHOUT OIDS;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET WITHOUT OIDS", "type": "set without oids"}], "identity": {"objname": "test_set_without_oids", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_without_oids SET WITHOUT OIDS
@@ -550,8 +550,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_without_oids SET WITHOU
 CREATE TABLE test_set_access_method(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_access_method SET ACCESS METHOD heap;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET ACCESS METHOD %{access_method}I", "type": "set access method", "access_method": "heap"}], "identity": {"objname": "test_set_access_method", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_access_method SET ACCESS METHOD heap
@@ -559,8 +559,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_access_method SET ACCES
 CREATE TABLE test_set_tablespace(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_tablespace SET TABLESPACE pg_default;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET TABLESPACE %{tablespace}I", "type": "set tablespace", "tablespace": "pg_default"}], "identity": {"objname": "test_set_tablespace", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_tablespace SET TABLESPACE pg_default
@@ -568,16 +568,16 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_tablespace SET TABLESPA
 CREATE TABLE test_set_logged(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_logged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_logged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_logged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_logged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_logged SET LOGGED;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET LOGGED", "type": "set logged"}], "identity": {"objname": "test_set_logged", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_logged SET LOGGED
 CREATE TABLE test_set_unlogged(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_unlogged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_unlogged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_unlogged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_unlogged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_unlogged SET UNLOGGED;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET UNLOGGED", "type": "set unlogged"}], "identity": {"objname": "test_set_unlogged", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_unlogged SET UNLOGGED
@@ -585,16 +585,16 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_unlogged SET UNLOGGED
 CREATE TABLE test_set_storage_params1(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params1 SET (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params1 SET (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')
 CREATE TABLE test_set_storage_params2(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params2 SET (vacuum_index_cleanup = ON);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params2 SET (vacuum_index_cleanup = 'on')
@@ -602,8 +602,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params2 SET (va
 CREATE TABLE test_reset_storage_params1(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params1 SET (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params1 SET (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')
@@ -613,8 +613,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_reset_storage_params1 RESET
 CREATE TABLE test_reset_storage_params2(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params2 SET (vacuum_index_cleanup = ON);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params2 SET (vacuum_index_cleanup = 'on')
@@ -625,14 +625,14 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_reset_storage_params2 RESET
 CREATE TABLE test_inherit_parent(
     parent_id int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )     
 CREATE TABLE test_inherit_child(
     parent_id int,
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_child (parent_id pg_catalog.int4 STORAGE PLAIN      , id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_child (parent_id pg_catalog.int4 STORAGE PLAIN      , id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_inherit_child INHERIT test_inherit_parent;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "INHERIT %{parent}D", "type": "inherit", "parent": {"objname": "test_inherit_parent", "schemaname": "public"}}], "identity": {"objname": "test_inherit_child", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_inherit_child INHERIT public.test_inherit_parent
@@ -640,13 +640,13 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_inherit_child INHERIT publi
 CREATE TABLE test_no_inherit_parent(
     parent_id int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_no_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_no_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )     
 CREATE TABLE test_no_inherit_child(
     LIKE orders
 ) INHERITS (test_no_inherit_parent);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_no_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "test_no_inherit_parent", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_child (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      ) INHERITS (public.test_no_inherit_parent)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_no_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "test_no_inherit_parent", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_child (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      ) INHERITS (public.test_no_inherit_parent)    
 ALTER TABLE test_no_inherit_child NO INHERIT test_no_inherit_parent;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "NO INHERIT %{parent}D", "type": "drop inherit", "parent": {"objname": "test_no_inherit_parent", "schemaname": "public"}}], "identity": {"objname": "test_no_inherit_child", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_no_inherit_child NO INHERIT public.test_no_inherit_parent
@@ -655,15 +655,15 @@ CREATE TABLE test_type(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 ALTER TABLE test_type OF test_type_product_type;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "OF %{type_of}T", "type": "add of", "type_of": {"typmod": "", "typarray": false, "typename": "test_type_product_type", "schemaname": "public"}}], "identity": {"objname": "test_type", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_type OF public.test_type_product_type
 -- NOT OF
 CREATE TABLE test_type_not_of OF test_type_product_type;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "test_type_product_type", "schemaname": "public"}, "identity": {"objname": "test_type_not_of", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_type_not_of OF public.test_type_product_type      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "test_type_product_type", "schemaname": "public"}, "identity": {"objname": "test_type_not_of", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_type_not_of OF public.test_type_product_type     
 ALTER TABLE test_type_not_of NOT OF;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "NOT OF", "type": "not of"}], "identity": {"objname": "test_type_not_of", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_type_not_of NOT OF
@@ -673,8 +673,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_type_not_of NOT OF
 CREATE TABLE test_replica_identity1(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_replica_identity1 REPLICA IDENTITY DEFAULT;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": "DEFAULT"}], "identity": {"objname": "test_replica_identity1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity1 REPLICA IDENTITY DEFAULT
@@ -682,24 +682,24 @@ CREATE TABLE test_replica_identity2(
     LIKE orders,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_replica_identity2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_replica_identity2_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_replica_identity2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_replica_identity2_pkey PRIMARY KEY (id))     
 ALTER TABLE test_replica_identity2 REPLICA IDENTITY USING INDEX test_replica_identity2_pkey;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": {"fmt": "USING INDEX %{index}I", "index": "test_replica_identity2_pkey"}}], "identity": {"objname": "test_replica_identity2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity2 REPLICA IDENTITY USING INDEX test_replica_identity2_pkey
 CREATE TABLE test_replica_identity3(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_replica_identity3 REPLICA IDENTITY FULL;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": "FULL"}], "identity": {"objname": "test_replica_identity3", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity3 REPLICA IDENTITY FULL
 CREATE TABLE test_replica_identity4(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity4", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity4 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity4", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity4 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_replica_identity4 REPLICA IDENTITY NOTHING;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": "NOTHING"}], "identity": {"objname": "test_replica_identity4", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity4 REPLICA IDENTITY NOTHING
@@ -707,8 +707,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity4 REPLICA I
 CREATE TABLE test_alter_col_name(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_col_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_col_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_col_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_col_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_alter_col_name RENAME id TO new_id;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{if_exists}s %{identity}D RENAME COLUMN %{colname}I TO %{newname}I", "colname": "id", "newname": "new_id", "objtype": "TABLE", "identity": {"objname": "test_alter_col_name", "schemaname": "public"}, "if_exists": ""}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_col_name RENAME COLUMN id TO new_id
@@ -720,8 +720,8 @@ CREATE TABLE test_alter_constraint_name(
     LIKE orders,
     CONSTRAINT test_alter_constraint_name_old CHECK (id > 10)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_name_old", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_alter_constraint_name_old CHECK ((id OPERATOR(pg_catalog.>) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_name_old", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_alter_constraint_name_old CHECK ((id OPERATOR(pg_catalog.>) 10)))     
 ALTER TABLE test_alter_constraint_name RENAME CONSTRAINT test_alter_constraint_name_old TO test_alter_constraint_name_new;
 NOTICE:  deparsed json: {"fmt": "ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I", "only": "", "newname": "test_alter_constraint_name_new", "oldname": "test_alter_constraint_name_old", "identity": {"objname": "test_alter_constraint_name", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint_name RENAME CONSTRAINT test_alter_constraint_name_old TO test_alter_constraint_name_new
@@ -729,8 +729,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint_name RENAM
 CREATE TABLE test_rename_table(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_rename_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_rename_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_rename_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_rename_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_rename_table RENAME to new_test_rename_table;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I", "newname": "new_test_rename_table", "objtype": "TABLE", "identity": {"objname": "test_rename_table", "schemaname": "public"}, "if_exists": ""}
 NOTICE:  re-formed command: ALTER TABLE  public.test_rename_table RENAME TO new_test_rename_table
@@ -738,8 +738,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_rename_table RENAME TO new_
 CREATE TABLE test_set_schema(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_schema", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_schema (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_schema", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_schema (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_schema SET SCHEMA new_test_schema;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I", "objtype": "TABLE", "identity": "public.test_set_schema", "newschema": "new_test_schema"}
 NOTICE:  re-formed command: ALTER TABLE public.test_set_schema SET SCHEMA new_test_schema
@@ -754,49 +754,49 @@ NOTICE:  re-formed command: ALTER TABLE public.test_set_schema SET SCHEMA new_te
 CREATE TABLE test_partition_attach_range(
     LIKE orders
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)   
 CREATE TABLE test_partition_attach_range_p_1(
     LIKE test_partition_attach_range
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_range ATTACH PARTITION test_partition_attach_range_p_1 DEFAULT;
 CREATE TABLE test_partition_attach_range_p_2(
     LIKE test_partition_attach_range
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_range ATTACH PARTITION test_partition_attach_range_p_2 FOR VALUES FROM (100) TO (200);
 CREATE TABLE test_partition_attach_hash(
     LIKE orders
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY HASH (id)   
 CREATE TABLE test_partition_attach_hash_p(
     LIKE test_partition_attach_hash
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash_p", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash_p (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash_p", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash_p (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_hash ATTACH PARTITION test_partition_attach_hash_p FOR VALUES WITH (MODULUS 10, REMAINDER 1);
 CREATE TABLE test_partition_attach_list(
     LIKE orders
 ) PARTITION BY LIST (name);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY LIST (name)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY LIST (name)   
 CREATE TABLE test_partition_attach_list_p1(
     LIKE test_partition_attach_list
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE TABLE test_partition_attach_list_p2(
     LIKE test_partition_attach_list
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_list ATTACH PARTITION test_partition_attach_list_p1 FOR VALUES IN ('key1');
 -- ALTER TABLE test_partition_attach_list ATTACH PARTITION test_partition_attach_list_p2 FOR VALUES IN ('key2', 'key3');
@@ -804,17 +804,17 @@ NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p2
 CREATE TABLE test_detach_partition(
     LIKE orders
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)   
 CREATE TABLE test_detach_partition_p1 PARTITION OF test_detach_partition FOR VALUES FROM (1) TO (100);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p1", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (1) TO (100)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p1 PARTITION OF public.test_detach_partition  FOR VALUES FROM (1) TO (100)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p1", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (1) TO (100)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p1 PARTITION OF public.test_detach_partition  FOR VALUES FROM (1) TO (100)    
 CREATE TABLE test_detach_partition_p2 PARTITION OF test_detach_partition FOR VALUES FROM (101) TO (200);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p2", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (101) TO (200)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p2 PARTITION OF public.test_detach_partition  FOR VALUES FROM (101) TO (200)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p2", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (101) TO (200)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p2 PARTITION OF public.test_detach_partition  FOR VALUES FROM (101) TO (200)    
 CREATE TABLE test_detach_partition_p3 PARTITION OF test_detach_partition FOR VALUES FROM (201) TO (300);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p3", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (201) TO (300)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p3 PARTITION OF public.test_detach_partition  FOR VALUES FROM (201) TO (300)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p3", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (201) TO (300)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p3 PARTITION OF public.test_detach_partition  FOR VALUES FROM (201) TO (300)    
 -- TOFIX
 -- ALTER TABLE test_detach_partition DETACH PARTITION test_detach_partition_p1;
 -- ALTER TABLE test_detach_partition DETACH PARTITION test_detach_partition_p2 CONCURRENTLY;
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/constraints.out b/src/test/modules/test_ddl_deparse_regress/expected/constraints.out
index 45058db174..9c24b795d0 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/constraints.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/constraints.out
@@ -5,42 +5,42 @@ CREATE TABLE col_cstr_not_null(
     id int CONSTRAINT id_constraint NOT NULL,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_null (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_null (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 --  NULL |
 CREATE TABLE col_cstr_null(
     id int NULL,
     name varchar CONSTRAINT name_constraint NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   )     
 --  CHECK ( expression ) [ NO INHERIT ] |
 CREATE TABLE col_cstr_check(
     id int CHECK (id > 10),
     name varchar NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_check", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_check", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)))     
 CREATE TABLE col_cstr_check_no_inherit(
     id int CHECK (id > 10) NO INHERIT,
     name varchar NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)     
 --  DEFAULT default_expr |
 CREATE TABLE col_cstr_default(
     id int NOT NULL,
     name varchar DEFAULT 'foo'
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_default (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_default (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )     
 --  GENERATED ALWAYS AS ( generation_expr ) STORED |
 CREATE TABLE col_cstr_generated_always_as(
     id int NOT NULL,
     id_generated int GENERATED ALWAYS AS ( id * 10 ) STORED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(id OPERATOR(pg_catalog.*) 10)"}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((id OPERATOR(pg_catalog.*) 10)) STORED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(id OPERATOR(pg_catalog.*) 10)"}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((id OPERATOR(pg_catalog.*) 10)) STORED)     
 --  GENERATED { ALWAYS | BY DEFAULT } AS IDENTITY [ ( sequence_options ) ] |
 CREATE TABLE col_cstr_generated_always_as_identity(
     id int NOT NULL,
@@ -48,8 +48,8 @@ CREATE TABLE col_cstr_generated_always_as_identity(
 );
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as_identity (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as_identity (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 CREATE TABLE col_cstr_generated_by_default_as_identity_with_options(
@@ -58,8 +58,8 @@ CREATE TABLE col_cstr_generated_by_default_as_identity_with_options(
 );
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_by_default_as_identity_with_options", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_by_default_as_identity_with_options (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 10 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_by_default_as_identity_with_options", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_by_default_as_identity_with_options (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 10 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 --  UNIQUE [ NULLS [ NOT ] DISTINCT ] |
@@ -67,43 +67,43 @@ CREATE TABLE col_cstr_unique(
     id int NOT NULL,
     name varchar UNIQUE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_name_key UNIQUE (name))     
 CREATE TABLE col_cstr_unique_nulls_distinct(
     id int NOT NULL,
     name varchar UNIQUE NULLS DISTINCT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_distinct_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_distinct_name_key UNIQUE (name))     
 CREATE TABLE col_cstr_unique_nulls_not_distinct(
     id int NOT NULL,
     name varchar UNIQUE NULLS NOT DISTINCT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_not_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_not_distinct_name_key UNIQUE NULLS NOT DISTINCT (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_not_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_not_distinct_name_key UNIQUE NULLS NOT DISTINCT (name))     
 --  PRIMARY KEY |
 CREATE TABLE col_cstr_primary_key(
     id int PRIMARY KEY,
     name varchar UNIQUE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_primary_key_name_key UNIQUE (name), CONSTRAINT col_cstr_primary_key_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_primary_key_name_key UNIQUE (name), CONSTRAINT col_cstr_primary_key_pkey PRIMARY KEY (id))     
 --  REFERENCES reftable [ ( refcolumn ) ] [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ]
 --    [ ON DELETE referential_action ] [ ON UPDATE referential_action ] }
 CREATE TABLE col_cstr_reference_table_default(
     id int REFERENCES col_cstr_primary_key,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_default_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id)"}], "identity": {"objname": "col_cstr_reference_table_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_default ADD CONSTRAINT col_cstr_reference_table_default_id_fkey FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id)
 CREATE TABLE col_cstr_reference_table_column(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column ADD CONSTRAINT col_cstr_reference_table_column_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 -- [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ]
@@ -113,16 +113,16 @@ CREATE TABLE col_cstr_reference_table_column_match_full(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) MATCH FULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_full", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_full (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_full", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_full (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_match_full_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL"}], "identity": {"objname": "col_cstr_reference_table_column_match_full", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_match_full ADD CONSTRAINT col_cstr_reference_table_column_match_full_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL
 CREATE TABLE col_cstr_reference_table_column_match_simple(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) MATCH SIMPLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_match_simple_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column_match_simple", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_match_simple ADD CONSTRAINT col_cstr_reference_table_column_match_simple_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 -- [ ON DELETE referential_action ]
@@ -130,32 +130,32 @@ CREATE TABLE col_cstr_reference_table_column_on_delete_no_action(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE NO ACTION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_no_action_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_no_action", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_no_action ADD CONSTRAINT col_cstr_reference_table_column_on_delete_no_action_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 CREATE TABLE col_cstr_reference_table_column_on_delete_restrict(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE RESTRICT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_restrict_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE RESTRICT"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_restrict", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_restrict ADD CONSTRAINT col_cstr_reference_table_column_on_delete_restrict_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE RESTRICT
 CREATE TABLE col_cstr_reference_table_column_on_delete_cascade(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE CASCADE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_cascade_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE CASCADE"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_cascade", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_cascade ADD CONSTRAINT col_cstr_reference_table_column_on_delete_cascade_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE CASCADE
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_null(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_null_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_null ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_null_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_null_with_column(
@@ -163,24 +163,24 @@ CREATE TABLE col_cstr_reference_table_column_on_delete_set_null_with_column(
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET NULL (name),
     foo varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET NULL (foo)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null_with_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "foo", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null_with_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , foo pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null_with_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "foo", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null_with_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , foo pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_null_wi_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (name)"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_null_wit_foo_fkey", "type": "add constraint", "definition": "FOREIGN KEY (foo) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (foo)"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null_with_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_null_with_column ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_null_wi_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (name), ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_null_wit_foo_fkey FOREIGN KEY (foo) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (foo)
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_default(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET DEFAULT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_default_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_default ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_default_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_default_with_col(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET DEFAULT (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default_with_col", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default_with_col (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default_with_col", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default_with_col (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_defaul_name_fkey1", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT (name)"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default_with_col", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_default_with_col ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_defaul_name_fkey1 FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT (name)
 -- [ ON UPDATE referential_action ]
@@ -188,40 +188,40 @@ CREATE TABLE col_cstr_reference_table_column_on_update_no_action(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE NO ACTION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_no_action_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_no_action", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_no_action ADD CONSTRAINT col_cstr_reference_table_column_on_update_no_action_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 CREATE TABLE col_cstr_reference_table_column_on_update_restrict(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE RESTRICT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_restrict_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE RESTRICT"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_restrict", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_restrict ADD CONSTRAINT col_cstr_reference_table_column_on_update_restrict_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE RESTRICT
 CREATE TABLE col_cstr_reference_table_column_on_update_cascade(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE CASCADE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_cascade_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE CASCADE"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_cascade", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_cascade ADD CONSTRAINT col_cstr_reference_table_column_on_update_cascade_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE CASCADE
 CREATE TABLE col_cstr_reference_table_column_on_update_set_null(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE SET NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_set_null_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET NULL"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_set_null", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_set_null ADD CONSTRAINT col_cstr_reference_table_column_on_update_set_null_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET NULL
 CREATE TABLE col_cstr_reference_table_column_on_update_set_default(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE SET DEFAULT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_set_default_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET DEFAULT"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_set_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_set_default ADD CONSTRAINT col_cstr_reference_table_column_on_update_set_default_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET DEFAULT
 -- complex combinations
@@ -229,16 +229,16 @@ CREATE TABLE col_cstr_reference_table_column_complex_combination1(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) MATCH FULL ON DELETE NO ACTION ON UPDATE NO ACTION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_complex_combination1_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL"}], "identity": {"objname": "col_cstr_reference_table_column_complex_combination1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_complex_combination1 ADD CONSTRAINT col_cstr_reference_table_column_complex_combination1_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL
 CREATE TABLE col_cstr_reference_table_column_complex_combination2(
     id int REFERENCES col_cstr_primary_key MATCH FULL ON DELETE SET DEFAULT ON UPDATE SET NULL,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_complex_combination2_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT"}], "identity": {"objname": "col_cstr_reference_table_column_complex_combination2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_complex_combination2 ADD CONSTRAINT col_cstr_reference_table_column_complex_combination2_id_fkey FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT
 -- [ DEFERRABLE | NOT DEFERRABLE ]
@@ -246,34 +246,34 @@ CREATE TABLE col_cstr_deferable(
     id int,
     name varchar UNIQUE DEFERRABLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_deferable_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name) DEFERRABLE"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_deferable_name_key UNIQUE (name) DEFERRABLE)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_deferable_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name) DEFERRABLE"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_deferable_name_key UNIQUE (name) DEFERRABLE)     
 CREATE TABLE col_cstr_not_deferable(
     id int PRIMARY KEY NOT DEFERRABLE,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_not_deferable_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_not_deferable_pkey PRIMARY KEY (id))     
 -- [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]
 CREATE TABLE col_cstr_initially_deferred(
     id int PRIMARY KEY INITIALLY DEFERRED,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_deferred_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_deferred_pkey PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_deferred_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_deferred_pkey PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED)     
 CREATE TABLE col_cstr_initially_immediate(
     id int,
     name varchar UNIQUE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_immediate_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_immediate_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_immediate_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_immediate_name_key UNIQUE (name))     
 -- complex combination
 CREATE TABLE col_cstr_complex_combination(
     id int,
     name varchar CONSTRAINT name_constraint REFERENCES col_cstr_primary_key (name) MATCH FULL ON DELETE SET DEFAULT ON UPDATE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "name_constraint", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT"}], "identity": {"objname": "col_cstr_complex_combination", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_complex_combination ADD CONSTRAINT name_constraint FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT
 -- part 4: table constraints
@@ -284,180 +284,180 @@ CREATE TABLE tbl_cstr_check_1(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "id_constraint", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT id_constraint CHECK ((id OPERATOR(pg_catalog.>) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "id_constraint", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT id_constraint CHECK ((id OPERATOR(pg_catalog.>) 10)))     
 CREATE TABLE tbl_cstr_check_2(
     id int,
     name varchar,
     CONSTRAINT table_check CHECK (id > 10) NO INHERIT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "table_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT table_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "table_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT table_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)     
 CREATE TABLE tbl_cstr_check_no_inherit(
     id int,
     name varchar,
     CHECK (id > 10) NO INHERIT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)     
 --   UNIQUE [ NULLS [ NOT ] DISTINCT ] ( column_name [, ... ] ) [ INCLUDE ( column_name [, ...]) ] |
 CREATE TABLE tbl_cstr_unique(
     id int,
     name varchar,
     UNIQUE (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_id_key UNIQUE (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_id_key UNIQUE (id))     
 CREATE TABLE tbl_cstr_unique_multicols(
     id int,
     name varchar,
     UNIQUE (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_multicols_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_multicols_id_name_key UNIQUE (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_multicols_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_multicols_id_name_key UNIQUE (id, name))     
 CREATE TABLE tbl_cstr_unique_nulls_distinct(
     id int,
     name varchar,
     UNIQUE NULLS DISTINCT (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_id_key UNIQUE (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_id_key UNIQUE (id))     
 CREATE TABLE tbl_cstr_unique_nulls_not_distinct(
     id int,
     name varchar,
     UNIQUE NULLS NOT DISTINCT (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_not_distinct_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_not_distinct_id_name_key UNIQUE NULLS NOT DISTINCT (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_not_distinct_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_not_distinct_id_name_key UNIQUE NULLS NOT DISTINCT (id, name))     
 CREATE TABLE tbl_cstr_unique_nulls_distinct_include(
     id int,
     name varchar,
     UNIQUE NULLS DISTINCT (id) INCLUDE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_id_name_key UNIQUE (id) INCLUDE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_id_name_key UNIQUE (id) INCLUDE (name))     
 CREATE TABLE tbl_cstr_unique_nulls_distinct_include_multi(
     id int,
     name varchar,
     info varchar,
     UNIQUE NULLS DISTINCT (id) INCLUDE (name, info)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name, info)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key UNIQUE (id) INCLUDE (name, info))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name, info)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key UNIQUE (id) INCLUDE (name, info))     
 -- PRIMARY KEY ( column_name [, ... ] ) [ INCLUDE ( column_name [, ...]) ] |
 CREATE TABLE tbl_cstr_primary_key(
     id int,
     name varchar,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_pkey PRIMARY KEY (id))     
 CREATE TABLE tbl_cstr_primary_key_multicols(
     id int,
     name varchar,
     PRIMARY KEY (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_multicols_pkey PRIMARY KEY (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_multicols_pkey PRIMARY KEY (id, name))     
 CREATE TABLE tbl_cstr_primary_key_include(
     id int,
     name varchar,
     PRIMARY KEY (id) INCLUDE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_pkey PRIMARY KEY (id) INCLUDE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_pkey PRIMARY KEY (id) INCLUDE (name))     
 CREATE TABLE tbl_cstr_primary_key_include_multicols(
     id int,
     name varchar,
     info varchar,
     PRIMARY KEY (id) INCLUDE (name, info)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name, info)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_multicols_pkey PRIMARY KEY (id) INCLUDE (name, info))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name, info)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_multicols_pkey PRIMARY KEY (id) INCLUDE (name, info))     
 --   EXCLUDE [ USING index_method ] ( exclude_element WITH operator [, ... ] ) index_parameters [ WHERE ( predicate ) ] |
 CREATE TABLE tbl_cstr_exclude(
     id int,
     name varchar,
     EXCLUDE (name WITH =)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_name_excl EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_name_excl EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=)))     
 CREATE TABLE tbl_cstr_exclude_multi(
     id int,
     name varchar,
     EXCLUDE ((id*10) with =, name WITH =)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_multi_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_multi_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_multi_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_multi_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))     
 CREATE TABLE tbl_cstr_exclude_index_method(
     id int,
     name varchar,
     EXCLUDE USING btree ((id*10) with =, name WITH =)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_index_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_index_method_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_index_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_index_method_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_index_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_index_method_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_index_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_index_method_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))     
 -- [ INCLUDE ( column_name [, ... ] ) ]
 CREATE TABLE tbl_cstr_exclude_with_index_params_include_1(
     id int,
     name varchar,
     EXCLUDE (id WITH =) INCLUDE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_1_id_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_1_id_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_1_id_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_1_id_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name))     
 CREATE TABLE tbl_cstr_exclude_with_index_params_include_2(
     id int,
     name varchar,
     EXCLUDE (id WITH =) INCLUDE (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name))     
 -- [ WITH ( storage_parameter [= value] [, ... ] ) ]
 CREATE TABLE tbl_cstr_exclude_with_index_params_storage_1(
     id int,
     name varchar,
     EXCLUDE (id WITH =) WITH (fillfactor = 20)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_1_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20')"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_1_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20'))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_1_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20')"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_1_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20'))     
 CREATE TABLE tbl_cstr_exclude_with_index_params_storage_2(
     id int,
     name varchar,
     EXCLUDE (id WITH =) WITH (fillfactor = 20, deduplicate_items = false)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_2_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false')"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_2_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false'))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_2_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false')"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_2_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false'))     
 -- [ USING INDEX TABLESPACE tablespace_name ]
 CREATE TABLE tbl_cstr_exclude_with_index_params_tablespace(
     id int,
     name varchar,
     EXCLUDE (id WITH =) USING INDEX TABLESPACE pg_default
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_tablespace_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_tablespace_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_tablespace_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_tablespace_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)))     
 -- index_parameters complex combination
 CREATE TABLE tbl_cstr_exclude_with_index_params_complex(
     id int,
     name varchar,
     EXCLUDE (id WITH =) INCLUDE (id, name) WITH (fillfactor = 20, deduplicate_items = false) USING INDEX TABLESPACE pg_default
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_complex", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false')"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_complex (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false'))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_complex", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false')"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_complex (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false'))     
 -- [ WHERE ( predicate ) ]
 CREATE TABLE tbl_cstr_exclude_with_predicate(
     id int,
     name varchar,
     EXCLUDE (id WITH =) WHERE (name<>'foo')
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_predicate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_predicate_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_predicate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_predicate_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_predicate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_predicate_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_predicate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_predicate_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))     
 -- complex combination for table constraint clauses
 CREATE TABLE tbl_cstr_exclude_complex_combination(
     id int,
     name varchar,
     EXCLUDE USING btree (id WITH =, name WITH =) INCLUDE (id, name) WITH (fillfactor = 20, deduplicate_items = false) USING INDEX TABLESPACE pg_default WHERE (name<>'foo')
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))     
 -- FOREIGN KEY ( column_name [, ... ] ) REFERENCES reftable [ ( refcolumn [, ... ] ) ]
 --     [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ] [ ON DELETE referential_action ] [ ON UPDATE referential_action ] }
 CREATE TABLE tbl_cstr_foreign_table(
@@ -465,15 +465,15 @@ CREATE TABLE tbl_cstr_foreign_table(
     name varchar UNIQUE,
     UNIQUE (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_foreign_table_id_name_key UNIQUE (id, name), CONSTRAINT tbl_cstr_foreign_table_name_key UNIQUE (name), CONSTRAINT tbl_cstr_foreign_table_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_foreign_table_id_name_key UNIQUE (id, name), CONSTRAINT tbl_cstr_foreign_table_name_key UNIQUE (name), CONSTRAINT tbl_cstr_foreign_table_pkey PRIMARY KEY (id))     
 CREATE TABLE tbl_cstr_foreign_key_simple_1(
     id int,
     name varchar,
     FOREIGN KEY (id) REFERENCES tbl_cstr_foreign_table
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_key_simple_1_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)"}], "identity": {"objname": "tbl_cstr_foreign_key_simple_1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_foreign_key_simple_1 ADD CONSTRAINT tbl_cstr_foreign_key_simple_1_id_fkey FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)
 CREATE TABLE tbl_cstr_foreign_key_simple_2(
@@ -481,8 +481,8 @@ CREATE TABLE tbl_cstr_foreign_key_simple_2(
     name varchar,
     FOREIGN KEY (id) REFERENCES tbl_cstr_foreign_table(id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_key_simple_2_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)"}], "identity": {"objname": "tbl_cstr_foreign_key_simple_2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_foreign_key_simple_2 ADD CONSTRAINT tbl_cstr_foreign_key_simple_2_id_fkey FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)
 CREATE TABLE tbl_cstr_foreign_key_multiple_keys(
@@ -490,8 +490,8 @@ CREATE TABLE tbl_cstr_foreign_key_multiple_keys(
     name varchar,
     FOREIGN KEY (id, name) REFERENCES tbl_cstr_foreign_table (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_multiple_keys", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_multiple_keys (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_multiple_keys", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_multiple_keys (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_key_multiple_keys_id_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name)"}], "identity": {"objname": "tbl_cstr_foreign_key_multiple_keys", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_foreign_key_multiple_keys ADD CONSTRAINT tbl_cstr_foreign_key_multiple_keys_id_name_fkey FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name)
 -- some combinations from REFERENCES clause, which is already tested in part 3
@@ -500,8 +500,8 @@ CREATE TABLE tbl_cstr_reference_table_complex_combination1(
     name varchar,
     FOREIGN KEY (name) REFERENCES tbl_cstr_foreign_table (name) MATCH SIMPLE ON DELETE CASCADE ON UPDATE SET NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_complex_combination1_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) ON UPDATE SET NULL ON DELETE CASCADE"}], "identity": {"objname": "tbl_cstr_reference_table_complex_combination1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_reference_table_complex_combination1 ADD CONSTRAINT tbl_cstr_reference_table_complex_combination1_name_fkey FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) ON UPDATE SET NULL ON DELETE CASCADE
 CREATE TABLE tbl_cstr_reference_table_complex_combination2(
@@ -509,8 +509,8 @@ CREATE TABLE tbl_cstr_reference_table_complex_combination2(
     name varchar,
     CONSTRAINT tbl_cstr FOREIGN KEY (id, name) REFERENCES tbl_cstr_foreign_table (id, name) ON DELETE SET NULL (id, name) ON UPDATE SET DEFAULT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "add constraint", "definition": "FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name) ON UPDATE SET DEFAULT ON DELETE SET NULL (id, name)"}], "identity": {"objname": "tbl_cstr_reference_table_complex_combination2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_reference_table_complex_combination2 ADD CONSTRAINT tbl_cstr FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name) ON UPDATE SET DEFAULT ON DELETE SET NULL (id, name)
 -- [ DEFERRABLE | NOT DEFERRABLE ]
@@ -519,38 +519,38 @@ CREATE TABLE tbl_cstr_reference_table_column_deferable(
     name varchar,
     UNIQUE (id, name) DEFERRABLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_deferable_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_deferable_id_name_key UNIQUE (id, name) DEFERRABLE)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_deferable_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_deferable_id_name_key UNIQUE (id, name) DEFERRABLE)     
 CREATE TABLE tbl_cstr_reference_table_column_not_deferable(
     id int,
     name varchar,
     PRIMARY KEY (id) NOT DEFERRABLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_not_deferable_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_not_deferable_pkey PRIMARY KEY (id))     
 -- [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]
 CREATE TABLE tbl_cstr_reference_table_column_initially_deferred(
     id int,
     name varchar,
     UNIQUE (id, name) INITIALLY DEFERRED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_deferred_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_deferred_id_name_key UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_deferred_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_deferred_id_name_key UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED)     
 CREATE TABLE tbl_cstr_reference_table_column_initially_immediate(
     id int,
     name varchar,
     PRIMARY KEY (id) INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_immediate_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_immediate_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_immediate_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_immediate_pkey PRIMARY KEY (id))     
 -- complex combinations
 CREATE TABLE tbl_cstr_reference_table_column_complex_combination1(
     id int,
     name varchar,
     CONSTRAINT tbl_cstr FOREIGN KEY (name) REFERENCES tbl_cstr_foreign_table (name) MATCH FULL ON DELETE NO ACTION ON UPDATE NO ACTION DEFERRABLE INITIALLY DEFERRED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) MATCH FULL DEFERRABLE INITIALLY DEFERRED"}], "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_reference_table_column_complex_combination1 ADD CONSTRAINT tbl_cstr FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) MATCH FULL DEFERRABLE INITIALLY DEFERRED
 CREATE TABLE tbl_cstr_reference_table_column_complex_combination2(
@@ -558,5 +558,5 @@ CREATE TABLE tbl_cstr_reference_table_column_complex_combination2(
     name varchar,
     CONSTRAINT tbl_cstr PRIMARY KEY (id, name) NOT DEFERRABLE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr PRIMARY KEY (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr PRIMARY KEY (id, name))     
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/create_index.out b/src/test/modules/test_ddl_deparse_regress/expected/create_index.out
index 490cac9662..f790f92544 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/create_index.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/create_index.out
@@ -11,8 +11,8 @@ CREATE TABLE test_add_constraint_using_index(
     id6 int,
     id7 int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_constraint_using_index", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_constraint_using_index (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      , id6 pg_catalog.int4 STORAGE PLAIN      , id7 pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_constraint_using_index", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_constraint_using_index (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      , id6 pg_catalog.int4 STORAGE PLAIN      , id7 pg_catalog.int4 STORAGE PLAIN      )     
 CREATE UNIQUE INDEX test_add_constraint_used_index1 ON test_add_constraint_using_index (id1);
 CREATE UNIQUE INDEX test_add_constraint_used_index2 ON test_add_constraint_using_index (id2);
 CREATE UNIQUE INDEX test_add_constraint_used_index3 ON test_add_constraint_using_index (id3);
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out b/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out
index 14c5664292..96d595b7c6 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out
@@ -10,8 +10,8 @@ CREATE TABLE test_disable_rule(
     quantity int,
     purchase_date date
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_disable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_disable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule1 AS
     ON UPDATE TO test_disable_rule
     DO INSTEAD
@@ -20,8 +20,8 @@ CREATE RULE sample_rule1 AS
 CREATE TABLE test_enable_rule(
     LIKE test_disable_rule
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule2 AS
     ON UPDATE TO test_enable_rule
     DO INSTEAD
@@ -30,8 +30,8 @@ CREATE RULE sample_rule2 AS
 CREATE TABLE test_enable_replica_rule(
     LIKE test_disable_rule
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_replica_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_replica_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_replica_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_replica_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule_enable_replica AS
     ON UPDATE TO test_enable_replica_rule
     DO INSTEAD
@@ -40,8 +40,8 @@ CREATE RULE sample_rule_enable_replica AS
 CREATE TABLE test_enable_always_rule(
     LIKE test_disable_rule
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_always_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_always_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_always_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_always_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule_enable_always AS
     ON UPDATE TO test_enable_always_rule
     DO INSTEAD
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/create_table.out b/src/test/modules/test_ddl_deparse_regress/expected/create_table.out
index 567dcf9c38..688b22dc0b 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/create_table.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/create_table.out
@@ -4,20 +4,20 @@ CREATE TABLE part1_simple_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_simple_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part1_simple_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_simple_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part1_simple_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMPORARY TABLE part1_temp_table0(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_temp_table0", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table0 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_temp_table0", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table0 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMP TABLE part1_temp_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- GLOBAL TEMP TATBLE is deprecated, expect warning message and create local temp table
 CREATE GLOBAL TEMP TABLE part1_global_temp_table(
     id int,
@@ -26,20 +26,20 @@ CREATE GLOBAL TEMP TABLE part1_global_temp_table(
 WARNING:  GLOBAL is deprecated in temporary table creation
 LINE 1: CREATE GLOBAL TEMP TABLE part1_global_temp_table(
                ^
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_global_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_global_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_global_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_global_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE LOCAL TEMP TABLE part1_local_temp_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_local_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_local_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE UNLOGGED TABLE part1_unlogged_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_unlogged_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "UNLOGGED", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE UNLOGGED TABLE  public.part1_unlogged_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_unlogged_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "UNLOGGED", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE UNLOGGED TABLE  public.part1_unlogged_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- [ IF NOT EXISTS ]
 CREATE TABLE IF NOT EXISTS part1_simple_table(
     id int,
@@ -50,291 +50,291 @@ CREATE TABLE IF NOT EXISTS part1_local_temp_table_not_exists(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table_not_exists", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "IF NOT EXISTS", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE IF NOT EXISTS public.part1_local_temp_table_not_exists (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table_not_exists", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "IF NOT EXISTS", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE IF NOT EXISTS public.part1_local_temp_table_not_exists (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- part 2: shared suffixes
 -- [ PARTITION BY { RANGE | LIST | HASH } ( { column_name | ( expression ) } [ COLLATE collation ] [ opclass ] [, ... ] ) ]
 CREATE TABLE part2_partition_by_range_simple(
     id int,
     name varchar
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_by_range_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_range_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_by_range_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_range_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   
 CREATE TABLE part2_partition_by_list_simple(
     id int,
     name varchar
 ) PARTITION BY LIST (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_by_list_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_list_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_by_list_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_list_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)   
 CREATE TABLE part2_partition_by_hash_simple(
     id int,
     name varchar
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_by_hash_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_hash_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_by_hash_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_hash_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)   
 CREATE TABLE part2_partition_with_expression(
     id int,
     name varchar
 ) PARTITION BY RANGE ((id * 190), name);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 190)), name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 190)), name)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 190)), name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 190)), name)   
 CREATE TABLE part2_partition_with_collation(
     id int,
     name varchar
 ) PARTITION BY LIST (name COLLATE "C");
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name COLLATE pg_catalog.\"C\")"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (name COLLATE pg_catalog."C")    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name COLLATE pg_catalog.\"C\")"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (name COLLATE pg_catalog."C")   
 CREATE TABLE part2_partition_with_opclass(
     id int,
     name varchar
 ) PARTITION BY HASH (id int4_ops, name varchar_ops);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id, name pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id, name pg_catalog.varchar_ops)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id, name pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id, name pg_catalog.varchar_ops)   
 CREATE TABLE part2_partition_with_collation_opclass(
     id int,
     name varchar
 ) PARTITION BY RANGE ((id * 10) int4_ops, name COLLATE "C" varchar_ops);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog.\"C\" pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog."C" pg_catalog.varchar_ops)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog.\"C\" pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog."C" pg_catalog.varchar_ops)   
 -- [ USING method ]
 -- default method
 CREATE TABLE part2_using_default_access_method(
     id int,
     name varchar
 ) USING heap;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_using_default_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_using_default_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap   
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_using_default_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_using_default_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap  
 -- [ WITH ( storage_parameter [= value] [, ... ] ) | WITHOUT OIDS ]
 CREATE TABLE part2_without_oids(
     id int,
     name varchar
 ) WITHOUT OIDS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part2_with_one_storage_param(
     id int,
     name varchar
 ) WITH (fillfactor = 20);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_with_one_storage_param", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "fillfactor"}, "value": "20"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_one_storage_param (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (fillfactor = '20')  
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_with_one_storage_param", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "fillfactor"}, "value": "20"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_one_storage_param (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (fillfactor = '20') 
 CREATE TABLE part2_with_multiple_storage_params(
     id int,
     name varchar
 ) WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_with_multiple_storage_params", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_multiple_storage_params (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_with_multiple_storage_params", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_multiple_storage_params (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') 
 -- [ ON COMMIT { PRESERVE ROWS | DELETE ROWS | DROP } ]
 CREATE TEMP TABLE part2_on_commit_preserve_rows(
     id int,
     name varchar
 ) ON COMMIT PRESERVE ROWS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_on_commit_preserve_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "PRESERVE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_preserve_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     ON COMMIT PRESERVE ROWS 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_on_commit_preserve_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_preserve_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMP TABLE part2_on_commit_delete_rows(
     id int,
     name varchar
 ) ON COMMIT DELETE ROWS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_on_commit_delete_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "DELETE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_delete_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     ON COMMIT DELETE ROWS 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_on_commit_delete_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_delete_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMPORARY TABLE part2_on_commit_drop(
     id int,
     name varchar
 ) ON COMMIT DROP;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_on_commit_drop", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "DROP"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_drop (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     ON COMMIT DROP 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_on_commit_drop", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_drop (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- [ TABLESPACE tablespace_name ]
 CREATE TABLE part2_tablespace_pg_default(
     id int,
     name varchar
 ) TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_tablespace_pg_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_tablespace_pg_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_tablespace_pg_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_tablespace_pg_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     TABLESPACE pg_default
 -- some complex combinations from the components above
 CREATE TEMPORARY TABLE part2_combination_1(
     id int,
     name varchar
 ) PARTITION BY RANGE (id) ON COMMIT PRESERVE ROWS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_combination_1", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "PRESERVE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   ON COMMIT PRESERVE ROWS 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_combination_1", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   
 CREATE LOCAL TEMP TABLE part2_combination_2(
     id int,
     name varchar
 ) USING heap WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true) ON COMMIT PRESERVE ROWS TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_combination_2", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "PRESERVE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') ON COMMIT PRESERVE ROWS TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_combination_2", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 CREATE TABLE part2_combination_3(
     id int,
     name varchar
 ) USING heap WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true) TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_combination_3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_combination_3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_combination_3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_combination_3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 -- part 5: LIKE source_table [ like_option ... ]
 CREATE TABLE part5_source_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_source_table2(
     id2 int,
     name2 varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_source_table2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table2 (id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_source_table2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table2 (id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_like_simple(
     LIKE part5_source_table
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_like_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_like_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- { INCLUDING | EXCLUDING } { COMMENTS | COMPRESSION | CONSTRAINTS | DEFAULTS | GENERATED | IDENTITY | INDEXES | STATISTICS | STORAGE | ALL }
 CREATE TABLE part5_including_all(
     LIKE part5_source_table INCLUDING ALL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_comments(
     LIKE part5_source_table INCLUDING COMMENTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_compression(
     LIKE part5_source_table INCLUDING COMPRESSION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_defaults(
     LIKE part5_source_table INCLUDING DEFAULTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_generated(
     LIKE part5_source_table INCLUDING GENERATED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_identity(
     LIKE part5_source_table INCLUDING IDENTITY
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_indexes(
     LIKE part5_source_table INCLUDING INDEXES
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_statistics(
     LIKE part5_source_table INCLUDING STATISTICS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_storage(
     LIKE part5_source_table INCLUDING STORAGE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_all(
     LIKE part5_source_table EXCLUDING ALL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_comments(
     LIKE part5_source_table EXCLUDING COMMENTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_compression(
     LIKE part5_source_table EXCLUDING COMPRESSION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_defaults(
     LIKE part5_source_table EXCLUDING DEFAULTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_generated(
     LIKE part5_source_table EXCLUDING GENERATED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_identity(
     LIKE part5_source_table EXCLUDING IDENTITY
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_indexes(
     LIKE part5_source_table EXCLUDING INDEXES
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_statistics(
     LIKE part5_source_table EXCLUDING STATISTICS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_storage(
     LIKE part5_source_table EXCLUDING STORAGE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_like_list(
     LIKE part5_source_table,
     info text,
     LIKE part5_source_table2 INCLUDING ALL,
     CONSTRAINT primary_key_constraint PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_like_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "primary_key_constraint", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT primary_key_constraint PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_like_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "primary_key_constraint", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT primary_key_constraint PRIMARY KEY (id))     
 -- part 6: partition specification
 -- PARTITION OF parent_table { FOR VALUES partition_bound_spec | DEFAULT }
 CREATE TABLE part6_parent_table_range(
     id int,
     name varchar
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   
 CREATE TABLE part6_parent_table_list(
     id int,
     name varchar
 ) PARTITION BY LIST (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)   
 CREATE TABLE part6_parent_table_hash(
     id int,
     name varchar
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)   
 CREATE TABLE part6_partition_default PARTITION OF part6_parent_table_range DEFAULT;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_default", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "DEFAULT"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_default PARTITION OF public.part6_parent_table_range  DEFAULT     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_default", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "DEFAULT"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_default PARTITION OF public.part6_parent_table_range  DEFAULT    
 -- FROM ( { partition_bound_expr | MINVALUE | MAXVALUE } [, ...] )
 --  TO ( { partition_bound_expr | MINVALUE | MAXVALUE } [, ...] ) |
 CREATE TABLE part6_partition_spec_range1 PARTITION OF part6_parent_table_range
 FOR VALUES FROM (MINVALUE) TO (2);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range1", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (MINVALUE) TO (2)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range1 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (MINVALUE) TO (2)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range1", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (MINVALUE) TO (2)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range1 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (MINVALUE) TO (2)    
 CREATE TABLE part6_partition_spec_range2 PARTITION OF part6_parent_table_range
 FOR VALUES FROM (3) TO (MAXVALUE);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range2", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (3) TO (MAXVALUE)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range2 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (3) TO (MAXVALUE)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range2", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (3) TO (MAXVALUE)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range2 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (3) TO (MAXVALUE)    
 -- IN ( partition_bound_expr [, ...] ) |
 CREATE TABLE part6_partition_spec_list PARTITION OF part6_parent_table_list
 FOR VALUES IN (1, (1+2), (4+5));
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_list", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "partition_bound": "FOR VALUES IN (1, 3, 9)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_list PARTITION OF public.part6_parent_table_list  FOR VALUES IN (1, 3, 9)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_list", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "partition_bound": "FOR VALUES IN (1, 3, 9)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_list PARTITION OF public.part6_parent_table_list  FOR VALUES IN (1, 3, 9)    
 -- WITH ( MODULUS numeric_literal, REMAINDER numeric_literal )
 CREATE TABLE part6_partition_spec_hash PARTITION OF part6_parent_table_hash
 FOR VALUES WITH (MODULUS 10, REMAINDER 2);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_hash", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "partition_bound": "FOR VALUES WITH (modulus 10, remainder 2)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_hash PARTITION OF public.part6_parent_table_hash  FOR VALUES WITH (modulus 10, remainder 2)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_hash", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "partition_bound": "FOR VALUES WITH (modulus 10, remainder 2)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_hash PARTITION OF public.part6_parent_table_hash  FOR VALUES WITH (modulus 10, remainder 2)    
 -- part7: create table
 -- all data types
 CREATE TABLE part7_source_table(
     src_id int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_source_table (src_id pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_source_table (src_id pg_catalog.int4 STORAGE PLAIN      )     
 CREATE TABLE part7_data_types(
     var1 int8,
     var2 serial8,
@@ -395,8 +395,8 @@ NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s SEQUENCE %{if_not_exists
 NOTICE:  re-formed command: CREATE  SEQUENCE  public.part7_data_types_var37_seq CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 32767 START WITH 1 RESTART 1 AS pg_catalog.int2
 NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s SEQUENCE %{if_not_exists}s %{identity}D %{definition: }s", "identity": {"objname": "part7_data_types_var38_seq", "schemaname": "public"}, "definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}, {"fmt": "AS %{seqtype}T", "seqtype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}}], "persistence": "", "if_not_exists": ""}
 NOTICE:  re-formed command: CREATE  SEQUENCE  public.part7_data_types_var38_seq CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 AS pg_catalog.int4
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_data_types", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var3", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var4", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var6", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bool", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var8", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "box", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var9", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bytea", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var10", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var11", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var12", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var13", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var14", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "cidr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var15", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "circle", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var16", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var17", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var18", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "inet", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var19", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var20", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var21", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "INTERVAL", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var22", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "json", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var23", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "jsonb", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var24", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "line", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var25", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "lseg", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var26", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "macaddr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var27", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "money", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var28", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var29", "type": "column", "coltype": {"typmod": "(3,1)", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var30", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "path", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var31", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_lsn", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var32", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var33", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "point", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var34", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "polygon", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var35", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var36", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var37", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var38", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var39", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var40", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var41", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var42", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var43", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var44", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var45", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var46", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var47", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var48", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsquery", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var49", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsvector", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var50", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "txid_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var51", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "uuid", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var52", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "xml", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_data_types (var1 pg_catalog.int8 STORAGE PLAIN      , var2 pg_catalog.int8 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)  , var3 pg_catalog."bit"(1) STORAGE EXTENDED      , var4 pg_catalog."bit"(1)[] STORAGE EXTENDED      , var5 pg_catalog.varbit STORAGE EXTENDED      , var6 pg_catalog.varbit[] STORAGE EXTENDED      , var7 pg_catalog.bool STORAGE PLAIN      , var8 pg_catalog.box STORAGE PLAIN      , var9 pg_catalog.bytea STORAGE EXTENDED      , var10 pg_catalog.bpchar(1) STORAGE EXTENDED  COLLATE pg_catalog."default"    , var11 pg_catalog.bpchar(1)[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var12 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , var13 pg_catalog."varchar"[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var14 pg_catalog.cidr STORAGE MAIN      , var15 pg_catalog.circle STORAGE PLAIN      , var16 pg_catalog.date STORAGE PLAIN      , var17 pg_catalog.float8 STORAGE PLAIN      , var18 pg_catalog.inet STORAGE MAIN      , var19 pg_catalog.int4 STORAGE PLAIN      , var20 pg_catalog.int4 STORAGE PLAIN      , var21 INTERVAL STORAGE PLAIN      , var22 pg_catalog.json STORAGE EXTENDED      , var23 pg_catalog.jsonb STORAGE EXTENDED      , var24 pg_catalog.line STORAGE PLAIN      , var25 pg_catalog.lseg STORAGE PLAIN      , var26 pg_catalog.macaddr STORAGE PLAIN      , var27 pg_catalog.money STORAGE PLAIN      , var28 pg_catalog."numeric" STORAGE MAIN      , var29 pg_catalog."numeric"(3,1) STORAGE MAIN      , var30 pg_catalog.path STORAGE EXTENDED      , var31 pg_catalog.pg_lsn STORAGE PLAIN      , var32 pg_catalog.pg_snapshot STORAGE EXTENDED      , var33 pg_catalog.point STORAGE PLAIN      , var34 pg_catalog.polygon STORAGE EXTENDED      , var35 pg_catalog.float4 STORAGE PLAIN      , var36 pg_catalog.int2 STORAGE PLAIN      , var37 pg_catalog.int2 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)  , var38 pg_catalog.int4 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)  , var39 pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , var40 TIME STORAGE PLAIN      , var41 TIME(3) without time zone STORAGE PLAIN      , var42 TIME WITH TIME ZONE STORAGE PLAIN      , var43 TIME(3) with time zone STORAGE PLAIN      , var44 TIMESTAMP STORAGE PLAIN      , var45 TIMESTAMP(3) without time zone STORAGE PLAIN      , var46 TIMESTAMP WITH TIME ZONE STORAGE PLAIN      , var47 TIMESTAMP(3) with time zone STORAGE PLAIN      , var48 pg_catalog.tsquery STORAGE PLAIN      , var49 pg_catalog.tsvector STORAGE EXTENDED      , var50 pg_catalog.txid_snapshot STORAGE EXTENDED      , var51 pg_catalog.uuid STORAGE PLAIN      , var52 pg_catalog.xml STORAGE EXTENDED      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_data_types", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var3", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var4", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var6", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bool", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var8", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "box", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var9", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bytea", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var10", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var11", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var12", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var13", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var14", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "cidr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var15", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "circle", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var16", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var17", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var18", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "inet", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var19", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var20", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var21", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "INTERVAL", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var22", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "json", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var23", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "jsonb", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var24", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "line", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var25", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "lseg", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var26", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "macaddr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var27", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "money", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var28", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var29", "type": "column", "coltype": {"typmod": "(3,1)", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var30", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "path", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var31", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_lsn", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var32", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var33", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "point", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var34", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "polygon", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var35", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var36", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var37", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var38", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var39", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var40", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var41", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var42", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var43", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var44", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var45", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var46", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var47", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var48", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsquery", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var49", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsvector", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var50", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "txid_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var51", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "uuid", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var52", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "xml", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_data_types (var1 pg_catalog.int8 STORAGE PLAIN      , var2 pg_catalog.int8 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)  , var3 pg_catalog."bit"(1) STORAGE EXTENDED      , var4 pg_catalog."bit"(1)[] STORAGE EXTENDED      , var5 pg_catalog.varbit STORAGE EXTENDED      , var6 pg_catalog.varbit[] STORAGE EXTENDED      , var7 pg_catalog.bool STORAGE PLAIN      , var8 pg_catalog.box STORAGE PLAIN      , var9 pg_catalog.bytea STORAGE EXTENDED      , var10 pg_catalog.bpchar(1) STORAGE EXTENDED  COLLATE pg_catalog."default"    , var11 pg_catalog.bpchar(1)[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var12 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , var13 pg_catalog."varchar"[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var14 pg_catalog.cidr STORAGE MAIN      , var15 pg_catalog.circle STORAGE PLAIN      , var16 pg_catalog.date STORAGE PLAIN      , var17 pg_catalog.float8 STORAGE PLAIN      , var18 pg_catalog.inet STORAGE MAIN      , var19 pg_catalog.int4 STORAGE PLAIN      , var20 pg_catalog.int4 STORAGE PLAIN      , var21 INTERVAL STORAGE PLAIN      , var22 pg_catalog.json STORAGE EXTENDED      , var23 pg_catalog.jsonb STORAGE EXTENDED      , var24 pg_catalog.line STORAGE PLAIN      , var25 pg_catalog.lseg STORAGE PLAIN      , var26 pg_catalog.macaddr STORAGE PLAIN      , var27 pg_catalog.money STORAGE PLAIN      , var28 pg_catalog."numeric" STORAGE MAIN      , var29 pg_catalog."numeric"(3,1) STORAGE MAIN      , var30 pg_catalog.path STORAGE EXTENDED      , var31 pg_catalog.pg_lsn STORAGE PLAIN      , var32 pg_catalog.pg_snapshot STORAGE EXTENDED      , var33 pg_catalog.point STORAGE PLAIN      , var34 pg_catalog.polygon STORAGE EXTENDED      , var35 pg_catalog.float4 STORAGE PLAIN      , var36 pg_catalog.int2 STORAGE PLAIN      , var37 pg_catalog.int2 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)  , var38 pg_catalog.int4 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)  , var39 pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , var40 TIME STORAGE PLAIN      , var41 TIME(3) without time zone STORAGE PLAIN      , var42 TIME WITH TIME ZONE STORAGE PLAIN      , var43 TIME(3) with time zone STORAGE PLAIN      , var44 TIMESTAMP STORAGE PLAIN      , var45 TIMESTAMP(3) without time zone STORAGE PLAIN      , var46 TIMESTAMP WITH TIME ZONE STORAGE PLAIN      , var47 TIMESTAMP(3) with time zone STORAGE PLAIN      , var48 pg_catalog.tsquery STORAGE PLAIN      , var49 pg_catalog.tsvector STORAGE EXTENDED      , var50 pg_catalog.txid_snapshot STORAGE EXTENDED      , var51 pg_catalog.uuid STORAGE PLAIN      , var52 pg_catalog.xml STORAGE EXTENDED      )     
 NOTICE:  deparsed json: {"fmt": "ALTER SEQUENCE %{identity}D %{definition: }s", "identity": {"objname": "part7_data_types_var2_seq", "schemaname": "public"}, "definition": [{"fmt": "OWNED BY %{owner}D", "owner": {"objname": "part7_data_types", "attrname": "var2", "schemaname": "public"}, "clause": "owned"}]}
 NOTICE:  re-formed command: ALTER SEQUENCE public.part7_data_types_var2_seq OWNED BY public.part7_data_types.var2
 NOTICE:  deparsed json: {"fmt": "ALTER SEQUENCE %{identity}D %{definition: }s", "identity": {"objname": "part7_data_types_var37_seq", "schemaname": "public"}, "definition": [{"fmt": "OWNED BY %{owner}D", "owner": {"objname": "part7_data_types", "attrname": "var37", "schemaname": "public"}, "clause": "owned"}]}
@@ -407,15 +407,15 @@ CREATE TABLE part7_compression_collate(
     str1 varchar COMPRESSION "pglz",
     str2 varchar COLLATE "C"
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_compression_collate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_compression_collate (str1 pg_catalog."varchar" STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."default"    , str2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."C"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_compression_collate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_compression_collate (str1 pg_catalog."varchar" STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."default"    , str2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."C"    )     
 CREATE TABLE part7_inherits_parent(
     id int,
     name varchar
 )
 INHERITS (part7_data_types, part7_compression_collate);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_inherits_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_inherits_parent (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    ) INHERITS (public.part7_data_types, public.part7_compression_collate)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_inherits_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_inherits_parent (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    ) INHERITS (public.part7_data_types, public.part7_compression_collate)    
 CREATE TABLE part7_combine_all_clauses(
     id varchar(5) COMPRESSION "pglz" COLLATE "C" CONSTRAINT id_constraint DEFAULT 'foo',
     PRIMARY KEY (id),
@@ -426,8 +426,8 @@ INHERITS (part7_data_types, part7_compression_collate)
 USING heap
 WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true)
 TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_combine_all_clauses (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_combine_all_clauses (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 CREATE TEMP TABLE part7_combine_all_clauses_temp(
     id varchar(5) COMPRESSION "pglz" COLLATE "C" CONSTRAINT id_constraint DEFAULT 'foo',
     PRIMARY KEY (id),
@@ -439,22 +439,22 @@ USING heap
 WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true)
 ON COMMIT DELETE ROWS
 TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses_temp", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "DELETE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_temp_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part7_combine_all_clauses_temp (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_temp_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') ON COMMIT DELETE ROWS TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses_temp", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_temp_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part7_combine_all_clauses_temp (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_temp_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 -- CREATE TABLE ... AS
 CREATE TABLE test_ctas AS SELECT 0 AS col1, 1 AS col2;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_ctas", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_ctas (col1 pg_catalog.int4 STORAGE PLAIN      , col2 pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_ctas", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_ctas (col1 pg_catalog.int4 STORAGE PLAIN      , col2 pg_catalog.int4 STORAGE PLAIN      )     
 -- part8: create typed table
 CREATE TABLE part8_create_typed_table OF part8_people_type;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table OF public.part8_people_type      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table OF public.part8_people_type     
 CREATE TABLE part8_create_typed_table_simple OF part8_people_type(
     weight,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_simple", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_simple_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_simple OF public.part8_people_type (CONSTRAINT part8_create_typed_table_simple_pkey PRIMARY KEY (id))     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_simple", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_simple_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_simple OF public.part8_people_type (CONSTRAINT part8_create_typed_table_simple_pkey PRIMARY KEY (id))    
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "part8_create_typed_table_simple", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.part8_create_typed_table_simple ALTER COLUMN id SET NOT NULL
 CREATE TABLE part8_create_typed_table_with_options_constaints OF part8_people_type(
@@ -462,8 +462,8 @@ CREATE TABLE part8_create_typed_table_with_options_constaints OF part8_people_ty
     name UNIQUE,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_with_options_constaints", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_with_options_constaints OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_with_options_constaints_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_with_options_constaints_pkey PRIMARY KEY (id))     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_with_options_constaints", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_with_options_constaints OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_with_options_constaints_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_with_options_constaints_pkey PRIMARY KEY (id))    
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "part8_create_typed_table_with_options_constaints", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.part8_create_typed_table_with_options_constaints ALTER COLUMN id SET NOT NULL
 CREATE TABLE part8_create_typed_table_complex_combinations OF part8_people_type(
@@ -474,8 +474,8 @@ CREATE TABLE part8_create_typed_table_complex_combinations OF part8_people_type(
 USING heap
 WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true)
 TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_complex_combinations", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_complex_combinations OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_complex_combinations_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_complex_combinations_pkey PRIMARY KEY (id))  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_complex_combinations", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_complex_combinations OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_complex_combinations_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_complex_combinations_pkey PRIMARY KEY (id))  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "part8_create_typed_table_complex_combinations", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.part8_create_typed_table_complex_combinations ALTER COLUMN id SET NOT NULL
 -- part9: create table as a partition of parent table, FOR VALUES clause is tested in part 6
@@ -485,24 +485,24 @@ CREATE TABLE part9_parent_table_range(
     height float4,
     weight float4
 ) PARTITION BY RANGE (height);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part9_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (height)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY RANGE (height)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part9_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (height)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY RANGE (height)   
 CREATE TABLE part9_parent_table_list(
     id int,
     name varchar,
     height float4,
     weight float4
 ) PARTITION BY LIST (name);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part9_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY LIST (name)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part9_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY LIST (name)   
 CREATE TABLE part9_parent_table_hash(
     id int,
     name varchar,
     height float4,
     weight float4
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part9_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part9_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY HASH (id)   
 -- TOFIX
 -- CREATE TABLE part9_partition_with_options_constraintscd
 -- PARTITION OF part9_parent_table_range (
@@ -533,8 +533,8 @@ NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_hash (id pg
 -- copied from old create_table.sql
 -- Test TableLikeClause is handled properly
 CREATE TABLE ctlt1 (a text CHECK (length(a) > 2) PRIMARY KEY, b text);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "ctlt1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1 (a pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_pkey PRIMARY KEY (a))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "ctlt1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1 (a pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_pkey PRIMARY KEY (a))     
 ALTER TABLE ctlt1 ALTER COLUMN a SET STORAGE MAIN;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STORAGE %{storage}s", "type": "set storage", "column": "a", "storage": "main"}], "identity": {"objname": "ctlt1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.ctlt1 ALTER COLUMN a SET STORAGE main
@@ -542,18 +542,18 @@ ALTER TABLE ctlt1 ALTER COLUMN b SET STORAGE EXTERNAL;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STORAGE %{storage}s", "type": "set storage", "column": "b", "storage": "external"}], "identity": {"objname": "ctlt1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.ctlt1 ALTER COLUMN b SET STORAGE external
 CREATE TABLE ctlt1_like (LIKE ctlt1 INCLUDING ALL);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "ctlt1_like", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTERNAL", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_like_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1_like (a pg_catalog.text STORAGE MAIN  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTERNAL  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_like_pkey PRIMARY KEY (a))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "ctlt1_like", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTERNAL", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_like_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1_like (a pg_catalog.text STORAGE MAIN  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTERNAL  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_like_pkey PRIMARY KEY (a))     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 -- Test foreign key constraint is handled in a following ALTER TABLE ADD CONSTRAINT FOREIGN KEY REFERENCES subcommand
 CREATE TABLE product (id int PRIMARY KEY, name text);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "product", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "product_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.product (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT product_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "product", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "product_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.product (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT product_pkey PRIMARY KEY (id))     
 CREATE TABLE orders2 (order_id int PRIMARY KEY, product_id int
 REFERENCES product (id));
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "orders2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "order_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "orders2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (order_id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.orders2 (order_id pg_catalog.int4 STORAGE PLAIN      , product_id pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT orders2_pkey PRIMARY KEY (order_id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "orders2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "order_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "orders2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (order_id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.orders2 (order_id pg_catalog.int4 STORAGE PLAIN      , product_id pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT orders2_pkey PRIMARY KEY (order_id))     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "orders2_product_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (product_id) REFERENCES public.product(id)"}], "identity": {"objname": "orders2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.orders2 ADD CONSTRAINT orders2_product_id_fkey FOREIGN KEY (product_id) REFERENCES public.product(id)
 -- Test CREATE and ALTER inherited table
@@ -561,11 +561,11 @@ CREATE TABLE gtest30 (
 a int,
 b int GENERATED ALWAYS AS (a * 2) STORED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "gtest30", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(a OPERATOR(pg_catalog.*) 2)"}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.gtest30 (a pg_catalog.int4 STORAGE PLAIN      , b pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((a OPERATOR(pg_catalog.*) 2)) STORED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "gtest30", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(a OPERATOR(pg_catalog.*) 2)"}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.gtest30 (a pg_catalog.int4 STORAGE PLAIN      , b pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((a OPERATOR(pg_catalog.*) 2)) STORED)     
 CREATE TABLE gtest30_1 () INHERITS (gtest30);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "gtest30_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "gtest30", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
-NOTICE:  re-formed command: CREATE  TABLE  public.gtest30_1 () INHERITS (public.gtest30)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "gtest30_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "gtest30", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
+NOTICE:  re-formed command: CREATE  TABLE  public.gtest30_1 () INHERITS (public.gtest30)    
 ALTER TABLE gtest30 ALTER COLUMN b DROP EXPRESSION;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", "type": "drop expression", "column": "b", "if_exists": ""}], "identity": {"objname": "gtest30", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.gtest30 ALTER COLUMN b DROP EXPRESSION 
diff --git a/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c b/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c
index 04288c68e0..79036a197f 100644
--- a/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c
+++ b/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c
@@ -58,10 +58,10 @@ deparse_drop_ddl(PG_FUNCTION_ARGS)
 		PG_RETURN_NULL();
 	}
 
-	command = deparse_drop_command(objidentity_str, objecttype_str, (Node *)&fake_node);
-
+	command = deparse_drop_table(objidentity_str, objecttype_str,
+											(Node *)&fake_node);
 	if (command)
 		PG_RETURN_TEXT_P(cstring_to_text(command));
 
 	PG_RETURN_NULL();
-}
\ No newline at end of file
+}
-- 
2.34.1

